#
# PySNMP MIB module GMPLS-LABEL-STD-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/GMPLS-LABEL-STD-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:13:51 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( OctetString, Integer, ObjectIdentifier, ) = mibBuilder.importSymbols("ASN1", "OctetString", "Integer", "ObjectIdentifier")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsUnion, SingleValueConstraint, ValueRangeConstraint, ValueSizeConstraint, ConstraintsIntersection, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsUnion", "SingleValueConstraint", "ValueRangeConstraint", "ValueSizeConstraint", "ConstraintsIntersection")
( IndexIntegerNextFree, ) = mibBuilder.importSymbols("DIFFSERV-MIB", "IndexIntegerNextFree")
( GmplsLabelTypeTC, GmplsFreeformLabelTC, ) = mibBuilder.importSymbols("GMPLS-TC-STD-MIB", "GmplsLabelTypeTC", "GmplsFreeformLabelTC")
( InterfaceIndexOrZero, ) = mibBuilder.importSymbols("IF-MIB", "InterfaceIndexOrZero")
( mplsStdMIB, MplsLabel, ) = mibBuilder.importSymbols("MPLS-TC-STD-MIB", "mplsStdMIB", "MplsLabel")
( NotificationGroup, ModuleCompliance, ObjectGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ModuleCompliance", "ObjectGroup")
( Bits, Unsigned32, Integer32, Counter32, Gauge32, iso, MibIdentifier, ModuleIdentity, TimeTicks, ObjectIdentity, MibScalar, MibTable, MibTableRow, MibTableColumn, NotificationType, IpAddress, Counter64, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Bits", "Unsigned32", "Integer32", "Counter32", "Gauge32", "iso", "MibIdentifier", "ModuleIdentity", "TimeTicks", "ObjectIdentity", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "NotificationType", "IpAddress", "Counter64")
( TextualConvention, DisplayString, StorageType, RowStatus, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "DisplayString", "StorageType", "RowStatus")
gmplsLabelStdMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 10, 166, 16)).setRevisions(("2007-02-27 00:00",))
if mibBuilder.loadTexts: gmplsLabelStdMIB.setLastUpdated('200702270000Z')
if mibBuilder.loadTexts: gmplsLabelStdMIB.setOrganization('IETF Common Control and Measurement Plane (CCAMP) Working Group')
if mibBuilder.loadTexts: gmplsLabelStdMIB.setContactInfo('       Thomas D. Nadeau\n            Cisco Systems, Inc.\n     Email: tnadeau@cisco.com\n\n            Adrian Farrel\n            Old Dog Consulting\n     Email: adrian@olddog.co.uk\n\n     Comments about this document should be emailed directly to the\n     CCAMP working group mailing list at ccamp@ops.ietf.org.')
if mibBuilder.loadTexts: gmplsLabelStdMIB.setDescription('Copyright (C) The IETF Trust (2007).  This version of\n     this MIB module is part of RFC 4803; see the RFC itself for\n     full legal notices.\n\n\n\n\n     This MIB module contains managed object definitions for labels\n     within GMPLS systems as defined in\n     Generalized Multi-Protocol Label Switching (GMPLS) Signaling\n     Functional Description, Berger, L. (Editor), RFC 3471,\n     January 2003.')
gmplsLabelObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 16, 1))
gmplsLabelConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 16, 2))
gmplsLabelIndexNext = MibScalar((1, 3, 6, 1, 2, 1, 10, 166, 16, 1, 1), IndexIntegerNextFree()).setMaxAccess("readonly")
if mibBuilder.loadTexts: gmplsLabelIndexNext.setDescription('This object contains an unused value for gmplsLabelIndex,\n       or a zero to indicate that no unused value exists or is\n       available.\n\n       A management application wishing to create a row in the\n       gmplsLabelTable may read this object and then attempt to\n       create a row in the table.  If row creation fails (because\n       another application has already created a row with the\n       supplied index), the management application should read this\n       object again to get a new index value.\n\n       When a row is created in the gmplsLabelTable with the\n       gmplsLabelIndex value held by this object, an implementation\n       MUST change the value in this object.')
gmplsLabelTable = MibTable((1, 3, 6, 1, 2, 1, 10, 166, 16, 1, 2), )
if mibBuilder.loadTexts: gmplsLabelTable.setDescription('Table of GMPLS Labels.  This table allows the representation\n     of the more complex label forms required for GMPLS that cannot\n     be held within the TEXTUAL-CONVENTION MplsLabel; that is, labels\n     that cannot be encoded within 32 bits.  It is, nevertheless, also\n     capable of holding 32-bit labels or regular MPLS Labels if\n     desired.\n\n\n     Each entry in this table represents an individual GMPLS Label\n     value.  The representation of Labels in tables in other MIB\n     modules may be achieved by a referrence to an entry in this\n     table by means of a row pointer into this table.  The indexing\n     of this table provides for arbitrary indexing and also for\n     concatenation of labels.\n\n     For an example of label concatenation, see RFC 3945, section 7.1.\n     In essence, a GMPLS Label may be composite in order to identify\n     a set of resources in the data plane.  Practical examples are\n     timeslots and wavelength sets (which are not contiguous like\n     wavebands).\n\n     The indexing mechanism allows multiple entries in this table to\n     be seen as a sequence of labels that should be concatenated.\n     Ordering is potentially very sensitive for concatenation.')
gmplsLabelEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 166, 16, 1, 2, 1), ).setIndexNames((0, "GMPLS-LABEL-STD-MIB", "gmplsLabelInterface"), (0, "GMPLS-LABEL-STD-MIB", "gmplsLabelIndex"), (0, "GMPLS-LABEL-STD-MIB", "gmplsLabelSubindex"))
if mibBuilder.loadTexts: gmplsLabelEntry.setDescription('An entry in this table represents a single label value.  There\n     are three indexes into the table.\n\n     -  The interface index may be helpful to distinguish which\n        labels are in use on which interfaces or to handle cases\n        where there are a very large number of labels in use in the\n        system.  When label representation is desired to apply to the\n        whole system or when it is not important to distinguish\n        labels by their interfaces, this index MAY be set to zero.\n\n     -  The label index provides a way of identifying the label.\n\n     -  The label sub-index is only used for concatenated labels.  It\n        identifies each component label.  When non-concatenated labels\n        are used, this index SHOULD be set to zero.\n\n     A storage type object is supplied to control the storage type\n     for each entry, but implementations should note that the storage\n     type of conceptual rows in other tables that include row\n     pointers to an entry in this table SHOULD dictate the storage\n     type of the rows in this table where the row in the other table\n     is more persistent.')
gmplsLabelInterface = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 16, 1, 2, 1, 1), InterfaceIndexOrZero())
if mibBuilder.loadTexts: gmplsLabelInterface.setDescription('The interface on which this label is used.  If this object is set\n     to zero, the label MUST have applicability across the\n     whole system and not be limited to a single interface.')
gmplsLabelIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 16, 1, 2, 1, 2), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,4294967295)))
if mibBuilder.loadTexts: gmplsLabelIndex.setDescription('An arbitrary index into the table to identify a label.\n\n     Note that implementations that are representing 32-bit labels\n     within this table MAY choose to align this index with the value\n     of the label, and this may result in the use of the value zero\n     since it represents a valid label value.  Such implementation\n     should be aware of the implications of sparsely populated\n\n\n     tables.\n\n     A management application may read the gmplsLabelIndexNext\n     object to find a suitable value for this object.')
gmplsLabelSubindex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 16, 1, 2, 1, 3), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,4294967295)))
if mibBuilder.loadTexts: gmplsLabelSubindex.setDescription('In conjunction with gmplsLabelInterface and gmplsLabelIndex,\n     this object uniquely identifies this row.  This sub-index allows\n     a single GMPLS Label to be defined as a concatenation of labels.\n     This is particularly useful in TDM.\n\n     The ordering of sub-labels is strict with the sub-label with\n     the lowest gmplsLabelSubindex appearing first.  Note that all\n     sub-labels of a single GMPLS Label must share the same\n     gmplsLabelInterface and gmplsLabelIndex values.  For labels that\n     are not composed of concatenated sub-labels, this value SHOULD\n     be set to zero.')
gmplsLabelType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 16, 1, 2, 1, 4), GmplsLabelTypeTC()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: gmplsLabelType.setDescription('Identifies the type of this label.  Note that this object does\n     not determine whether MPLS or GMPLS signaling is in use: a value\n     of gmplsMplsLabel(1) denotes that an MPLS Packet Label is\n     present in the gmplsLabelMplsLabel object and encoded using the\n     MplsLabel TEXTUAL-CONVENTION (may be a 20-bit MPLS Label, a 10-\n     or 23-bit Frame Relay Label, or an Asynchronous Transfer Mode\n     (ATM) Label), but does not describe whether this is signaled\n     using MPLS or GMPLS.\n\n     The value of this object helps determine which of the following\n     objects are valid.  This object cannot be modified if\n     gmplsLabelRowStatus is active(1).')
gmplsLabelMplsLabel = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 16, 1, 2, 1, 5), MplsLabel()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: gmplsLabelMplsLabel.setDescription('The value of an MPLS Label (that is a Packet Label) if this\n     table is used to store it.  This may be used in MPLS systems even\n     though the label values can be adequately stored in the MPLS MIB\n     modules (MPLS-LSR-STD-MIB and MPLS-TE-STD-MIB).  Furthermore, in\n     mixed MPLS and GMPLS systems, it may be advantageous to store all\n     labels in a single label table.  Lastly, in GMPLS systems where\n     Packet Labels are used (that is in systems that use GMPLS\n     signaling and GMPLS Labels for packet switching), it may be\n     desirable to use this table.\n\n     This object is only valid if gmplsLabelType is set\n     to gmplsMplsLabel(1).  This object cannot be modified if\n     gmplsLabelRowStatus is active(1).')
gmplsLabelPortWavelength = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 16, 1, 2, 1, 6), Unsigned32()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: gmplsLabelPortWavelength.setDescription('The value of a Port or Wavelength Label when carried as a\n     Generalized Label.  Only valid if gmplsLabelType is set to\n     gmplsPortWavelengthLabel(2).  This object cannot be modified if\n     gmplsLabelRowStatus is active(1).')
gmplsLabelFreeform = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 16, 1, 2, 1, 7), GmplsFreeformLabelTC().clone(hexValue="00")).setMaxAccess("readcreate")
if mibBuilder.loadTexts: gmplsLabelFreeform.setDescription('The value of a Freeform Generalized Label that does not conform\n     to one of the standardized label encodings or that an\n     implementation chooses to represent as an octet string without\n     further decoding.  Only valid if gmplsLabelType is set to\n     gmplsFreeformLabel(3).  This object cannot be modified\n     if gmplsLabelRowStatus is active(1).')
gmplsLabelSonetSdhSignalIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 16, 1, 2, 1, 8), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,4095))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: gmplsLabelSonetSdhSignalIndex.setDescription('The Signal Index value (S) of a SONET or SDH Generalized Label.\n     Zero indicates that this field is non-significant.  Only valid if\n     gmplsLabelType is set to gmplsSonetLabel(4) or gmplsSdhLabel(5).\n     This object cannot be modified if gmplsLabelRowStatus is\n     active(1).')
gmplsLabelSdhVc = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 16, 1, 2, 1, 9), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,15))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: gmplsLabelSdhVc.setDescription('The VC Indicator (U) of an SDH Generalized Label.  Zero indicates\n     that this field is non-significant.  Only valid if gmplsLabelType\n     is set to gmplsSdhLabel(5).  This object cannot be modified if\n     gmplsLabelRowStatus is active(1).')
gmplsLabelSdhVcBranch = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 16, 1, 2, 1, 10), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,15))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: gmplsLabelSdhVcBranch.setDescription('The VC Branch Indicator (K) of an SDH Generalized Label.  Zero\n     indicates that this field is non-significant.  Only valid if\n     gmplsLabelType is set to gmplsSdhLabel(5).  This\n     object cannot be modified if gmplsLabelRowStatus is active(1).')
gmplsLabelSonetSdhBranch = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 16, 1, 2, 1, 11), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,15))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: gmplsLabelSonetSdhBranch.setDescription('The Branch Indicator (L) of a SONET or SDH Generalized Label.\n     Zero indicates that this field is non-significant.  Only valid\n     gmplsLabelType is set to gmplsSonetLabel(4) or\n     gmplsSdhLabel(5).  This object cannot be modified if\n     gmplsLabelRowStatus is active(1).')
gmplsLabelSonetSdhGroupBranch = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 16, 1, 2, 1, 12), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,15))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: gmplsLabelSonetSdhGroupBranch.setDescription('The Group Branch Indicator (M) of a SONET or SDH Generalized\n     Label.  Zero indicates that this field is non-significant.\n     Only valid if gmplsLabelType is set to gmplsSonetLabel(4) or\n     gmplsSdhLabel(5).  This object cannot be modified if\n     gmplsLabelRowStatus is active(1).')
gmplsLabelWavebandId = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 16, 1, 2, 1, 13), Unsigned32()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: gmplsLabelWavebandId.setDescription('The waveband identifier component of a Waveband Label.  Only\n     valid if gmplsLabelType is set to gmplsWavebandLabel(6).  This\n     object cannot be modified if gmplsLabelRowStatus is active(1).')
gmplsLabelWavebandStart = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 16, 1, 2, 1, 14), Unsigned32()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: gmplsLabelWavebandStart.setDescription('The starting label component of a Waveband Label.  Only valid if\n     gmplsLabelType is set to gmplsWavebandLabel(6).  This object\n     cannot be modified if gmplsLabelRowStatus is active(1).')
gmplsLabelWavebandEnd = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 16, 1, 2, 1, 15), Unsigned32()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: gmplsLabelWavebandEnd.setDescription('The end label component of a Waveband Label.  Only valid if\n     gmplsLabelType is set to gmplsWavebandLabel(6).  This object\n     cannot be modified if gmplsLabelRowStatus is active(1).')
gmplsLabelStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 16, 1, 2, 1, 16), StorageType().clone('volatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: gmplsLabelStorageType.setDescription("This variable indicates the storage type for this row.  The\n     agent MUST ensure that this object's value remains consistent\n     with the storage type of any rows in other tables that contain\n     pointers to this row.  In particular, the storage type of this\n     row must be at least as permanent as that of any row that points\n     to it.\n     Conceptual rows having the value 'permanent' need not\n     allow write-access to any columnar objects in the row.")
gmplsLabelRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 16, 1, 2, 1, 17), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: gmplsLabelRowStatus.setDescription('This variable is used to create, modify, and/or delete a row in\n     this table.  When a row in this table has a row in the active(1)\n     state, no objects in this row can be modified except the\n     gmplsLabelRowStatus and gmplsLabelStorageType.\n\n     The gmplsLabelType object does not have a default and must be\n     set before a row can become active.  The corresponding label\n     objects (dependent on the value of gmplsLabelType) should also\n     be set unless they happen to need to use the specified default\n     values as follows:\n\n     gmplsLabelType setting             objects to be set\n     --------------------------------------------------------------\n     gmplsMplsLabel(1)                  gmplsLabelMplsLabel\n\n     gmplsPortWavelengthLabel(2)        gmplsLabelPortWavelength\n\n     gmplsFreeformLabel(3)              gmplsLabelFreeform\n\n     gmplsSonetLabel(4)                 gmplsLabelSonetSdhSignalIndex\n                                        gmplsLabelSdhVc\n                                        gmplsLabelSdhVcBranch\n                                        gmplsLabelSonetSdhBranch\n                                        gmplsLabelSonetSdhGroupBranch\n\n     gmplsSdhLabel(5)                   gmplsLabelSonetSdhSignalIndex\n                                        gmplsLabelSdhVc\n                                        gmplsLabelSdhVcBranch\n                                        gmplsLabelSonetSdhBranch\n                                        gmplsLabelSonetSdhGroupBranch\n\n     gmplsWavebandLabel(6)              gmplsLabelWavebandId\n                                        gmplsLabelWavebandStart\n                                        gmplsLabelWavebandEnd')
gmplsLabelGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 16, 2, 1))
gmplsLabelCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 16, 2, 2))
gmplsLabelModuleReadOnlyCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 10, 166, 16, 2, 2, 1)).setObjects(*(("GMPLS-LABEL-STD-MIB", "gmplsLabelTableGroup"), ("GMPLS-LABEL-STD-MIB", "gmplsLabelPacketGroup"), ("GMPLS-LABEL-STD-MIB", "gmplsLabelPortWavelengthGroup"), ("GMPLS-LABEL-STD-MIB", "gmplsLabelFreeformGroup"), ("GMPLS-LABEL-STD-MIB", "gmplsLabelSonetSdhGroup"), ("GMPLS-LABEL-STD-MIB", "gmplsLabelWavebandGroup"),))
if mibBuilder.loadTexts: gmplsLabelModuleReadOnlyCompliance.setDescription('Compliance requirement for implementations that only provide\n     read-only support for GMPLS-LABEL-STD-MIB.  Such devices can then\n     be monitored but cannot be configured using this MIB module.')
gmplsLabelModuleFullCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 10, 166, 16, 2, 2, 2)).setObjects(*(("GMPLS-LABEL-STD-MIB", "gmplsLabelTableGroup"),))
if mibBuilder.loadTexts: gmplsLabelModuleFullCompliance.setDescription('Compliance statement for agents that support the complete\n     GMPLS-LABEL-STD-MIB module.\n\n     The mandatory groups have to be implemented by GMPLS LSRs\n     claiming support for this MIB module.  This MIB module is,\n     however, not mandatory for a working implementation of a GMPLS\n     LSR with full MIB support if the GMPLS Labels in use can be\n     represented within a 32-bit quantity.')
gmplsLabelTableGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 166, 16, 2, 1, 1)).setObjects(*(("GMPLS-LABEL-STD-MIB", "gmplsLabelIndexNext"), ("GMPLS-LABEL-STD-MIB", "gmplsLabelType"), ("GMPLS-LABEL-STD-MIB", "gmplsLabelStorageType"), ("GMPLS-LABEL-STD-MIB", "gmplsLabelRowStatus"),))
if mibBuilder.loadTexts: gmplsLabelTableGroup.setDescription('Necessary, but not sufficient, set of objects to implement label\n     table support.  In addition, depending on the type of labels\n     supported, the following other groups defined below are\n     mandatory:\n\n       gmplsLabelWavebandGroup and/or\n       gmplsLabelPacketGroup and/or\n       gmplsLabelPortWavelengthGroup and/or\n       gmplsLabelFreeformGroup and/or\n       gmplsLabelSonetSdhGroup.')
gmplsLabelPacketGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 166, 16, 2, 1, 2)).setObjects(*(("GMPLS-LABEL-STD-MIB", "gmplsLabelMplsLabel"),))
if mibBuilder.loadTexts: gmplsLabelPacketGroup.setDescription('Object needed to implement Packet (MPLS) Labels.')
gmplsLabelPortWavelengthGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 166, 16, 2, 1, 3)).setObjects(*(("GMPLS-LABEL-STD-MIB", "gmplsLabelPortWavelength"),))
if mibBuilder.loadTexts: gmplsLabelPortWavelengthGroup.setDescription('Object needed to implement Port and Wavelength Labels.')
gmplsLabelFreeformGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 166, 16, 2, 1, 4)).setObjects(*(("GMPLS-LABEL-STD-MIB", "gmplsLabelFreeform"),))
if mibBuilder.loadTexts: gmplsLabelFreeformGroup.setDescription('Object needed to implement Freeform Labels.')
gmplsLabelSonetSdhGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 166, 16, 2, 1, 5)).setObjects(*(("GMPLS-LABEL-STD-MIB", "gmplsLabelSonetSdhSignalIndex"), ("GMPLS-LABEL-STD-MIB", "gmplsLabelSdhVc"), ("GMPLS-LABEL-STD-MIB", "gmplsLabelSdhVcBranch"), ("GMPLS-LABEL-STD-MIB", "gmplsLabelSonetSdhBranch"), ("GMPLS-LABEL-STD-MIB", "gmplsLabelSonetSdhGroupBranch"),))
if mibBuilder.loadTexts: gmplsLabelSonetSdhGroup.setDescription('Objects needed to implement SONET and SDH Labels.')
gmplsLabelWavebandGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 166, 16, 2, 1, 6)).setObjects(*(("GMPLS-LABEL-STD-MIB", "gmplsLabelWavebandId"), ("GMPLS-LABEL-STD-MIB", "gmplsLabelWavebandStart"), ("GMPLS-LABEL-STD-MIB", "gmplsLabelWavebandEnd"),))
if mibBuilder.loadTexts: gmplsLabelWavebandGroup.setDescription('Objects needed to implement Waveband Labels.')
mibBuilder.exportSymbols("GMPLS-LABEL-STD-MIB", gmplsLabelFreeformGroup=gmplsLabelFreeformGroup, gmplsLabelWavebandEnd=gmplsLabelWavebandEnd, gmplsLabelSonetSdhBranch=gmplsLabelSonetSdhBranch, gmplsLabelSdhVcBranch=gmplsLabelSdhVcBranch, gmplsLabelSdhVc=gmplsLabelSdhVc, gmplsLabelMplsLabel=gmplsLabelMplsLabel, PYSNMP_MODULE_ID=gmplsLabelStdMIB, gmplsLabelTableGroup=gmplsLabelTableGroup, gmplsLabelSubindex=gmplsLabelSubindex, gmplsLabelSonetSdhGroup=gmplsLabelSonetSdhGroup, gmplsLabelType=gmplsLabelType, gmplsLabelConformance=gmplsLabelConformance, gmplsLabelWavebandGroup=gmplsLabelWavebandGroup, gmplsLabelInterface=gmplsLabelInterface, gmplsLabelModuleReadOnlyCompliance=gmplsLabelModuleReadOnlyCompliance, gmplsLabelWavebandId=gmplsLabelWavebandId, gmplsLabelPacketGroup=gmplsLabelPacketGroup, gmplsLabelFreeform=gmplsLabelFreeform, gmplsLabelWavebandStart=gmplsLabelWavebandStart, gmplsLabelStorageType=gmplsLabelStorageType, gmplsLabelCompliances=gmplsLabelCompliances, gmplsLabelRowStatus=gmplsLabelRowStatus, gmplsLabelPortWavelengthGroup=gmplsLabelPortWavelengthGroup, gmplsLabelPortWavelength=gmplsLabelPortWavelength, gmplsLabelModuleFullCompliance=gmplsLabelModuleFullCompliance, gmplsLabelIndex=gmplsLabelIndex, gmplsLabelEntry=gmplsLabelEntry, gmplsLabelSonetSdhSignalIndex=gmplsLabelSonetSdhSignalIndex, gmplsLabelSonetSdhGroupBranch=gmplsLabelSonetSdhGroupBranch, gmplsLabelTable=gmplsLabelTable, gmplsLabelObjects=gmplsLabelObjects, gmplsLabelStdMIB=gmplsLabelStdMIB, gmplsLabelGroups=gmplsLabelGroups, gmplsLabelIndexNext=gmplsLabelIndexNext)
