#
# PySNMP MIB module RIPv2-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/RIPv2-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:26:36 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( Integer, ObjectIdentifier, OctetString, ) = mibBuilder.importSymbols("ASN1", "Integer", "ObjectIdentifier", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueRangeConstraint, ConstraintsIntersection, SingleValueConstraint, ValueSizeConstraint, ConstraintsUnion, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueRangeConstraint", "ConstraintsIntersection", "SingleValueConstraint", "ValueSizeConstraint", "ConstraintsUnion")
( ModuleCompliance, ObjectGroup, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "ObjectGroup", "NotificationGroup")
( IpAddress, Gauge32, iso, Integer32, mib_2, NotificationType, TimeTicks, Bits, Counter64, ModuleIdentity, ObjectIdentity, Unsigned32, Counter32, MibIdentifier, MibScalar, MibTable, MibTableRow, MibTableColumn, ) = mibBuilder.importSymbols("SNMPv2-SMI", "IpAddress", "Gauge32", "iso", "Integer32", "mib-2", "NotificationType", "TimeTicks", "Bits", "Counter64", "ModuleIdentity", "ObjectIdentity", "Unsigned32", "Counter32", "MibIdentifier", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn")
( RowStatus, TextualConvention, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "RowStatus", "TextualConvention", "DisplayString")
rip2 = ModuleIdentity((1, 3, 6, 1, 2, 1, 23))
if mibBuilder.loadTexts: rip2.setLastUpdated('9407272253Z')
if mibBuilder.loadTexts: rip2.setOrganization('IETF RIP-II Working Group')
if mibBuilder.loadTexts: rip2.setContactInfo('       Fred Baker\n          Postal: Cisco Systems\n                  519 Lado Drive\n                  Santa Barbara, California 93111\n          Tel:    +1 805 681 0115\n          E-Mail: fbaker@cisco.com\n\n          Postal: Gary Malkin\n                  Xylogics, Inc.\n                  53 Third Avenue\n                  Burlington, MA  01803\n\n          Phone:  (617) 272-8140\n          EMail:  gmalkin@Xylogics.COM')
if mibBuilder.loadTexts: rip2.setDescription('The MIB module to describe the RIP2 Version 2 Protocol')
class RouteTag(OctetString, TextualConvention):
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(2,2)
    fixedLength = 2

rip2Globals = MibIdentifier((1, 3, 6, 1, 2, 1, 23, 1))
rip2GlobalRouteChanges = MibScalar((1, 3, 6, 1, 2, 1, 23, 1, 1), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rip2GlobalRouteChanges.setDescription("The number of route changes made to the IP Route\n           Database by RIP.  This does not include the refresh\n           of a route's age.")
rip2GlobalQueries = MibScalar((1, 3, 6, 1, 2, 1, 23, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rip2GlobalQueries.setDescription('The number of responses sent to RIP queries\n           from other systems.')
rip2IfStatTable = MibTable((1, 3, 6, 1, 2, 1, 23, 2), )
if mibBuilder.loadTexts: rip2IfStatTable.setDescription('A list of subnets which require separate\n           status monitoring in RIP.')
rip2IfStatEntry = MibTableRow((1, 3, 6, 1, 2, 1, 23, 2, 1), ).setIndexNames((0, "RIPv2-MIB", "rip2IfStatAddress"))
if mibBuilder.loadTexts: rip2IfStatEntry.setDescription('A Single Routing Domain in a single Subnet.')
rip2IfStatAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 23, 2, 1, 1), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rip2IfStatAddress.setDescription('The IP Address of this system on the indicated\n           subnet. For unnumbered interfaces, the value 0.0.0.N,\n           where the least significant 24 bits (N) is the ifIndex\n           for the IP Interface in network byte order.')
rip2IfStatRcvBadPackets = MibTableColumn((1, 3, 6, 1, 2, 1, 23, 2, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rip2IfStatRcvBadPackets.setDescription('The number of RIP response packets received by\n           the RIP process which were subsequently discarded\n           for any reason (e.g. a version 0 packet, or an\n           unknown command type).')
rip2IfStatRcvBadRoutes = MibTableColumn((1, 3, 6, 1, 2, 1, 23, 2, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rip2IfStatRcvBadRoutes.setDescription('The number of routes, in valid RIP packets,\n           which were ignored for any reason (e.g. unknown\n           address family, or invalid metric).')
rip2IfStatSentUpdates = MibTableColumn((1, 3, 6, 1, 2, 1, 23, 2, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rip2IfStatSentUpdates.setDescription('The number of triggered RIP updates actually\n           sent on this interface.  This explicitly does\n           NOT include full updates sent containing new\n           information.')
rip2IfStatStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 23, 2, 1, 5), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: rip2IfStatStatus.setDescription('Writing invalid has the effect of deleting\n           this interface.')
rip2IfConfTable = MibTable((1, 3, 6, 1, 2, 1, 23, 3), )
if mibBuilder.loadTexts: rip2IfConfTable.setDescription('A list of subnets which require separate\n           configuration in RIP.')
rip2IfConfEntry = MibTableRow((1, 3, 6, 1, 2, 1, 23, 3, 1), ).setIndexNames((0, "RIPv2-MIB", "rip2IfConfAddress"))
if mibBuilder.loadTexts: rip2IfConfEntry.setDescription('A Single Routing Domain in a single Subnet.')
rip2IfConfAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 23, 3, 1, 1), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rip2IfConfAddress.setDescription('The IP Address of this system on the indicated\n           subnet.  For unnumbered interfaces, the value 0.0.0.N,\n           where the least significant 24 bits (N) is the ifIndex\n           for the IP Interface in network byte order.')
rip2IfConfDomain = MibTableColumn((1, 3, 6, 1, 2, 1, 23, 3, 1, 2), RouteTag().clone(hexValue="0000")).setMaxAccess("readcreate")
if mibBuilder.loadTexts: rip2IfConfDomain.setDescription('Value inserted into the Routing Domain field\n           of all RIP packets sent on this interface.')
rip2IfConfAuthType = MibTableColumn((1, 3, 6, 1, 2, 1, 23, 3, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("noAuthentication", 1), ("simplePassword", 2), ("md5", 3),)).clone('noAuthentication')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: rip2IfConfAuthType.setDescription('The type of Authentication used on this\n           interface.')
rip2IfConfAuthKey = MibTableColumn((1, 3, 6, 1, 2, 1, 23, 3, 1, 4), OctetString().subtype(subtypeSpec=ValueSizeConstraint(0,16)).clone(hexValue="")).setMaxAccess("readcreate")
if mibBuilder.loadTexts: rip2IfConfAuthKey.setDescription('The value to be used as the Authentication Key\n           whenever the corresponding instance of\n           rip2IfConfAuthType has a value other than\n           noAuthentication.  A modification of the corresponding\n           instance of rip2IfConfAuthType does not modify\n           the rip2IfConfAuthKey value.  If a string shorter\n           than 16 octets is supplied, it will be left-\n           justified and padded to 16 octets, on the right,\n           with nulls (0x00).\n\n           Reading this object always results in an  OCTET\n           STRING of length zero; authentication may not\n           be bypassed by reading the MIB object.')
rip2IfConfSend = MibTableColumn((1, 3, 6, 1, 2, 1, 23, 3, 1, 5), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6,))).clone(namedValues=NamedValues(("doNotSend", 1), ("ripVersion1", 2), ("rip1Compatible", 3), ("ripVersion2", 4), ("ripV1Demand", 5), ("ripV2Demand", 6),)).clone('rip1Compatible')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: rip2IfConfSend.setDescription('What the router sends on this interface.\n           ripVersion1 implies sending RIP updates compliant\n           with  RFC  1058.   rip1Compatible implies\n           broadcasting RIP-2 updates using RFC 1058 route\n           subsumption rules.  ripVersion2 implies\n           multicasting RIP-2 updates.  ripV1Demand indicates\n           the use of Demand RIP on a WAN interface under RIP\n           Version 1 rules.  ripV2Demand indicates the use of\n           Demand RIP on a WAN interface under Version 2 rules.')
rip2IfConfReceive = MibTableColumn((1, 3, 6, 1, 2, 1, 23, 3, 1, 6), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("rip1", 1), ("rip2", 2), ("rip1OrRip2", 3), ("doNotRecieve", 4),)).clone('rip1OrRip2')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: rip2IfConfReceive.setDescription('This indicates which version of RIP updates\n           are to be accepted.  Note that rip2 and\n           rip1OrRip2 implies reception of multicast\n           packets.')
rip2IfConfDefaultMetric = MibTableColumn((1, 3, 6, 1, 2, 1, 23, 3, 1, 7), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,15))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: rip2IfConfDefaultMetric.setDescription('This variable indicates the metric that is to\n           be used for the default route entry in RIP updates\n           originated on this interface.  A value of zero\n           indicates that no default route should be\n           originated; in this case, a default route via\n           another router may be propagated.')
rip2IfConfStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 23, 3, 1, 8), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: rip2IfConfStatus.setDescription('Writing invalid has  the  effect  of  deleting\n           this interface.')
rip2IfConfSrcAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 23, 3, 1, 9), IpAddress()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: rip2IfConfSrcAddress.setDescription('The IP Address this system will use as a source\n            address on this interface.  If it is a numbered\n            interface, this MUST be the same value as\n            rip2IfConfAddress.  On unnumbered interfaces,\n            it must be the value of rip2IfConfAddress for\n            some interface on the system.')
rip2PeerTable = MibTable((1, 3, 6, 1, 2, 1, 23, 4), )
if mibBuilder.loadTexts: rip2PeerTable.setDescription('A list of RIP Peers.')
rip2PeerEntry = MibTableRow((1, 3, 6, 1, 2, 1, 23, 4, 1), ).setIndexNames((0, "RIPv2-MIB", "rip2PeerAddress"), (0, "RIPv2-MIB", "rip2PeerDomain"))
if mibBuilder.loadTexts: rip2PeerEntry.setDescription('Information regarding a single routing peer.')
rip2PeerAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 23, 4, 1, 1), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rip2PeerAddress.setDescription('The IP Address that the peer is using as its source\n            address.  Note that on an unnumbered link, this may\n            not be a member of any subnet on the system.')
rip2PeerDomain = MibTableColumn((1, 3, 6, 1, 2, 1, 23, 4, 1, 2), RouteTag()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rip2PeerDomain.setDescription('The value in the Routing Domain field  in  RIP\n           packets received from the peer.  As domain suuport\n           is deprecated, this must be zero.')
rip2PeerLastUpdate = MibTableColumn((1, 3, 6, 1, 2, 1, 23, 4, 1, 3), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rip2PeerLastUpdate.setDescription('The value of sysUpTime when the most recent\n           RIP update was received from this system.')
rip2PeerVersion = MibTableColumn((1, 3, 6, 1, 2, 1, 23, 4, 1, 4), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,255))).setMaxAccess("readonly")
if mibBuilder.loadTexts: rip2PeerVersion.setDescription('The RIP version number in the header of the\n           last RIP packet received.')
rip2PeerRcvBadPackets = MibTableColumn((1, 3, 6, 1, 2, 1, 23, 4, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rip2PeerRcvBadPackets.setDescription('The number of RIP response packets from this\n           peer discarded as invalid.')
rip2PeerRcvBadRoutes = MibTableColumn((1, 3, 6, 1, 2, 1, 23, 4, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rip2PeerRcvBadRoutes.setDescription('The number of routes from this peer that were\n           ignored because the entry format was invalid.')
rip2Conformance = MibIdentifier((1, 3, 6, 1, 2, 1, 23, 5))
rip2Groups = MibIdentifier((1, 3, 6, 1, 2, 1, 23, 5, 1))
rip2Compliances = MibIdentifier((1, 3, 6, 1, 2, 1, 23, 5, 2))
rip2Compliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 23, 5, 2, 1)).setObjects(*(("RIPv2-MIB", "rip2GlobalGroup"), ("RIPv2-MIB", "rip2IfStatGroup"), ("RIPv2-MIB", "rip2IfConfGroup"), ("RIPv2-MIB", "rip2PeerGroup"),))
if mibBuilder.loadTexts: rip2Compliance.setDescription('The compliance statement ')
rip2GlobalGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 23, 5, 1, 1)).setObjects(*(("RIPv2-MIB", "rip2GlobalRouteChanges"), ("RIPv2-MIB", "rip2GlobalQueries"),))
if mibBuilder.loadTexts: rip2GlobalGroup.setDescription('This group defines global controls for RIP-II systems.')
rip2IfStatGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 23, 5, 1, 2)).setObjects(*(("RIPv2-MIB", "rip2IfStatAddress"), ("RIPv2-MIB", "rip2IfStatRcvBadPackets"), ("RIPv2-MIB", "rip2IfStatRcvBadRoutes"), ("RIPv2-MIB", "rip2IfStatSentUpdates"), ("RIPv2-MIB", "rip2IfStatStatus"),))
if mibBuilder.loadTexts: rip2IfStatGroup.setDescription('This group defines interface statistics for RIP-II systems.')
rip2IfConfGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 23, 5, 1, 3)).setObjects(*(("RIPv2-MIB", "rip2IfConfAddress"), ("RIPv2-MIB", "rip2IfConfAuthType"), ("RIPv2-MIB", "rip2IfConfAuthKey"), ("RIPv2-MIB", "rip2IfConfSend"), ("RIPv2-MIB", "rip2IfConfReceive"), ("RIPv2-MIB", "rip2IfConfDefaultMetric"), ("RIPv2-MIB", "rip2IfConfStatus"), ("RIPv2-MIB", "rip2IfConfSrcAddress"),))
if mibBuilder.loadTexts: rip2IfConfGroup.setDescription('This group defines interface configuration for RIP-II systems.')
rip2PeerGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 23, 5, 1, 4)).setObjects(*(("RIPv2-MIB", "rip2PeerAddress"), ("RIPv2-MIB", "rip2PeerDomain"), ("RIPv2-MIB", "rip2PeerLastUpdate"), ("RIPv2-MIB", "rip2PeerVersion"), ("RIPv2-MIB", "rip2PeerRcvBadPackets"), ("RIPv2-MIB", "rip2PeerRcvBadRoutes"),))
if mibBuilder.loadTexts: rip2PeerGroup.setDescription('This group defines peer information for RIP-II systems.')
mibBuilder.exportSymbols("RIPv2-MIB", rip2IfStatSentUpdates=rip2IfStatSentUpdates, RouteTag=RouteTag, rip2IfConfAuthType=rip2IfConfAuthType, rip2IfStatStatus=rip2IfStatStatus, rip2IfStatEntry=rip2IfStatEntry, rip2PeerDomain=rip2PeerDomain, rip2IfStatRcvBadPackets=rip2IfStatRcvBadPackets, rip2Globals=rip2Globals, rip2IfConfStatus=rip2IfConfStatus, rip2IfConfAddress=rip2IfConfAddress, rip2IfStatAddress=rip2IfStatAddress, rip2PeerAddress=rip2PeerAddress, rip2PeerLastUpdate=rip2PeerLastUpdate, rip2PeerTable=rip2PeerTable, rip2PeerRcvBadRoutes=rip2PeerRcvBadRoutes, rip2PeerGroup=rip2PeerGroup, rip2IfConfEntry=rip2IfConfEntry, rip2PeerEntry=rip2PeerEntry, rip2Compliance=rip2Compliance, rip2IfConfSend=rip2IfConfSend, rip2IfConfDomain=rip2IfConfDomain, rip2IfStatGroup=rip2IfStatGroup, rip2PeerRcvBadPackets=rip2PeerRcvBadPackets, rip2PeerVersion=rip2PeerVersion, rip2Groups=rip2Groups, rip2IfConfAuthKey=rip2IfConfAuthKey, rip2GlobalQueries=rip2GlobalQueries, rip2IfConfSrcAddress=rip2IfConfSrcAddress, rip2IfStatRcvBadRoutes=rip2IfStatRcvBadRoutes, rip2IfConfReceive=rip2IfConfReceive, rip2=rip2, rip2IfStatTable=rip2IfStatTable, rip2GlobalGroup=rip2GlobalGroup, rip2IfConfTable=rip2IfConfTable, PYSNMP_MODULE_ID=rip2, rip2Compliances=rip2Compliances, rip2IfConfDefaultMetric=rip2IfConfDefaultMetric, rip2IfConfGroup=rip2IfConfGroup, rip2GlobalRouteChanges=rip2GlobalRouteChanges, rip2Conformance=rip2Conformance)
