#
# PySNMP MIB module MIOX25-MIB (http://pysnmp.sf.net)
# ASN.1 source file:///home/tt/fixed_mibs/MIOX25-MIB
# Produced by pysmi-0.0.2 at Mon Jun 22 22:13:13 2015
# On host cray platform Linux version 2.6.37.6-smp by user tt
# Using Python version 2.7.2 (default, Apr  2 2012, 20:32:47) 
#
( Integer, ObjectIdentifier, OctetString, ) = mibBuilder.importSymbols("ASN1", "Integer", "ObjectIdentifier", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsUnion, SingleValueConstraint, ConstraintsIntersection, ValueSizeConstraint, ValueRangeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsUnion", "SingleValueConstraint", "ConstraintsIntersection", "ValueSizeConstraint", "ValueRangeConstraint")
( ifIndex, ) = mibBuilder.importSymbols("IF-MIB", "ifIndex")
( PositiveInteger, ) = mibBuilder.importSymbols("RFC1253-MIB", "PositiveInteger")
( InstancePointer, ) = mibBuilder.importSymbols("RFC1316-MIB", "InstancePointer")
( X121Address, ) = mibBuilder.importSymbols("RFC1382-MIB", "X121Address")
( Integer32, MibScalar, MibTable, MibTableRow, MibTableColumn, transmission, TimeTicks, Counter64, NotificationType, iso, Gauge32, MibIdentifier, Bits, Counter32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Integer32", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "transmission", "TimeTicks", "Counter64", "NotificationType", "iso", "Gauge32", "MibIdentifier", "Bits", "Counter32")
( DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString")
miox = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 38))
mioxPle = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 38, 1))
mioxPeer = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 38, 2))
mioxPleTable = MibTable((1, 3, 6, 1, 2, 1, 10, 38, 1, 1), )
if mibBuilder.loadTexts: mioxPleTable.setDescription('This table contains information relative to\n                          an interface to an X.25 Packet Level Entity\n                          (PLE).')
mioxPleEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 38, 1, 1, 1), ).setIndexNames((0, "MIOX25-MIB", "ifIndex"))
if mibBuilder.loadTexts: mioxPleEntry.setDescription('These objects manage the encapsulation of\n                          other protocols within X.25.')
mioxPleMaxCircuits = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 1, 1, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,2147483647))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mioxPleMaxCircuits.setDescription('The maximum number of X.25 circuits that\n                          can be open at one time for this interface.\n                          A value of zero indicates the interface will\n                          not allow any additional circuits (as it may\n                          soon be shutdown).  A value of 2147483647\n                          allows an unlimited number of circuits.')
mioxPleRefusedConnections = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 1, 1, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mioxPleRefusedConnections.setDescription('The number of X.25 calls from a remote\n                          systems to this system that were cleared by\n                          this system.  The interface instance should\n                          identify the X.25 interface the call came in\n                          on.')
mioxPleEnAddrToX121LkupFlrs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 1, 1, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mioxPleEnAddrToX121LkupFlrs.setDescription('The number of times a translation from an\n                          Encapsulated Address to an X.121 address\n                          failed to find a corresponding X.121\n                          address.  Encapsulated addresses can be\n                          looked up in the mioxPeerTable or translated\n                          via an algorithm as for the DDN.  Addresses\n                          that are successfully recognized do not\n                          increment this counter.  Addresses that are\n                          not recognized (reflecting an abnormal\n                          packet delivery condition) increment this\n                          counter.\n\n                          If an address translation fails, it may be\n                          difficult to determine which PLE entry\n                          should count the failure.  In such cases the\n                          first likely entry in this table should be\n                          selected.  Agents should record the failure\n                          even if they are unsure which PLE should be\n                          associated with the failure.')
mioxPleLastFailedEnAddr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 1, 1, 1, 4), OctetString().subtype(subtypeSpec=ValueSizeConstraint(2,128))).setMaxAccess("readonly")
if mibBuilder.loadTexts: mioxPleLastFailedEnAddr.setDescription('The last Encapsulated address that failed\n                          to find a corresponding X.121 address and\n                          caused mioxPleEnAddrToX121LkupFlrs to be\n                          incremented.  The first octet of this object\n                          contains the encapsulation type, the\n                          remaining octets contain the address of that\n                          type that failed.  Thus for an IP address,\n                          the length will be five octets, the first\n                          octet will contain 204 (hex CC), and the\n                          last four octets will contain the IP\n                          address.  For a snap encapsulation, the\n                          first byte would be 128 (hex 80) and the\n                          rest of the octet string would have the snap\n                          header.')
mioxPleEnAddrToX121LkupFlrTime = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 1, 1, 1, 5), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mioxPleEnAddrToX121LkupFlrTime.setDescription('The most recent value of sysUpTime when the\n                          translation from an Encapsulated Address to\n                          X.121 address failed to find a corresponding\n                          X.121 address.')
mioxPleX121ToEnAddrLkupFlrs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 1, 1, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mioxPleX121ToEnAddrLkupFlrs.setDescription('The number of times the translation from an\n                          X.121 address to an Encapsulated Address\n                          failed to find a corresponding Encapsulated\n                          Address.  Addresses successfully recognized\n                          by an algorithm do not increment this\n                          counter.  This counter reflects the number\n                          of times call acceptance encountered the\n                          abnormal condition of not recognizing the\n                          peer.')
mioxPleLastFailedX121Address = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 1, 1, 1, 7), X121Address()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mioxPleLastFailedX121Address.setDescription('The last X.121 address that caused\n                          mioxPleX121ToEnAddrLkupFlrs to increase.')
mioxPleX121ToEnAddrLkupFlrTime = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 1, 1, 1, 8), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mioxPleX121ToEnAddrLkupFlrTime.setDescription('The most recent value of sysUpTime when the\n                          translation from an X.121 address to an\n                          Encapsulated Address failed to find a\n                          corresponding Encapsulated Address.')
mioxPleQbitFailures = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 1, 1, 1, 9), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mioxPleQbitFailures.setDescription('The number of times a connection was closed\n                          because of a Q-bit failure.')
mioxPleQbitFailureRemoteAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 1, 1, 1, 10), X121Address()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mioxPleQbitFailureRemoteAddress.setDescription('The remote address of the most recent\n                          (last) connection that was closed because of\n                          a Q-bit failure.')
mioxPleQbitFailureTime = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 1, 1, 1, 11), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mioxPleQbitFailureTime.setDescription('The most recent value of sysUpTime when a\n                          connection was closed because of a Q-bit\n                          failure.  This will also be the last time\n                          that mioxPleQbitFailures was incremented.')
mioxPleMinimumOpenTimer = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 1, 1, 1, 12), PositiveInteger()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mioxPleMinimumOpenTimer.setDescription('The minimum time in milliseconds this\n                          interface will keep a connection open before\n                          allowing it to be closed.  A value of zero\n                          indicates no timer.')
mioxPleInactivityTimer = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 1, 1, 1, 13), PositiveInteger().clone(10000)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mioxPleInactivityTimer.setDescription('The amount of time time in milliseconds\n                          this interface will keep an idle connection\n                          open before closing it.  A value of\n                          2147483647 indicates no timer.')
mioxPleHoldDownTimer = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 1, 1, 1, 14), PositiveInteger()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mioxPleHoldDownTimer.setDescription('The hold down timer in milliseconds.  This\n                          is the minimum amount of time to wait before\n                          trying another call to a host that was\n                          previously unsuccessful.  A value of\n                          2147483647 indicates the host will not be\n                          retried.')
mioxPleCollisionRetryTimer = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 1, 1, 1, 15), PositiveInteger()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mioxPleCollisionRetryTimer.setDescription('The Collision Retry Timer in milliseconds.\n                          The time to delay between call attempts when\n                          the maximum number of circuits is exceeded\n                          in a call attempt.')
mioxPleDefaultPeerId = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 1, 1, 1, 16), InstancePointer()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mioxPleDefaultPeerId.setDescription("This identifies the instance of the index\n                          in the mioxPeerTable for the default\n                          parameters to use with this interface.\n\n                          The entry identified by this object may have\n                          a zero length Encapsulation address and a\n                          zero length X.121 address.\n\n                          These default parameters are used with\n                          connections to hosts that do not have\n                          entries in the mioxPeerTable.  Such\n                          connections occur when using ddn-x25 IP-X.25\n                          address mapping or when accepting\n                          connections from other hosts not in the\n                          mioxPeerTable.\n\n                          The mioxPeerEncTable entry with the same\n                          index as the mioxPeerTable entry specifies\n                          the call encapsulation types this PLE will\n                          accept for peers not in the mioxPeerTable.\n                          If the mioxPeerEncTable doesn't contain any\n                          entries, this PLE will not accept calls from\n                          entries not in the mioxPeerTable.")
mioxPeerTable = MibTable((1, 3, 6, 1, 2, 1, 10, 38, 2, 1), )
if mibBuilder.loadTexts: mioxPeerTable.setDescription('This table contains information about the\n                          possible peers this machine may exchange\n                          packets with.')
mioxPeerEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 38, 2, 1, 1), ).setIndexNames((0, "MIOX25-MIB", "mioxPeerIndex"))
if mibBuilder.loadTexts: mioxPeerEntry.setDescription('Per peer information.')
mioxPeerIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 2, 1, 1, 1), PositiveInteger()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mioxPeerIndex.setDescription('An index value that distinguished one entry\n                          from another.  This index is independent of\n                          any other index.')
mioxPeerStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 2, 1, 1, 2), Integer32().subtype(subtypeSpec=SingleValueConstraint(1, 2, 3, 4, 5, 6,)).clone(namedValues=NamedValues(("valid", 1), ("createRequest", 2), ("underCreation", 3), ("invalid", 4), ("clearCall", 5), ("makeCall", 6),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mioxPeerStatus.setDescription("This reports the status of a peer entry.\n                          A value of valid indicates a normal entry\n                          that is in use by the agent.  A value of\n                          underCreation indicates a newly created\n                          entry which isn't yet in use because the\n                          creating management station is still setting\n                          values.\n\n                          The value of invalid indicates the entry is\n                          no longer in use and the agent is free to\n                          delete the entry at any time.  A management\n                          station is also free to use an entry in the\n                          invalid state.\n\n                          Entries are created by setting a value of\n                          createRequest.  Only non-existent or invalid\n                          entries can be set to createRequest.  Upon\n                          receiving a valid createRequest, the agent\n                          will create an entry in the underCreation\n                          state.  This object can not be set to a\n                          value of underCreation directly, entries can\n                          only be created by setting a value of\n                          createRequest.  Entries that exist in other\n                          than the invalid state can not be set to\n                          createRequest.\n\n                          Entries with a value of underCreation are\n                          not used by the system and the management\n                          station can change the values of other\n                          objects in the table entry.  Management\n                          stations should also remember to configure\n                          values in the mioxPeerEncTable with the same\n                          peer index value as this peer entry.\n\n                          An entry in the underCreation state can be\n                          set to valid or invalid.  Entries in the\n                          underCreation state will stay in that state\n                          until 1) the agent times them out, 2) they\n                          are set to valid, 3) they are set to\n                          invalid.  If an agent notices an entry has\n                          been in the underCreation state for an\n                          abnormally long time, it may decide the\n                          management station has failed and invalidate\n                          the entry.  A prudent agent will understand\n                          that the management station may need to wait\n                          for human input and will allow for that\n                          possibility in its determination of this\n                          abnormally long period.\n\n                          Once a management station has completed all\n                          fields of an entry, it will set a value of\n                          valid.  This causes the entry to be\n                          activated.\n\n                          Entries in the valid state may also be set\n                          to makeCall or clearCall to make or clear\n                          X.25 calls to the peer.  After such a set\n                          request the entry will still be in the valid\n                          state.  Setting a value of makeCall causes\n                          the agent to initiate an X.25 call request\n                          to the peer specified by the entry.  Setting\n                          a value of clearCall causes the agent to\n                          initiate clearing one X.25 call present to\n                          the peer.  Each set request will initiate\n                          another call or clear request (up to the\n                          maximum allowed); this means that management\n                          stations that fail to get a response to a\n                          set request should query to see if a call\n                          was in fact placed or cleared before\n                          retrying the request.  Entries not in the\n                          valid state can not be set to makeCall or\n                          clearCall.\n\n                          The values of makeCall and clearCall provide\n                          for circuit control on devices which perform\n                          Ethernet Bridging using static circuit\n                          assignment without address recognition;\n                          other devices which dynamically place calls\n                          based on destination addresses may reject\n                          such requests.\n\n                          An agent that (re)creates a new entry\n                          because of a set with createRequest, should\n                          also (re)create a mioxPeerEncTable entry\n                          with a mioxPeerEncIndex of 1, and a\n                          mioxPeerEncType of 204 (hex CC).")
mioxPeerMaxCircuits = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 2, 1, 1, 3), PositiveInteger().clone(1)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mioxPeerMaxCircuits.setDescription('The maximum number of X.25 circuits allowed\n                          to this peer.')
mioxPeerIfIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 2, 1, 1, 4), PositiveInteger().clone(1)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mioxPeerIfIndex.setDescription('The value of the ifIndex object for the\n                          interface to X.25 to use to call the peer.')
mioxPeerConnectSeconds = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 2, 1, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mioxPeerConnectSeconds.setDescription('The number of seconds a call to this peer\n                          was active.  This counter will be\n                          incremented by one for every second a\n                          connection to a peer was open.  If two calls\n                          are open at the same time, one second of\n                          elapsed real time will results in two\n                          seconds of connect time.')
mioxPeerX25CallParamId = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 2, 1, 1, 6), InstancePointer()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mioxPeerX25CallParamId.setDescription('The instance of the index object in the\n                          x25CallParmTable from RFC 1382 for the X.25\n                          call parameters used to communicate with the\n                          remote host.  The well known value {0 0}\n                          indicates no call parameters specified.')
mioxPeerEnAddr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 2, 1, 1, 7), OctetString().subtype(subtypeSpec=ValueSizeConstraint(0,128)).clone(hexValue="")).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mioxPeerEnAddr.setDescription('The Encapsulation address of the remote\n                          host mapped by this table entry.  A length\n                          of zero indicates the remote IP address is\n                          unknown or unspecified for use as a PLE\n                          default.\n\n                          The first octet of this object contains the\n                          encapsulation type, the remaining octets\n                          contain an address of that type.  Thus for\n                          an IP address, the length will be five\n                          octets, the first octet will contain 204\n                          (hex CC), and the last four octets will\n                          contain the IP address.  For a snap\n                          encapsulation, the first byte would be 128\n                          (hex 80) and the rest of the octet string\n                          would have the snap header.')
mioxPeerX121Address = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 2, 1, 1, 8), X121Address().clone(hexValue="")).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mioxPeerX121Address.setDescription('The X.25 address of the remote host mapped\n                          by this table entry.  A zero length string\n                          indicates the X.25 address is unspecified\n                          for use as the PLE default.')
mioxPeerX25CircuitId = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 2, 1, 1, 9), InstancePointer()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mioxPeerX25CircuitId.setDescription('This object identifies the instance of the\n                          index for the X.25 circuit open to the peer\n                          mapped by this table entry.  The well known\n                          value {0 0} indicates no connection\n                          currently active.  For multiple connections,\n                          this identifies the index of a multiplexing\n                          table entry for the connections.  This can\n                          only be written to configure use of PVCs\n                          which means the identified circuit table\n                          entry for a write must be a PVC.')
mioxPeerDescr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 2, 1, 1, 10), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,255)).clone(hexValue="")).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mioxPeerDescr.setDescription('This object returns any identification\n                          information about the peer.  An agent may\n                          supply the comment information found in the\n                          configuration file entry for this peer.  A\n                          zero length string indicates no information\n                          available.')
mioxPeerEncTable = MibTable((1, 3, 6, 1, 2, 1, 10, 38, 2, 2), )
if mibBuilder.loadTexts: mioxPeerEncTable.setDescription("This table contains the list of\n                          encapsulations used to communicate with a\n                          peer.  This table has two indexes, the first\n                          identifies the peer, the second\n                          distinguishes encapsulation types.\n\n                          The first index identifies the corresponding\n                          entry in the mioxPeerTable.  The second\n                          index gives the priority of the different\n                          encapsulations.\n\n                          The encapsulation types are ordered in\n                          priority order.  For calling a peer, the\n                          first entry (mioxPeerEncIndex of 1) is tried\n                          first.  If the call doesn't succeed because\n                          the remote host clears the call due to\n                          incompatible call user data, the next entry\n                          in the list is tried.  Each entry is tried\n                          until the list is exhausted.\n\n                          For answering a call, the encapsulation type\n                          requested by the peer must be found the list\n                          or the call will be refused.  If there are\n                          no entries in this table for a peer, all\n                          call requests from the peer will be refused.\n\n                          Objects in this table can only be set when\n                          the mioxPeerStatus object with the same\n                          index has a value of underCreation.  When\n                          that status object is set to invalid and\n                          deleted, the entry in this table with that\n                          peer index must also be deleted.")
mioxPeerEncEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 38, 2, 2, 1), ).setIndexNames((0, "MIOX25-MIB", "mioxPeerIndex"), (0, "MIOX25-MIB", "mioxPeerEncIndex"))
if mibBuilder.loadTexts: mioxPeerEncEntry.setDescription('Per connection information.')
mioxPeerEncIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 2, 2, 1, 1), PositiveInteger()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mioxPeerEncIndex.setDescription('The second index in the table which\n                          distinguishes different encapsulation\n                          types.')
mioxPeerEncType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 2, 2, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,256))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mioxPeerEncType.setDescription('The value of the encapsulation type.  For\n                          IP encapsulation this will have a value of\n                          204 (hex CC).  For SNAP encapsulated\n                          packets, this will have a value of 128 (hex\n                          80).  For CLNP, ISO 8473, this will have a\n                          value of 129 (hex 81).  For ES-ES, ISO 9542,\n                          this will have a value of 130 (hex 82).  A\n                          value of 197 (hex C5) identifies the Blacker\n                          X.25 encapsulation.  A value of 0,\n                          identifies the Null encapsulation.\n\n                          This value can only be written when the\n                          mioxPeerStatus object with the same\n                          mioxPeerIndex has a value of underCreation.\n                          Setting this object to a value of 256\n                          deletes the entry.  When deleting an entry,\n                          all other entries in the mioxPeerEncTable\n                          with the same mioxPeerIndex and with an\n                          mioxPeerEncIndex higher then the deleted\n                          entry, will all have their mioxPeerEncIndex\n                          values decremented by one.')
mibBuilder.exportSymbols("MIOX25-MIB", mioxPleX121ToEnAddrLkupFlrs=mioxPleX121ToEnAddrLkupFlrs, mioxPeerX25CallParamId=mioxPeerX25CallParamId, mioxPeerDescr=mioxPeerDescr, mioxPeerIfIndex=mioxPeerIfIndex, mioxPeerEncEntry=mioxPeerEncEntry, mioxPle=mioxPle, mioxPeerMaxCircuits=mioxPeerMaxCircuits, mioxPeerStatus=mioxPeerStatus, mioxPleMaxCircuits=mioxPleMaxCircuits, mioxPeerTable=mioxPeerTable, mioxPleLastFailedX121Address=mioxPleLastFailedX121Address, mioxPleMinimumOpenTimer=mioxPleMinimumOpenTimer, mioxPeerEncType=mioxPeerEncType, mioxPleQbitFailures=mioxPleQbitFailures, mioxPleEnAddrToX121LkupFlrTime=mioxPleEnAddrToX121LkupFlrTime, mioxPeer=mioxPeer, mioxPeerEntry=mioxPeerEntry, mioxPleDefaultPeerId=mioxPleDefaultPeerId, mioxPeerEnAddr=mioxPeerEnAddr, mioxPeerX121Address=mioxPeerX121Address, mioxPleQbitFailureTime=mioxPleQbitFailureTime, mioxPeerConnectSeconds=mioxPeerConnectSeconds, mioxPeerEncTable=mioxPeerEncTable, mioxPleLastFailedEnAddr=mioxPleLastFailedEnAddr, mioxPleEntry=mioxPleEntry, mioxPeerIndex=mioxPeerIndex, mioxPleCollisionRetryTimer=mioxPleCollisionRetryTimer, mioxPleHoldDownTimer=mioxPleHoldDownTimer, mioxPleX121ToEnAddrLkupFlrTime=mioxPleX121ToEnAddrLkupFlrTime, miox=miox, mioxPleTable=mioxPleTable, mioxPleRefusedConnections=mioxPleRefusedConnections, mioxPleQbitFailureRemoteAddress=mioxPleQbitFailureRemoteAddress, mioxPeerEncIndex=mioxPeerEncIndex, mioxPleEnAddrToX121LkupFlrs=mioxPleEnAddrToX121LkupFlrs, mioxPeerX25CircuitId=mioxPeerX25CircuitId, mioxPleInactivityTimer=mioxPleInactivityTimer)
