#
# PySNMP MIB module SIP-UA-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/SIP-UA-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:28:20 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( OctetString, ObjectIdentifier, Integer, ) = mibBuilder.importSymbols("ASN1", "OctetString", "ObjectIdentifier", "Integer")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsUnion, ValueSizeConstraint, SingleValueConstraint, ValueRangeConstraint, ConstraintsIntersection, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsUnion", "ValueSizeConstraint", "SingleValueConstraint", "ValueRangeConstraint", "ConstraintsIntersection")
( applIndex, ) = mibBuilder.importSymbols("NETWORK-SERVICES-MIB", "applIndex")
( sipMIB, ) = mibBuilder.importSymbols("SIP-MIB-SMI", "sipMIB")
( ModuleCompliance, NotificationGroup, ObjectGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "NotificationGroup", "ObjectGroup")
( MibIdentifier, Bits, MibScalar, MibTable, MibTableRow, MibTableColumn, Integer32, ObjectIdentity, Counter64, iso, ModuleIdentity, NotificationType, Gauge32, IpAddress, TimeTicks, Unsigned32, Counter32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "MibIdentifier", "Bits", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Integer32", "ObjectIdentity", "Counter64", "iso", "ModuleIdentity", "NotificationType", "Gauge32", "IpAddress", "TimeTicks", "Unsigned32", "Counter32")
( DisplayString, TextualConvention, ) = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString", "TextualConvention")
sipUAMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 9998, 3))
if mibBuilder.loadTexts: sipUAMIB.setLastUpdated('200007080000Z')
if mibBuilder.loadTexts: sipUAMIB.setOrganization('IETF SIP Working Group, SIP MIB Team')
if mibBuilder.loadTexts: sipUAMIB.setContactInfo('SIP MIB Team email: sip-mib@egroups.com \n\n                 Co-editor  Kevin Lingle \n                            Cisco Systems, Inc. \n                 postal:    7025 Kit Creek Road \n                            P.O. Box 14987 \n                            Research Triangle Park, NC 27709 \n                            USA \n                 email:     klingle@cisco.com \n                 phone:     +1-919-392-2029 \n\n                 Co-editor  Joon Maeng \n                            VTEL Corporation \n                 postal:    108 Wild Basin Rd. \n                            Austin, TX 78746 \n                            USA \n                 email:     joon_maeng@vtel.com \n                 phone:     +1-512-437-4567 \n\n                 Co-editor  Dave Walker \n                            SS8 Networks, Inc. \n                 postal:    80 Hines Road \n                            Kanata, ON  K2K 2T8 \n                            Canada \n                 email:     drwalker@ss8networks.com \n                 phone:     +1 613 592 2100')
if mibBuilder.loadTexts: sipUAMIB.setDescription('Initial version of Session Initiation Protocol (SIP) \n                 User Agent (UA) MIB module. \n\n                 SIP is an application-layer signalling protocol for  \n                 creating, modifying and terminating multimedia  \n                 sessions with one or more participants. These sessions \n                 include Internet multimedia conferences and Internet  \n                 telephone calls.  SIP is defined in RFC 2543 (March  \n                 1999). \n\n                 A User Agent is an application that contains both a \n                 User Agent Client (UAC) and a User Agent Server (UAS). \n                 A UAC is an application that initiates a SIP request. \n                 A UAS is an application that contacts the user when a \n                 SIP request is received and that returns a response on \n                 behalf of the user.  The response accepts, rejects, or \n                 redirects the request.')
sipUACfg = MibIdentifier((1, 3, 6, 1, 2, 1, 9998, 3, 1))
sipUACfgTimer = MibIdentifier((1, 3, 6, 1, 2, 1, 9998, 3, 1, 1))
sipUACfgRetry = MibIdentifier((1, 3, 6, 1, 2, 1, 9998, 3, 1, 2))
sipUAStats = MibIdentifier((1, 3, 6, 1, 2, 1, 9998, 3, 2))
sipUAStatsRetry = MibIdentifier((1, 3, 6, 1, 2, 1, 9998, 3, 2, 1))
sipUACfgTimerTable = MibTable((1, 3, 6, 1, 2, 1, 9998, 3, 1, 1, 1), )
if mibBuilder.loadTexts: sipUACfgTimerTable.setDescription('This table contains timer configuration objects applicable  \n             to each SIP user agent in this system.  The instances of  \n             SIP entities are uniquely identified by applIndex.')
sipUACfgTimerEntry = MibTableRow((1, 3, 6, 1, 2, 1, 9998, 3, 1, 1, 1, 1), ).setIndexNames((0, "NETWORK-SERVICES-MIB", "applIndex"))
if mibBuilder.loadTexts: sipUACfgTimerEntry.setDescription('A row of timer configuration.')
sipUACfgTimerTrying = MibTableColumn((1, 3, 6, 1, 2, 1, 9998, 3, 1, 1, 1, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(100,1000))).setUnits('milliseconds').setMaxAccess("readwrite")
if mibBuilder.loadTexts: sipUACfgTimerTrying.setDescription('This object specifies the time a user agent will wait to \n             receive a provisional response to an INVITE before \n             resending the INVITE.')
sipUACfgTimerProv = MibTableColumn((1, 3, 6, 1, 2, 1, 9998, 3, 1, 1, 1, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(60000,300000))).setUnits('milliseconds').setMaxAccess("readwrite")
if mibBuilder.loadTexts: sipUACfgTimerProv.setDescription('This object specifies the time a user agent will wait to \n             receive a final response to an INVITE before canceling the \n             transaction.')
sipUACfgTimerAck = MibTableColumn((1, 3, 6, 1, 2, 1, 9998, 3, 1, 1, 1, 1, 3), Integer32().subtype(subtypeSpec=ValueRangeConstraint(100,1000))).setUnits('milliseconds').setMaxAccess("readwrite")
if mibBuilder.loadTexts: sipUACfgTimerAck.setDescription('This object specifies the time a user agent will wait to \n             receive an ACK confirmation indicating that a session is \n             established.')
sipUACfgTimerDisconnect = MibTableColumn((1, 3, 6, 1, 2, 1, 9998, 3, 1, 1, 1, 1, 4), Integer32().subtype(subtypeSpec=ValueRangeConstraint(100,1000))).setUnits('milliseconds').setMaxAccess("readwrite")
if mibBuilder.loadTexts: sipUACfgTimerDisconnect.setDescription('This object specifies the time a user agent will wait to \n             receive a BYE confirmation indicating that a session is \n             disconnected.')
sipUACfgTimerReRegister = MibTableColumn((1, 3, 6, 1, 2, 1, 9998, 3, 1, 1, 1, 1, 5), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647))).setUnits('seconds').setMaxAccess("readwrite")
if mibBuilder.loadTexts: sipUACfgTimerReRegister.setDescription('This object specifies how long the user agent wishes its \n             registrations to be valid.')
sipUACfgRetryTable = MibTable((1, 3, 6, 1, 2, 1, 9998, 3, 1, 2, 1), )
if mibBuilder.loadTexts: sipUACfgRetryTable.setDescription('This table contains retry configuration objects applicable  \n             to each SIP user agent in this system.  The instances of  \n             SIP entities are uniquely identified by applIndex.')
sipUACfgRetryEntry = MibTableRow((1, 3, 6, 1, 2, 1, 9998, 3, 1, 2, 1, 1), ).setIndexNames((0, "NETWORK-SERVICES-MIB", "applIndex"))
if mibBuilder.loadTexts: sipUACfgRetryEntry.setDescription('A row of retry configuration.')
sipUACfgRetryInvite = MibTableColumn((1, 3, 6, 1, 2, 1, 9998, 3, 1, 2, 1, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,10))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: sipUACfgRetryInvite.setDescription('This object will specify the number of times a user agent \n             will retry sending an INVITE request.')
sipUACfgRetryBye = MibTableColumn((1, 3, 6, 1, 2, 1, 9998, 3, 1, 2, 1, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,10))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: sipUACfgRetryBye.setDescription('This object will specify the number of times a user agent \n             will retry sending a BYE request.')
sipUACfgRetryCancel = MibTableColumn((1, 3, 6, 1, 2, 1, 9998, 3, 1, 2, 1, 1, 3), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,10))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: sipUACfgRetryCancel.setDescription('This object will specify the number of times a user agent \n             will retry sending a CANCEL request.')
sipUACfgRetryRegister = MibTableColumn((1, 3, 6, 1, 2, 1, 9998, 3, 1, 2, 1, 1, 4), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,10))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: sipUACfgRetryRegister.setDescription('This object will specify the number of times a user agent \n             will retry sending a REGISTER request.')
sipUACfgRetryResponse = MibTableColumn((1, 3, 6, 1, 2, 1, 9998, 3, 1, 2, 1, 1, 5), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,10))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: sipUACfgRetryResponse.setDescription('This object will specify the number of times a user agent \n             will retry sending a Response and expecting an ACK.')
sipUAStatsRetryTable = MibTable((1, 3, 6, 1, 2, 1, 9998, 3, 2, 1, 1), )
if mibBuilder.loadTexts: sipUAStatsRetryTable.setDescription('This table contains retry statistics objects applicable  \n             to each SIP user agent in this system.  The instances of  \n             SIP entities are uniquely identified by applIndex.')
sipUAStatsRetryEntry = MibTableRow((1, 3, 6, 1, 2, 1, 9998, 3, 2, 1, 1, 1), ).setIndexNames((0, "NETWORK-SERVICES-MIB", "applIndex"))
if mibBuilder.loadTexts: sipUAStatsRetryEntry.setDescription('A row of retry statistics.')
sipStatsRetryInvites = MibTableColumn((1, 3, 6, 1, 2, 1, 9998, 3, 2, 1, 1, 1, 1), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sipStatsRetryInvites.setDescription("This object reflects the total number of INVITE retries \n             that have been sent by the user agent.   If the number of \n             'first attempt' INVITES is of interest, subtract the value \n             of this object from sipStatsTrafficInviteOut.")
sipStatsRetryByes = MibTableColumn((1, 3, 6, 1, 2, 1, 9998, 3, 2, 1, 1, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sipStatsRetryByes.setDescription('This object reflects the total number of BYE retries that \n             have been sent by the user agent.')
sipStatsRetryCancels = MibTableColumn((1, 3, 6, 1, 2, 1, 9998, 3, 2, 1, 1, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sipStatsRetryCancels.setDescription('This object reflects the total number of CANCEL retries \n             that have been sent by the user agent.')
sipStatsRetryRegisters = MibTableColumn((1, 3, 6, 1, 2, 1, 9998, 3, 2, 1, 1, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sipStatsRetryRegisters.setDescription('This object reflects the total number of REGISTER retries \n             that have been sent by the user agent.')
sipStatsRetryResponses = MibTableColumn((1, 3, 6, 1, 2, 1, 9998, 3, 2, 1, 1, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sipStatsRetryResponses.setDescription('This object reflects the total number of Response (while \n             expecting an ACK) retries that have been sent by the user \n             agent.')
sipUAMIBNotif = MibIdentifier((1, 3, 6, 1, 2, 1, 9998, 3, 3))
sipUAMIBConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 9998, 3, 4))
sipUAMIBCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 9998, 3, 4, 1))
sipUAMIBGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 9998, 3, 4, 2))
sipUACompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 9998, 3, 4, 1, 1)).setObjects(*(("SIP-UA-MIB", "sipUAConfigGroup"), ("SIP-UA-MIB", "sipUAStatsGroup"),))
if mibBuilder.loadTexts: sipUACompliance.setDescription('The compliance statement for SIP entities.')
sipUAConfigGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 9998, 3, 4, 2, 1)).setObjects(*(("SIP-UA-MIB", "sipUACfgTimerTrying"), ("SIP-UA-MIB", "sipUACfgTimerProv"), ("SIP-UA-MIB", "sipUACfgTimerAck"), ("SIP-UA-MIB", "sipUACfgTimerDisconnect"), ("SIP-UA-MIB", "sipUACfgTimerReRegister"), ("SIP-UA-MIB", "sipUACfgRetryInvite"), ("SIP-UA-MIB", "sipUACfgRetryBye"), ("SIP-UA-MIB", "sipUACfgRetryCancel"), ("SIP-UA-MIB", "sipUACfgRetryRegister"), ("SIP-UA-MIB", "sipUACfgRetryResponse"),))
if mibBuilder.loadTexts: sipUAConfigGroup.setDescription('A collection of objects providing configuration for \n             SIP User Agents.')
sipUAStatsGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 9998, 3, 4, 2, 2)).setObjects(*(("SIP-UA-MIB", "sipStatsRetryInvites"), ("SIP-UA-MIB", "sipStatsRetryByes"), ("SIP-UA-MIB", "sipStatsRetryCancels"), ("SIP-UA-MIB", "sipStatsRetryRegisters"), ("SIP-UA-MIB", "sipStatsRetryResponses"),))
if mibBuilder.loadTexts: sipUAStatsGroup.setDescription('A collection of objects providing statistics for \n             SIP User Agents.')
mibBuilder.exportSymbols("SIP-UA-MIB", PYSNMP_MODULE_ID=sipUAMIB, sipStatsRetryInvites=sipStatsRetryInvites, sipUACfgTimerTrying=sipUACfgTimerTrying, sipUACfgTimerAck=sipUACfgTimerAck, sipUAMIBNotif=sipUAMIBNotif, sipUACfgRetryEntry=sipUACfgRetryEntry, sipUACfgRetryCancel=sipUACfgRetryCancel, sipUAMIBCompliances=sipUAMIBCompliances, sipUAMIBGroups=sipUAMIBGroups, sipStatsRetryRegisters=sipStatsRetryRegisters, sipUAStatsRetryTable=sipUAStatsRetryTable, sipUAMIB=sipUAMIB, sipUACfgTimerDisconnect=sipUACfgTimerDisconnect, sipStatsRetryCancels=sipStatsRetryCancels, sipStatsRetryResponses=sipStatsRetryResponses, sipUACfgRetryBye=sipUACfgRetryBye, sipUAStatsRetry=sipUAStatsRetry, sipUACfgTimer=sipUACfgTimer, sipUACfgTimerProv=sipUACfgTimerProv, sipUACfgTimerEntry=sipUACfgTimerEntry, sipUAStatsRetryEntry=sipUAStatsRetryEntry, sipUACfg=sipUACfg, sipUACfgRetryInvite=sipUACfgRetryInvite, sipUACfgRetryRegister=sipUACfgRetryRegister, sipUAStatsGroup=sipUAStatsGroup, sipUACfgTimerReRegister=sipUACfgTimerReRegister, sipUACfgRetryResponse=sipUACfgRetryResponse, sipUAConfigGroup=sipUAConfigGroup, sipUACfgRetryTable=sipUACfgRetryTable, sipUAMIBConformance=sipUAMIBConformance, sipUACompliance=sipUACompliance, sipUACfgRetry=sipUACfgRetry, sipStatsRetryByes=sipStatsRetryByes, sipUAStats=sipUAStats, sipUACfgTimerTable=sipUACfgTimerTable)
