#
# PySNMP MIB module FRSLD-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/FRSLD-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:13:42 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( ObjectIdentifier, Integer, OctetString, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "Integer", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( SingleValueConstraint, ConstraintsIntersection, ValueRangeConstraint, ConstraintsUnion, ValueSizeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "SingleValueConstraint", "ConstraintsIntersection", "ValueRangeConstraint", "ConstraintsUnion", "ValueSizeConstraint")
( DLCI, ) = mibBuilder.importSymbols("FRAME-RELAY-DTE-MIB", "DLCI")
( CounterBasedGauge64, ) = mibBuilder.importSymbols("HCNUM-TC", "CounterBasedGauge64")
( ifIndex, ) = mibBuilder.importSymbols("IF-MIB", "ifIndex")
( ModuleCompliance, NotificationGroup, ObjectGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "NotificationGroup", "ObjectGroup")
( ModuleIdentity, TimeTicks, Bits, Unsigned32, Counter32, mib_2, ObjectIdentity, MibScalar, MibTable, MibTableRow, MibTableColumn, Integer32, Gauge32, Counter64, IpAddress, iso, NotificationType, MibIdentifier, ) = mibBuilder.importSymbols("SNMPv2-SMI", "ModuleIdentity", "TimeTicks", "Bits", "Unsigned32", "Counter32", "mib-2", "ObjectIdentity", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Integer32", "Gauge32", "Counter64", "IpAddress", "iso", "NotificationType", "MibIdentifier")
( TextualConvention, RowStatus, DisplayString, TimeStamp, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "RowStatus", "DisplayString", "TimeStamp")
frsldMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 95)).setRevisions(("2002-01-03 00:00",))
if mibBuilder.loadTexts: frsldMIB.setLastUpdated('200201030000Z')
if mibBuilder.loadTexts: frsldMIB.setOrganization('IETF Frame Relay Service MIB Working Group')
if mibBuilder.loadTexts: frsldMIB.setContactInfo('IETF Frame Relay Service MIB (frnetmib) Working Group\n\n           WG Charter:    http://www.ietf.org/html.charters/\n                                 frnetmib-charter.html\n           WG-email:      frnetmib@sunroof.eng.sun.com\n           Subscribe:     frnetmib-request@sunroof.eng.sun.com\n           Email Archive: ftp://ftp.ietf.org/ietf-mail-archive/frnetmib\n\n           Chair:      Andy Malis\n                       Vivace Networks\n           Email:      Andy.Malis@vivacenetworks.com\n\n           WG editor:  Robert Steinberger\n                       Paradyne Networks and\n                       Fujitsu Network Communications\n           Email:      robert.steinberger@fnc.fujitsu.com\n\n           Co-author:  Orly Nicklass\n                       RAD Data Communications Ltd.\n           EMail:      Orly_n@rad.co.il')
if mibBuilder.loadTexts: frsldMIB.setDescription('The MIB module to describe generic objects for\n             FRF.13 Frame Relay Service Level Definitions.')
class FrsldTxRP(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12,))
    namedValues = NamedValues(("srcLocalRP", 1), ("ingTxLocalRP", 2), ("tpTxLocalRP", 3), ("eqiTxLocalRP", 4), ("eqoTxLocalRP", 5), ("otherTxLocalRP", 6), ("srcRemoteRP", 7), ("ingTxRemoteRP", 8), ("tpTxRemoteRP", 9), ("eqiTxRemoteRP", 10), ("eqoTxRemoteRP", 11), ("otherTxRemoteRP", 12),)

class FrsldRxRP(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12,))
    namedValues = NamedValues(("desLocalRP", 1), ("ingRxLocalRP", 2), ("tpRxLocalRP", 3), ("eqiRxLocalRP", 4), ("eqoRxLocalRP", 5), ("otherRxLocalRP", 6), ("desRemoteRP", 7), ("ingRxRemoteRP", 8), ("tpRxRemoteRP", 9), ("eqiRxRemoteRP", 10), ("eqoRxRemoteRP", 11), ("otherRxRemoteRP", 12),)

frsldObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 95, 1))
frsldCapabilities = MibIdentifier((1, 3, 6, 1, 2, 1, 95, 2))
frsldConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 95, 3))
frsldPvcCtrlTable = MibTable((1, 3, 6, 1, 2, 1, 95, 1, 1), )
if mibBuilder.loadTexts: frsldPvcCtrlTable.setDescription('The Frame Relay Service Level Definitions\n             PVC control table.')
frsldPvcCtrlEntry = MibTableRow((1, 3, 6, 1, 2, 1, 95, 1, 1, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"), (0, "FRSLD-MIB", "frsldPvcCtrlDlci"), (0, "FRSLD-MIB", "frsldPvcCtrlTransmitRP"), (0, "FRSLD-MIB", "frsldPvcCtrlReceiveRP"))
if mibBuilder.loadTexts: frsldPvcCtrlEntry.setDescription('An entry in the Frame Relay Service Level\n             Definitions PVC control table.')
frsldPvcCtrlDlci = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 1, 1, 1), DLCI())
if mibBuilder.loadTexts: frsldPvcCtrlDlci.setDescription('The value of this object is equal to the DLCI\n             value for this PVC.')
frsldPvcCtrlTransmitRP = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 1, 1, 2), FrsldTxRP())
if mibBuilder.loadTexts: frsldPvcCtrlTransmitRP.setDescription('The reference point this PVC uses for calculation\n             of transmitter related statistics.  This object\n             together with frsldPvcCtrlReceiveRP define the\n             measurement domain.')
frsldPvcCtrlReceiveRP = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 1, 1, 3), FrsldRxRP())
if mibBuilder.loadTexts: frsldPvcCtrlReceiveRP.setDescription('The reference point this PVC uses for calculation\n             of receiver related statistics.  This object\n             together with frsldPvcCtrlTransmitRP define the\n             measurement domain.')
frsldPvcCtrlStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 1, 1, 4), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: frsldPvcCtrlStatus.setDescription('The status of the current row.  This object is\n             used to add, delete, and disable rows in this\n             table.  When the status changes to active(1) for the\n             first time, a row will also be added to the data\n             table below.  This row SHOULD not be removed until\n             the status is changed to deleted.\n\n             When this object is set to destroy(6), all associated\n             sample and data table rows will also be deleted.\n             When this object is changed from active(1) to any\n             other valid value, the defined purge behavior will\n             affect the data and sample tables.\n\n             The rows added to this table MUST have a valid\n             ifIndex and an ifType related to frame relay.  Further,\n             the reference points referred to by frsldPvcCtrlTransmitRP\n             and frsldPvcCtrlReceiveRP MUST be supported (see the\n             frsldRPCaps object).\n\n             If at any point the row is not in the active(1) state\n             and the DLCI no longer exists, the state SHOULD\n             report notReady(3).\n\n             The data in this table SHOULD persist through power\n             cycles.  The symantics of readiness for the rows still\n             applies.  This means that it is possible for a row to be\n             reprovisioned as notReady(3) if the underlying DLCI does\n             not persist.')
frsldPvcCtrlPacketFreq = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 1, 1, 5), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,3600)).clone(60)).setUnits('seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: frsldPvcCtrlPacketFreq.setDescription('The frequency in seconds between initiation of\n             specialized packets used to collect delay and / or\n             delivery information as supported by the device.\n             A value of zero indicates that no packets will\n             be sent.')
frsldPvcCtrlDelayFrSize = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 1, 1, 6), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,8188)).clone(128)).setUnits('octets').setMaxAccess("readcreate")
if mibBuilder.loadTexts: frsldPvcCtrlDelayFrSize.setDescription('The size of the payload in the frame used for\n             calculation of network delay.')
frsldPvcCtrlDelayType = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 1, 1, 7), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("oneWay", 1), ("roundTrip", 2),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: frsldPvcCtrlDelayType.setDescription('The type of delay measurement performed.')
frsldPvcCtrlDelayTimeOut = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 1, 1, 8), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,3600)).clone(60)).setUnits('seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: frsldPvcCtrlDelayTimeOut.setDescription('A delay frame will count as a missed poll if\n             it is not updated in the time specified by\n             frsldPvcCtrlDelayTimeOut.')
frsldPvcCtrlPurge = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 1, 1, 9), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,172800))).setUnits('seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: frsldPvcCtrlPurge.setDescription('This object defines the amount of time the device\n             will wait, after discovering that a DLCI does not exist,\n             the DLCI was deleted or the value of frsldPvcCtrlStatus\n             changes from active(1) to either notInService(2) or\n             notReady(3), prior to automatically purging the history\n             in the sample tables and resetting the data in the data\n             tables to all zeroes.  If frsldPvcCtrlStatus is manually\n             set to destroy(6), this object does not apply.')
frsldPvcCtrlDeleteOnPurge = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 1, 1, 10), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("none", 1), ("sampleContols", 2), ("all", 3),)).clone('all')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: frsldPvcCtrlDeleteOnPurge.setDescription('This object defines whether rows will\n             automatically be deleted from the tables\n             when the information is purged.\n\n             - A value of none(1) indicates that no rows\n               will deleted.  The last known values will\n               be preserved.\n             - A value of sampleControls(2) indicates\n               that all associated sample control rows\n               will be deleted.\n             - A value of all(3) indicates that all\n               associated rows SHOULD be deleted.')
frsldPvcCtrlLastPurgeTime = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 1, 1, 11), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcCtrlLastPurgeTime.setDescription('This object returns the value of sysUpTime\n             at the time the information was last purged.\n             This value SHOULD be set to the sysUpTime\n             upon setting frsldPvcCtrlStatus to active(1)\n             for the first time.  Each time a\n             discontinuity in the counters occurs, this\n             value MUST be set to the sysUpTime.\n\n             If frsldPvcCtrlStatus has never been active(1),\n             this object SHOULD return 0.\n\n             This object SHOULD be used as the discontinuity\n             timer for the counters in frsldPvcDataTable.')
frsldSmplCtrlTable = MibTable((1, 3, 6, 1, 2, 1, 95, 1, 2), )
if mibBuilder.loadTexts: frsldSmplCtrlTable.setDescription('The Frame Relay Service Level Definitions\n             sampling control table.')
frsldSmplCtrlEntry = MibTableRow((1, 3, 6, 1, 2, 1, 95, 1, 2, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"), (0, "FRSLD-MIB", "frsldPvcCtrlDlci"), (0, "FRSLD-MIB", "frsldPvcCtrlTransmitRP"), (0, "FRSLD-MIB", "frsldPvcCtrlReceiveRP"), (0, "FRSLD-MIB", "frsldSmplCtrlIdx"))
if mibBuilder.loadTexts: frsldSmplCtrlEntry.setDescription('An entry in the Frame Relay Service Level\n             Definitions sample control table.')
frsldSmplCtrlIdx = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 2, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,256)))
if mibBuilder.loadTexts: frsldSmplCtrlIdx.setDescription('The unique index for this row in the\n             sample control table.')
frsldSmplCtrlStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 2, 1, 2), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: frsldSmplCtrlStatus.setDescription('The status of the current row.  This object is\n             used to add, delete, and disable rows in this\n             table.  This row SHOULD NOT be removed until the\n             status is changed to destroy(6).  When the status\n             changes to active(1), the collection in the sample\n             tables below will be activated.\n\n             The rows added to this table MUST have a valid\n             ifIndex, an ifType related to frame relay,\n             frsldPvcCtrlDlci MUST exist for the specified\n             ifIndex and frsldPvcCtrlStatus MUST have a\n             value of active(1).\n\n             The value of frsldPvcCtrlStatus MUST be active(1)\n             to transition this object to active(1).  If\n             the value of frsldPvcCtrlStatus becomes anything\n             other than active(1) when the state of this object\n             is not active(1), this object SHOULD be set to\n             notReady(3).\n\n             The data in this table SHOULD persist through power\n             cycles.  The symantics of readiness for the rows still\n             applies.  This means that it is possible for a row to be\n             reprovisioned as notReady(3) if the underlying DLCI does\n             not persist.')
frsldSmplCtrlColPeriod = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 2, 1, 3), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647))).setUnits('seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: frsldSmplCtrlColPeriod.setDescription('The amount of time in seconds that defines a\n             period of collection for the statistics.\n             At the end of each period, the statistics will be\n             sampled and a row is added to the sample table.')
frsldSmplCtrlBuckets = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 2, 1, 4), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,65535)).clone(60)).setMaxAccess("readcreate")
if mibBuilder.loadTexts: frsldSmplCtrlBuckets.setDescription('The number of discrete buckets over which the\n             data statistics are sampled.\n\n             When this object is created or modified, the device\n             SHOULD attempt to set the frsldSmplCtrlBuckets-\n             Granted to a value as close as is possible\n             depending upon the implementation and the available\n             resources.')
frsldSmplCtrlBucketsGranted = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 2, 1, 5), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldSmplCtrlBucketsGranted.setDescription('The number of discrete buckets granted.  This\n             object will return 0 until frsldSmplCtrlStatus is\n             set to active(1).  At that time the buckets will be\n             allocated depending upon implementation and\n             available resources.')
frsldPvcDataTable = MibTable((1, 3, 6, 1, 2, 1, 95, 1, 3), )
if mibBuilder.loadTexts: frsldPvcDataTable.setDescription('The Frame Relay Service Level Definitions\n             data table.\n\n             This table contains accumulated values of the\n             collected data.  It is the table that should be\n             referenced by external polling mechanisms if\n             time based polling be desired.')
frsldPvcDataEntry = MibTableRow((1, 3, 6, 1, 2, 1, 95, 1, 3, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"), (0, "FRSLD-MIB", "frsldPvcCtrlDlci"), (0, "FRSLD-MIB", "frsldPvcCtrlTransmitRP"), (0, "FRSLD-MIB", "frsldPvcCtrlReceiveRP"))
if mibBuilder.loadTexts: frsldPvcDataEntry.setDescription('An entry in the Frame Relay Service Level\n             Definitions data table.')
frsldPvcDataMissedPolls = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 3, 1, 1), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcDataMissedPolls.setDescription('The total number of polls that have been determined\n             to be missed.  These polls are typically associated\n             with the calculation of delay but may also be\n             used for the calculation of other statistics.  If an\n             anticipated poll is not received in a reasonable\n             amount of time, it should be counted as missed.\n             The value used to determine the reasonable amount\n             of time is contained in frsldPvcCtrlDelayTimeOut.\n\n             Discontinuities in the value of this counter can\n             occur at re-initialization of the management system\n             and at other times as indicated by\n\n             frsldPvcCtrlLastPurgeTime.')
frsldPvcDataFrDeliveredC = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 3, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcDataFrDeliveredC.setDescription('The number of frames that were received at\n             frsldPvcCtrlReceiveRP and determined to have been\n             sent within CIR.\n\n             Discontinuities in the value of this counter can\n             occur at re-initialization of the management system\n             and at other times as indicated by\n             frsldPvcCtrlLastPurgeTime.')
frsldPvcDataFrDeliveredE = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 3, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcDataFrDeliveredE.setDescription('The number of frames that were received at\n             frsldPvcCtrlReceiveRP and determined to have been\n             sent in excess of the CIR.\n\n             Discontinuities in the value of this counter can\n             occur at re-initialization of the management system\n             and at other times as indicated by\n             frsldPvcCtrlLastPurgeTime.')
frsldPvcDataFrOfferedC = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 3, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcDataFrOfferedC.setDescription('The number of frames that were offered through\n             frsldPvcCtrlTransmitRP within CIR.\n\n             Discontinuities in the value of this counter can\n             occur at re-initialization of the management system\n             and at other times as indicated by\n\n             frsldPvcCtrlLastPurgeTime.')
frsldPvcDataFrOfferedE = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 3, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcDataFrOfferedE.setDescription('The number of frames that were offered through\n             frsldPvcCtrlTransmitRP in excess of the CIR.\n\n             Discontinuities in the value of this counter can\n             occur at re-initialization of the management system\n             and at other times as indicated by\n             frsldPvcCtrlLastPurgeTime.')
frsldPvcDataDataDeliveredC = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 3, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcDataDataDeliveredC.setDescription('The number of octets that were received at\n             frsldPvcCtrlReceiveRP and determined to have been\n             sent within CIR.\n\n             Discontinuities in the value of this counter can\n             occur at re-initialization of the management system\n             and at other times as indicated by\n             frsldPvcCtrlLastPurgeTime.')
frsldPvcDataDataDeliveredE = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 3, 1, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcDataDataDeliveredE.setDescription('The number of octets that were received at\n             frsldPvcCtrlReceiveRP and determined to have been\n             sent in excess of the CIR.\n\n             Discontinuities in the value of this counter can\n\n             occur at re-initialization of the management system\n             and at other times as indicated by\n             frsldPvcCtrlLastPurgeTime.')
frsldPvcDataDataOfferedC = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 3, 1, 8), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcDataDataOfferedC.setDescription('The number of octets that were offered through\n             frsldPvcCtrlTransmitRP within CIR.\n\n             Discontinuities in the value of this counter can\n             occur at re-initialization of the management system\n             and at other times as indicated by\n             frsldPvcCtrlLastPurgeTime.')
frsldPvcDataDataOfferedE = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 3, 1, 9), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcDataDataOfferedE.setDescription('The number of octets that were offered through\n             frsldPvcCtrlTransmitRP in excess of the CIR.\n\n             Discontinuities in the value of this counter can\n             occur at re-initialization of the management system\n             and at other times as indicated by\n             frsldPvcCtrlLastPurgeTime.')
frsldPvcDataHCFrDeliveredC = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 3, 1, 10), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcDataHCFrDeliveredC.setDescription('The number of frames that were received at\n             frsldPvcCtrlReceiveRP and determined to have been\n             sent within CIR.  This object is a 64-bit version\n             of frsldPvcDataFrDeliveredC.\n\n             Discontinuities in the value of this counter can\n             occur at re-initialization of the management system\n             and at other times as indicated by\n             frsldPvcCtrlLastPurgeTime.')
frsldPvcDataHCFrDeliveredE = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 3, 1, 11), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcDataHCFrDeliveredE.setDescription('The number of frames that were received at\n             frsldPvcCtrlReceiveRP and determined to have been\n             sent in excess of the CIR.  This object is a 64-bit\n             version of frsldPvcDataFrDeliveredE.\n\n             Discontinuities in the value of this counter can\n             occur at re-initialization of the management system\n             and at other times as indicated by\n             frsldPvcCtrlLastPurgeTime.')
frsldPvcDataHCFrOfferedC = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 3, 1, 12), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcDataHCFrOfferedC.setDescription('The number of frames that were offered through\n             frsldPvcCtrlTransmitRP within CIR.  This object is\n             a 64-bit version of frsldPvcDataFrOfferedC.\n\n             Discontinuities in the value of this counter can\n             occur at re-initialization of the management system\n             and at other times as indicated by\n             frsldPvcCtrlLastPurgeTime.')
frsldPvcDataHCFrOfferedE = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 3, 1, 13), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcDataHCFrOfferedE.setDescription('The number of frames that were offered through\n             frsldPvcCtrlTransmitRP in excess of the CIR.  This\n             object is a 64-bit version of frsldPvcDataFrOfferedE.\n\n             Discontinuities in the value of this counter can\n             occur at re-initialization of the management system\n             and at other times as indicated by\n             frsldPvcCtrlLastPurgeTime.')
frsldPvcDataHCDataDeliveredC = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 3, 1, 14), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcDataHCDataDeliveredC.setDescription('The number of octets that were received at\n             frsldPvcCtrlReceiveRP and determined to have been\n             sent within CIR.  This object is a 64-bit version of\n             frsldPvcDataDataDeliveredC.\n\n             Discontinuities in the value of this counter can\n             occur at re-initialization of the management system\n             and at other times as indicated by\n             frsldPvcCtrlLastPurgeTime.')
frsldPvcDataHCDataDeliveredE = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 3, 1, 15), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcDataHCDataDeliveredE.setDescription('The number of octets that were received at\n             frsldPvcCtrlReceiveRP and determined to have been\n             sent in excess of the CIR.  This object is a 64-bit\n             version of frsldPvcDataDataDeliveredE.\n\n             Discontinuities in the value of this counter can\n             occur at re-initialization of the management system\n             and at other times as indicated by\n             frsldPvcCtrlLastPurgeTime.')
frsldPvcDataHCDataOfferedC = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 3, 1, 16), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcDataHCDataOfferedC.setDescription('The number of octets that were offered through\n             frsldPvcCtrlTransmitRP within CIR.  This object is\n             a 64-bit version of frsldPvcDataDataOfferedC.\n\n             Discontinuities in the value of this counter can\n             occur at re-initialization of the management system\n             and at other times as indicated by\n             frsldPvcCtrlLastPurgeTime.')
frsldPvcDataHCDataOfferedE = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 3, 1, 17), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcDataHCDataOfferedE.setDescription('The number of octets that were offered through\n             frsldPvcCtrlTransmitRP in excess of the CIR.\n             This object is a 64-bit version of\n             frsldPvcDataDataOfferedE.\n\n             Discontinuities in the value of this counter can\n             occur at re-initialization of the management system\n             and at other times as indicated by\n             frsldPvcCtrlLastPurgeTime.')
frsldPvcDataUnavailableTime = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 3, 1, 18), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcDataUnavailableTime.setDescription('The amount of time this PVC was declared unavailable\n             for any reason since this row was created.')
frsldPvcDataUnavailables = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 3, 1, 19), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcDataUnavailables.setDescription('The number of times this PVC was declared unavailable\n             for any reason since this row was created.\n\n             Discontinuities in the value of this counter can\n             occur at re-initialization of the management system\n             and at other times as indicated by\n             frsldPvcCtrlLastPurgeTime.')
frsldPvcSampleTable = MibTable((1, 3, 6, 1, 2, 1, 95, 1, 4), )
if mibBuilder.loadTexts: frsldPvcSampleTable.setDescription('The Frame Relay Service Level Definitions\n             sample table.')
frsldPvcSampleEntry = MibTableRow((1, 3, 6, 1, 2, 1, 95, 1, 4, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"), (0, "FRSLD-MIB", "frsldPvcCtrlDlci"), (0, "FRSLD-MIB", "frsldPvcCtrlTransmitRP"), (0, "FRSLD-MIB", "frsldPvcCtrlReceiveRP"), (0, "FRSLD-MIB", "frsldSmplCtrlIdx"), (0, "FRSLD-MIB", "frsldPvcSmplIdx"))
if mibBuilder.loadTexts: frsldPvcSampleEntry.setDescription('An entry in the Frame Relay Service Level\n             Definitions data sample table.')
frsldPvcSmplIdx = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647)))
if mibBuilder.loadTexts: frsldPvcSmplIdx.setDescription('The bucket index of the current sample.  This\n             increments once for each new bucket in the\n             table.')
frsldPvcSmplDelayMin = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 2), Gauge32()).setUnits('microseconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcSmplDelayMin.setDescription('The minimum delay reported in microseconds measured\n             for any information packet that arrived during this\n             interval.\n\n             A value of zero means that no data is available.')
frsldPvcSmplDelayMax = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 3), Gauge32()).setUnits('microseconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcSmplDelayMax.setDescription('The largest delay reported in microseconds measured\n             for any information packet that arrived during this\n             interval.\n\n             A value of zero means that no data is available.')
frsldPvcSmplDelayAvg = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 4), Gauge32()).setUnits('microseconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcSmplDelayAvg.setDescription('The average delay reported in microseconds measured\n             for all delay packets that arrived during this\n             interval.\n\n             A value of zero means that no data is available.')
frsldPvcSmplMissedPolls = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 5), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcSmplMissedPolls.setDescription('The total number of polls that were missed during\n             this interval.')
frsldPvcSmplFrDeliveredC = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 6), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcSmplFrDeliveredC.setDescription('The number of frames that were received at\n             frsldPvcCtrlReceiveRP and determined to have been\n             sent within CIR during this interval.\n\n             If it is the case that the high capacity counters\n             are also used, this MUST report the value of the\n\n             lower 32 bits of the CounterBasedGauge64 value of\n             frsldPvcSmplHCFrDeliveredC.')
frsldPvcSmplFrDeliveredE = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 7), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcSmplFrDeliveredE.setDescription('The number of frames that were received at\n             frsldPvcCtrlReceiveRP and determined to have been\n             sent in excess of the CIR during this interval.\n\n             If it is the case that the high capacity counters\n             are also used, this MUST report the value of the\n             lower 32 bits of the CounterBasedGauge64 value of\n             frsldPvcSmplHCFrDeliveredE.')
frsldPvcSmplFrOfferedC = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 8), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcSmplFrOfferedC.setDescription('The number of frames that were offered through\n             frsldPvcCtrlTransmitRP within CIR during this\n             interval.\n\n             If it is the case that the high capacity counters\n             are also used, this MUST report the value of the\n             lower 32 bits of the CounterBasedGauge64 value of\n             frsldPvcSmplHCFrOfferedC.')
frsldPvcSmplFrOfferedE = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 9), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcSmplFrOfferedE.setDescription('The number of frames that were offered through\n             frsldPvcCtrlTransmitRP in excess of the CIR\n             during this interval.\n\n             If it is the case that the high capacity counters\n             are also used, this MUST report the value of the\n             lower 32 bits of the CounterBasedGauge64 value of\n             frsldPvcSmplHCFrOfferedE.')
frsldPvcSmplDataDeliveredC = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 10), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcSmplDataDeliveredC.setDescription('The number of octets that were received at\n             frsldPvcCtrlReceiveRP and determined to have been\n             sent within CIR during this interval.\n\n             If it is the case that the high capacity counters\n             are also used, this MUST report the value of the\n             lower 32 bits of the CounterBasedGauge64 value of\n             frsldPvcSmplHCDataDeliveredC.')
frsldPvcSmplDataDeliveredE = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 11), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcSmplDataDeliveredE.setDescription('The number of octets that were received at\n             frsldPvcCtrlDeliveredRP and determined to have been\n             sent in excess of the CIR during this interval.\n\n             If it is the case that the high capacity counters\n             are also used, this MUST report the value of the\n             lower 32 bits of the CounterBasedGauge64 value of\n             frsldPvcSmplHCDataDeliveredE.')
frsldPvcSmplDataOfferedC = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 12), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcSmplDataOfferedC.setDescription('The number of octets that were offered through\n\n             frsldPvcCtrlTransmitRP within CIR during this\n             interval.\n\n             If it is the case that the high capacity counters\n             are also used, this MUST report the value of the\n             lower 32 bits of the CounterBasedGauge64 value of\n             frsldPvcSmplHCDataOfferredC.')
frsldPvcSmplDataOfferedE = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 13), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcSmplDataOfferedE.setDescription('The number of octets that were offered through\n             frsldPvcCtrlTransmitRP in excess of the CIR\n             during this interval.\n\n             If it is the case that the high capacity counters\n             are also used, this MUST report the value of the\n             lower 32 bits of the CounterBasedGauge64 value of\n             frsldPvcSmplHCDataOfferedE.')
frsldPvcSmplHCFrDeliveredC = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 14), CounterBasedGauge64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcSmplHCFrDeliveredC.setDescription('The number of frames that were received at\n             frsldPvcCtrlReceiveRP and determined to have been\n             sent within CIR during this interval.  This object\n             is a 64-bit version of frsldPvcSmplFrDeliveredC.')
frsldPvcSmplHCFrDeliveredE = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 15), CounterBasedGauge64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcSmplHCFrDeliveredE.setDescription('The number of frames that were received at\n             frsldPvcCtrlReceiveRP and determined to have been\n\n             sent in excess of the CIR during this interval.\n             This object is a 64-bit version of frsldPvcSmpl-\n             FrDeliveredE.')
frsldPvcSmplHCFrOfferedC = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 16), CounterBasedGauge64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcSmplHCFrOfferedC.setDescription('The number of frames that were offered through\n             frsldPvcCtrlTransmitRP within CIR during this\n             interval.  This object is a 64-bit version of\n             frsldPvcSmplFrOfferedC.')
frsldPvcSmplHCFrOfferedE = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 17), CounterBasedGauge64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcSmplHCFrOfferedE.setDescription('The number of frames that were offered through\n             frsldPvcCtrlTransmitRP in excess of the CIR\n             during this interval.  This object is a 64-bit\n             version of frsldPvcSmplFrOfferedE.')
frsldPvcSmplHCDataDeliveredC = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 18), CounterBasedGauge64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcSmplHCDataDeliveredC.setDescription('The number of octets that were received at\n             frsldPvcCtrlReceiveRP and determined to have been\n             sent within CIR during this interval.  This value\n             is a 64-bit version of frsldPvcSmplDataDeliveredC.')
frsldPvcSmplHCDataDeliveredE = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 19), CounterBasedGauge64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcSmplHCDataDeliveredE.setDescription('The number of octets that were received at\n             frsldPvcCtrlReceiveRP and determined to have been\n             sent in excess of the CIR during this interval.  This\n             value is a 64-bit version of frsldPvcSmplData-\n             DeliveredE.')
frsldPvcSmplHCDataOfferedC = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 20), CounterBasedGauge64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcSmplHCDataOfferedC.setDescription('The number of octets that were offered through\n             frsldPvcCtrlTransmitRP within CIR during this\n             interval.  This value is a 64-bit version of\n             frsldPvcSmplDataOfferedC.')
frsldPvcSmplHCDataOfferedE = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 21), CounterBasedGauge64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcSmplHCDataOfferedE.setDescription('The number of octets that were offered through\n             frsldPvcCtrlTransmitRP in excess of the CIR\n             during this interval.  This object is a 64-bit\n             version of frsldPvcSmplDataOfferedE.')
frsldPvcSmplUnavailableTime = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 22), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcSmplUnavailableTime.setDescription('The amount of time this PVC was declared\n             unavailable for any reason during this interval.')
frsldPvcSmplUnavailables = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 23), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcSmplUnavailables.setDescription('The number of times this PVC was declared\n             unavailable for any reason during this interval.')
frsldPvcSmplStartTime = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 24), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcSmplStartTime.setDescription('The value of sysUpTime when this sample interval\n             started.')
frsldPvcSmplEndTime = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 25), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcSmplEndTime.setDescription('The value of sysUpTime when this sample interval\n             ended.  No data will be reported and the row will\n             not appear in the table until the sample has\n             been collected.')
frsldPvcCtrlWriteCaps = MibScalar((1, 3, 6, 1, 2, 1, 95, 2, 1), Bits().clone(namedValues=NamedValues(("frsldPvcCtrlStatus", 0), ("frsldPvcCtrlPacketFreq", 1), ("frsldPvcCtrlDelayFrSize", 2), ("frsldPvcCtrlDelayType", 3), ("frsldPvcCtrlDelayTimeOut", 4), ("frsldPvcCtrlPurge", 5), ("frsldPvcCtrlDeleteOnPurge", 6),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcCtrlWriteCaps.setDescription('This object specifies the write capabilities\n             for the read-create objects of the PVC Control\n             table.  If the corresponding bit is enabled (1),\n             the agent supports writes to that object.')
frsldSmplCtrlWriteCaps = MibScalar((1, 3, 6, 1, 2, 1, 95, 2, 2), Bits().clone(namedValues=NamedValues(("frsldSmplCtrlStatus", 0), ("frsldSmplCtrlBuckets", 1),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldSmplCtrlWriteCaps.setDescription('This object specifies the write capabilities\n             for the read-create objects of the Sample Control\n             table.  If the corresponding bit is enabled (1),\n             the agent supports writes to that object.')
frsldRPCaps = MibScalar((1, 3, 6, 1, 2, 1, 95, 2, 3), Bits().clone(namedValues=NamedValues(("srcLocalRP", 0), ("ingTxLocalRP", 1), ("tpTxLocalRP", 2), ("eqiTxLocalRP", 3), ("eqoTxLocalRP", 4), ("otherTxLocalRP", 5), ("srcRemoteRP", 6), ("ingTxRemoteRP", 7), ("tpTxRemoteRP", 8), ("eqiTxRemoteRP", 9), ("eqoTxRemoteRP", 10), ("otherTxRemoteRP", 11), ("desLocalRP", 12), ("ingRxLocalRP", 13), ("tpRxLocalRP", 14), ("eqiRxLocalRP", 15), ("eqoRxLocalRP", 16), ("otherRxLocalRP", 17), ("desRemoteRP", 18), ("ingRxRemoteRP", 19), ("tpRxRemoteRP", 20), ("eqiRxRemoteRP", 21), ("eqoRxRemoteRP", 22), ("otherRxRemoteRP", 23),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldRPCaps.setDescription('This object specifies the reference points that\n             the agent supports.  This object allows the management\n             application to discover which rows can be created on\n             a specific device.')
frsldMaxPvcCtrls = MibScalar((1, 3, 6, 1, 2, 1, 95, 2, 4), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,2147483647))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: frsldMaxPvcCtrls.setDescription('The maximum number of control rows that can be created\n             in frsldPvcCtrlTable.  Sets to this object lower than\n             the current value of frsldNumPvcCtrls should result in\n             inconsistentValue.')
frsldNumPvcCtrls = MibScalar((1, 3, 6, 1, 2, 1, 95, 2, 5), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldNumPvcCtrls.setDescription('The current number of rows in frsldPvcCtrlTable.')
frsldMaxSmplCtrls = MibScalar((1, 3, 6, 1, 2, 1, 95, 2, 6), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,2147483647))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: frsldMaxSmplCtrls.setDescription('The maximum number of control rows that can be created\n             in frsldSmplCtrlTable.  Sets to this object lower than\n             the current value of frsldNumSmplCtrls should result in\n             inconsistentValue.')
frsldNumSmplCtrls = MibScalar((1, 3, 6, 1, 2, 1, 95, 2, 7), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldNumSmplCtrls.setDescription('The current number of rows in frsldSmplCtrlTable.')
frsldMIBGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 95, 3, 1))
frsldMIBCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 95, 3, 2))
frsldCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 95, 3, 2, 1)).setObjects(*(("FRSLD-MIB", "frsldPvcReqCtrlGroup"), ("FRSLD-MIB", "frsldPvcReqDataGroup"), ("FRSLD-MIB", "frsldCapabilitiesGroup"), ("FRSLD-MIB", "frsldPvcHCFrameDataGroup"), ("FRSLD-MIB", "frsldPvcHCOctetDataGroup"), ("FRSLD-MIB", "frsldPvcPacketGroup"), ("FRSLD-MIB", "frsldPvcDelayCtrlGroup"), ("FRSLD-MIB", "frsldPvcSampleCtrlGroup"), ("FRSLD-MIB", "frsldPvcDelayDataGroup"), ("FRSLD-MIB", "frsldPvcSampleDelayGroup"), ("FRSLD-MIB", "frsldPvcSampleDataGroup"), ("FRSLD-MIB", "frsldPvcSampleHCFrameGroup"), ("FRSLD-MIB", "frsldPvcSampleHCDataGroup"), ("FRSLD-MIB", "frsldPvcSampleAvailGroup"), ("FRSLD-MIB", "frsldPvcSampleGeneralGroup"),))
if mibBuilder.loadTexts: frsldCompliance.setDescription('The compliance statement for SNMP entities\n             which support with Frame Relay Service Level\n             Definitions.  This group defines the minimum\n             level of support required for compliance.')
frsldPvcReqCtrlGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 95, 3, 1, 1)).setObjects(*(("FRSLD-MIB", "frsldPvcCtrlStatus"), ("FRSLD-MIB", "frsldPvcCtrlPurge"), ("FRSLD-MIB", "frsldPvcCtrlDeleteOnPurge"), ("FRSLD-MIB", "frsldPvcCtrlLastPurgeTime"),))
if mibBuilder.loadTexts: frsldPvcReqCtrlGroup.setDescription('A collection of required objects providing\n            control information applicable to a PVC which\n            implements Service Level Definitions.')
frsldPvcPacketGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 95, 3, 1, 2)).setObjects(*(("FRSLD-MIB", "frsldPvcCtrlPacketFreq"),))
if mibBuilder.loadTexts: frsldPvcPacketGroup.setDescription('A collection of optional objects providing packet\n            level control information applicable to a PVC which\n            implements Service Level Definitions.')
frsldPvcDelayCtrlGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 95, 3, 1, 3)).setObjects(*(("FRSLD-MIB", "frsldPvcCtrlDelayFrSize"), ("FRSLD-MIB", "frsldPvcCtrlDelayType"), ("FRSLD-MIB", "frsldPvcCtrlDelayTimeOut"),))
if mibBuilder.loadTexts: frsldPvcDelayCtrlGroup.setDescription('A collection of optional objects providing delay\n            control information applicable to a PVC which\n            implements Service Level Definitions.\n\n            If this group is implemented, frsldPvcPacketGroup\n            and frsldPvcDelayDataGroup MUST also be implemented.')
frsldPvcSampleCtrlGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 95, 3, 1, 4)).setObjects(*(("FRSLD-MIB", "frsldSmplCtrlStatus"), ("FRSLD-MIB", "frsldSmplCtrlColPeriod"), ("FRSLD-MIB", "frsldSmplCtrlBuckets"), ("FRSLD-MIB", "frsldSmplCtrlBucketsGranted"),))
if mibBuilder.loadTexts: frsldPvcSampleCtrlGroup.setDescription('A collection of optional objects providing sample\n            control information applicable to a PVC which\n            implements Service Level Definitions.\n\n            If this group is implemented, frsldPvcReqDataGroup\n            and frsldPvcSampleGeneralGroup MUST also be\n            implemented.')
frsldPvcReqDataGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 95, 3, 1, 5)).setObjects(*(("FRSLD-MIB", "frsldPvcDataFrDeliveredC"), ("FRSLD-MIB", "frsldPvcDataFrDeliveredE"), ("FRSLD-MIB", "frsldPvcDataFrOfferedC"), ("FRSLD-MIB", "frsldPvcDataFrOfferedE"), ("FRSLD-MIB", "frsldPvcDataDataDeliveredC"), ("FRSLD-MIB", "frsldPvcDataDataDeliveredE"), ("FRSLD-MIB", "frsldPvcDataDataOfferedC"), ("FRSLD-MIB", "frsldPvcDataDataOfferedE"), ("FRSLD-MIB", "frsldPvcDataUnavailableTime"), ("FRSLD-MIB", "frsldPvcDataUnavailables"),))
if mibBuilder.loadTexts: frsldPvcReqDataGroup.setDescription('A collection of required objects providing data\n            collected on a PVC which implements Service\n            Level Definitions.')
frsldPvcDelayDataGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 95, 3, 1, 6)).setObjects(*(("FRSLD-MIB", "frsldPvcDataMissedPolls"),))
if mibBuilder.loadTexts: frsldPvcDelayDataGroup.setDescription('A collection of optional objects providing delay\n            data collected on a PVC which implements Service\n            Level Definitions.\n\n            If this group is implemented, frsldPvcDelayCtrlGroup\n            MUST also be implemented.')
frsldPvcHCFrameDataGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 95, 3, 1, 7)).setObjects(*(("FRSLD-MIB", "frsldPvcDataHCFrDeliveredC"), ("FRSLD-MIB", "frsldPvcDataHCFrDeliveredE"), ("FRSLD-MIB", "frsldPvcDataHCFrOfferedC"), ("FRSLD-MIB", "frsldPvcDataHCFrOfferedE"),))
if mibBuilder.loadTexts: frsldPvcHCFrameDataGroup.setDescription('A collection of optional objects providing high\n            capacity frame data collected on a PVC which\n            implements Service Level Definitions.')
frsldPvcHCOctetDataGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 95, 3, 1, 8)).setObjects(*(("FRSLD-MIB", "frsldPvcDataHCDataDeliveredC"), ("FRSLD-MIB", "frsldPvcDataHCDataDeliveredE"), ("FRSLD-MIB", "frsldPvcDataHCDataOfferedC"), ("FRSLD-MIB", "frsldPvcDataHCDataOfferedE"),))
if mibBuilder.loadTexts: frsldPvcHCOctetDataGroup.setDescription('A collection of optional objects providing high\n            capacity octet data collected on a PVC which\n            implements Service Level Definitions.')
frsldPvcSampleDelayGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 95, 3, 1, 9)).setObjects(*(("FRSLD-MIB", "frsldPvcSmplDelayMin"), ("FRSLD-MIB", "frsldPvcSmplDelayMax"), ("FRSLD-MIB", "frsldPvcSmplDelayAvg"), ("FRSLD-MIB", "frsldPvcSmplMissedPolls"),))
if mibBuilder.loadTexts: frsldPvcSampleDelayGroup.setDescription('A collection of optional objects providing delay\n            sample data collected on a PVC which implements\n            Service Level Definitions.\n\n            If this group is implemented, frsldPvcDelayCtrlGroup\n            MUST also be implemented.')
frsldPvcSampleDataGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 95, 3, 1, 10)).setObjects(*(("FRSLD-MIB", "frsldPvcSmplFrDeliveredC"), ("FRSLD-MIB", "frsldPvcSmplFrDeliveredE"), ("FRSLD-MIB", "frsldPvcSmplFrOfferedC"), ("FRSLD-MIB", "frsldPvcSmplFrOfferedE"), ("FRSLD-MIB", "frsldPvcSmplDataDeliveredC"), ("FRSLD-MIB", "frsldPvcSmplDataDeliveredE"), ("FRSLD-MIB", "frsldPvcSmplDataOfferedC"), ("FRSLD-MIB", "frsldPvcSmplDataOfferedE"),))
if mibBuilder.loadTexts: frsldPvcSampleDataGroup.setDescription('A collection of optional objects providing data\n            and frame delivery sample data collected on a PVC\n            which implements Service Level Definitions.\n\n            If this group is implemented, frsldPvcReqDataGroup\n            MUST also be implemented.')
frsldPvcSampleHCFrameGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 95, 3, 1, 11)).setObjects(*(("FRSLD-MIB", "frsldPvcSmplHCFrDeliveredC"), ("FRSLD-MIB", "frsldPvcSmplHCFrDeliveredE"), ("FRSLD-MIB", "frsldPvcSmplHCFrOfferedC"), ("FRSLD-MIB", "frsldPvcSmplHCFrOfferedE"),))
if mibBuilder.loadTexts: frsldPvcSampleHCFrameGroup.setDescription('A collection of optional objects providing high\n            capacity frame delivery sample data collected on a PVC\n            which implements Service Level Definitions.\n\n            If this group is implemented, frsldPvcHCFrameDataGroup\n            MUST also be implemented.')
frsldPvcSampleHCDataGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 95, 3, 1, 12)).setObjects(*(("FRSLD-MIB", "frsldPvcSmplHCDataDeliveredC"), ("FRSLD-MIB", "frsldPvcSmplHCDataDeliveredE"), ("FRSLD-MIB", "frsldPvcSmplHCDataOfferedC"), ("FRSLD-MIB", "frsldPvcSmplHCDataOfferedE"),))
if mibBuilder.loadTexts: frsldPvcSampleHCDataGroup.setDescription('A collection of optional objects providing high\n            capacity data delivery sample data collected on a PVC\n            which implements Service Level Definitions.\n\n            If this group is implemented, frsldPvcHCOctetDataGroup\n\n            MUST also be implemented.')
frsldPvcSampleAvailGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 95, 3, 1, 13)).setObjects(*(("FRSLD-MIB", "frsldPvcSmplUnavailableTime"), ("FRSLD-MIB", "frsldPvcSmplUnavailables"),))
if mibBuilder.loadTexts: frsldPvcSampleAvailGroup.setDescription('A collection of optional objects providing\n            availability sample data collected on a PVC which\n            implements Service Level Definitions.\n\n            If this group is implemented, frsldPvcReqDataGroup\n            MUST also be implemented.')
frsldPvcSampleGeneralGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 95, 3, 1, 14)).setObjects(*(("FRSLD-MIB", "frsldPvcSmplStartTime"), ("FRSLD-MIB", "frsldPvcSmplEndTime"),))
if mibBuilder.loadTexts: frsldPvcSampleGeneralGroup.setDescription('A collection of optional objects providing\n            general sample data collected on a PVC which\n            implements Service Level Definitions.')
frsldCapabilitiesGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 95, 3, 1, 15)).setObjects(*(("FRSLD-MIB", "frsldPvcCtrlWriteCaps"), ("FRSLD-MIB", "frsldSmplCtrlWriteCaps"), ("FRSLD-MIB", "frsldRPCaps"), ("FRSLD-MIB", "frsldMaxPvcCtrls"), ("FRSLD-MIB", "frsldNumPvcCtrls"), ("FRSLD-MIB", "frsldMaxSmplCtrls"), ("FRSLD-MIB", "frsldNumSmplCtrls"),))
if mibBuilder.loadTexts: frsldCapabilitiesGroup.setDescription('A collection of required objects providing\n            capability information and control for this\n            MIB module.')
mibBuilder.exportSymbols("FRSLD-MIB", PYSNMP_MODULE_ID=frsldMIB, frsldPvcSampleDataGroup=frsldPvcSampleDataGroup, frsldCapabilitiesGroup=frsldCapabilitiesGroup, frsldPvcSmplMissedPolls=frsldPvcSmplMissedPolls, FrsldTxRP=FrsldTxRP, frsldPvcCtrlReceiveRP=frsldPvcCtrlReceiveRP, frsldMIB=frsldMIB, FrsldRxRP=FrsldRxRP, frsldPvcDataHCFrOfferedE=frsldPvcDataHCFrOfferedE, frsldPvcCtrlDeleteOnPurge=frsldPvcCtrlDeleteOnPurge, frsldMaxSmplCtrls=frsldMaxSmplCtrls, frsldPvcSmplFrOfferedE=frsldPvcSmplFrOfferedE, frsldPvcDataFrOfferedC=frsldPvcDataFrOfferedC, frsldPvcSmplHCFrOfferedE=frsldPvcSmplHCFrOfferedE, frsldPvcCtrlDlci=frsldPvcCtrlDlci, frsldPvcSmplEndTime=frsldPvcSmplEndTime, frsldCompliance=frsldCompliance, frsldMIBGroups=frsldMIBGroups, frsldPvcSmplDataDeliveredC=frsldPvcSmplDataDeliveredC, frsldPvcCtrlDelayTimeOut=frsldPvcCtrlDelayTimeOut, frsldPvcSampleGeneralGroup=frsldPvcSampleGeneralGroup, frsldPvcSmplFrDeliveredE=frsldPvcSmplFrDeliveredE, frsldPvcSmplUnavailables=frsldPvcSmplUnavailables, frsldPvcDataDataOfferedC=frsldPvcDataDataOfferedC, frsldPvcSmplHCDataDeliveredE=frsldPvcSmplHCDataDeliveredE, frsldPvcSmplStartTime=frsldPvcSmplStartTime, frsldPvcSmplUnavailableTime=frsldPvcSmplUnavailableTime, frsldPvcReqDataGroup=frsldPvcReqDataGroup, frsldCapabilities=frsldCapabilities, frsldPvcSmplDelayMin=frsldPvcSmplDelayMin, frsldPvcSmplDataOfferedC=frsldPvcSmplDataOfferedC, frsldRPCaps=frsldRPCaps, frsldPvcSmplDataOfferedE=frsldPvcSmplDataOfferedE, frsldPvcSampleTable=frsldPvcSampleTable, frsldPvcSmplDataDeliveredE=frsldPvcSmplDataDeliveredE, frsldSmplCtrlBuckets=frsldSmplCtrlBuckets, frsldNumSmplCtrls=frsldNumSmplCtrls, frsldObjects=frsldObjects, frsldPvcSmplDelayAvg=frsldPvcSmplDelayAvg, frsldPvcDataDataDeliveredC=frsldPvcDataDataDeliveredC, frsldPvcSmplDelayMax=frsldPvcSmplDelayMax, frsldPvcHCOctetDataGroup=frsldPvcHCOctetDataGroup, frsldPvcDataUnavailables=frsldPvcDataUnavailables, frsldPvcCtrlEntry=frsldPvcCtrlEntry, frsldPvcCtrlTable=frsldPvcCtrlTable, frsldPvcSmplHCDataOfferedC=frsldPvcSmplHCDataOfferedC, frsldPvcCtrlTransmitRP=frsldPvcCtrlTransmitRP, frsldPvcSmplFrDeliveredC=frsldPvcSmplFrDeliveredC, frsldPvcDataFrDeliveredC=frsldPvcDataFrDeliveredC, frsldSmplCtrlStatus=frsldSmplCtrlStatus, frsldPvcSampleAvailGroup=frsldPvcSampleAvailGroup, frsldPvcCtrlWriteCaps=frsldPvcCtrlWriteCaps, frsldPvcDelayCtrlGroup=frsldPvcDelayCtrlGroup, frsldPvcCtrlDelayFrSize=frsldPvcCtrlDelayFrSize, frsldPvcCtrlLastPurgeTime=frsldPvcCtrlLastPurgeTime, frsldPvcDataHCDataDeliveredE=frsldPvcDataHCDataDeliveredE, frsldPvcDataTable=frsldPvcDataTable, frsldPvcDataFrOfferedE=frsldPvcDataFrOfferedE, frsldPvcDataHCDataDeliveredC=frsldPvcDataHCDataDeliveredC, frsldSmplCtrlBucketsGranted=frsldSmplCtrlBucketsGranted, frsldSmplCtrlWriteCaps=frsldSmplCtrlWriteCaps, frsldPvcPacketGroup=frsldPvcPacketGroup, frsldMIBCompliances=frsldMIBCompliances, frsldSmplCtrlColPeriod=frsldSmplCtrlColPeriod, frsldSmplCtrlIdx=frsldSmplCtrlIdx, frsldPvcSmplFrOfferedC=frsldPvcSmplFrOfferedC, frsldConformance=frsldConformance, frsldSmplCtrlTable=frsldSmplCtrlTable, frsldPvcCtrlStatus=frsldPvcCtrlStatus, frsldPvcHCFrameDataGroup=frsldPvcHCFrameDataGroup, frsldPvcSmplHCFrOfferedC=frsldPvcSmplHCFrOfferedC, frsldNumPvcCtrls=frsldNumPvcCtrls, frsldPvcSmplHCFrDeliveredE=frsldPvcSmplHCFrDeliveredE, frsldPvcDataDataOfferedE=frsldPvcDataDataOfferedE, frsldPvcCtrlPurge=frsldPvcCtrlPurge, frsldPvcSmplHCFrDeliveredC=frsldPvcSmplHCFrDeliveredC, frsldPvcDataHCFrOfferedC=frsldPvcDataHCFrOfferedC, frsldPvcDataHCDataOfferedE=frsldPvcDataHCDataOfferedE, frsldPvcSmplIdx=frsldPvcSmplIdx, frsldPvcSampleHCDataGroup=frsldPvcSampleHCDataGroup, frsldPvcDataDataDeliveredE=frsldPvcDataDataDeliveredE, frsldPvcSampleCtrlGroup=frsldPvcSampleCtrlGroup, frsldPvcDelayDataGroup=frsldPvcDelayDataGroup, frsldPvcSampleDelayGroup=frsldPvcSampleDelayGroup, frsldPvcDataMissedPolls=frsldPvcDataMissedPolls, frsldMaxPvcCtrls=frsldMaxPvcCtrls, frsldPvcSmplHCDataDeliveredC=frsldPvcSmplHCDataDeliveredC, frsldPvcCtrlDelayType=frsldPvcCtrlDelayType, frsldPvcDataHCFrDeliveredC=frsldPvcDataHCFrDeliveredC, frsldPvcDataUnavailableTime=frsldPvcDataUnavailableTime, frsldPvcDataHCDataOfferedC=frsldPvcDataHCDataOfferedC, frsldPvcDataEntry=frsldPvcDataEntry, frsldPvcSampleHCFrameGroup=frsldPvcSampleHCFrameGroup, frsldPvcDataFrDeliveredE=frsldPvcDataFrDeliveredE, frsldPvcReqCtrlGroup=frsldPvcReqCtrlGroup, frsldPvcDataHCFrDeliveredE=frsldPvcDataHCFrDeliveredE, frsldPvcSmplHCDataOfferedE=frsldPvcSmplHCDataOfferedE, frsldSmplCtrlEntry=frsldSmplCtrlEntry, frsldPvcCtrlPacketFreq=frsldPvcCtrlPacketFreq, frsldPvcSampleEntry=frsldPvcSampleEntry)
