#
# PySNMP MIB module T11-FC-FSPF-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/T11-FC-FSPF-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:30:06 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( OctetString, Integer, ObjectIdentifier, ) = mibBuilder.importSymbols("ASN1", "OctetString", "Integer", "ObjectIdentifier")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsUnion, SingleValueConstraint, ConstraintsIntersection, ValueSizeConstraint, ValueRangeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsUnion", "SingleValueConstraint", "ConstraintsIntersection", "ValueSizeConstraint", "ValueRangeConstraint")
( fcmSwitchIndex, fcmInstanceIndex, FcDomainIdOrZero, ) = mibBuilder.importSymbols("FC-MGMT-MIB", "fcmSwitchIndex", "fcmInstanceIndex", "FcDomainIdOrZero")
( InterfaceIndex, ifIndex, ) = mibBuilder.importSymbols("IF-MIB", "InterfaceIndex", "ifIndex")
( NotificationGroup, ObjectGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ObjectGroup", "ModuleCompliance")
( ObjectIdentity, NotificationType, MibScalar, MibTable, MibTableRow, MibTableColumn, Bits, Gauge32, iso, Counter64, MibIdentifier, ModuleIdentity, Unsigned32, IpAddress, Counter32, Integer32, TimeTicks, mib_2, ) = mibBuilder.importSymbols("SNMPv2-SMI", "ObjectIdentity", "NotificationType", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Bits", "Gauge32", "iso", "Counter64", "MibIdentifier", "ModuleIdentity", "Unsigned32", "IpAddress", "Counter32", "Integer32", "TimeTicks", "mib-2")
( RowStatus, TruthValue, DisplayString, TextualConvention, StorageType, ) = mibBuilder.importSymbols("SNMPv2-TC", "RowStatus", "TruthValue", "DisplayString", "TextualConvention", "StorageType")
( t11FamConfigDomainId, ) = mibBuilder.importSymbols("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamConfigDomainId")
( T11FabricIndex, ) = mibBuilder.importSymbols("T11-TC-MIB", "T11FabricIndex")
t11FcFspfMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 143)).setRevisions(("2006-08-14 00:00",))
if mibBuilder.loadTexts: t11FcFspfMIB.setLastUpdated('200608140000Z')
if mibBuilder.loadTexts: t11FcFspfMIB.setOrganization('T11')
if mibBuilder.loadTexts: t11FcFspfMIB.setContactInfo('Claudio DeSanti\n                    Cisco Systems, Inc.\n                    170 West Tasman Drive\n                    San Jose, CA 95134 USA\n                    EMail: cds@cisco.com\n\n\n\n\n                    Keith McCloghrie\n                    Cisco Systems, Inc.\n                    170 West Tasman Drive\n                    San Jose, CA USA 95134\n                    Email: kzm@cisco.com')
if mibBuilder.loadTexts: t11FcFspfMIB.setDescription('The MIB module for managing the Fabric Shortest Path\n           First (FSPF) protocol.  FSPF is specified in FC-SW-4.\n\n           Copyright (C) The Internet Society (2006).  This version of\n           this MIB module is part of RFC 4626;  see the RFC itself for\n           full legal notices.')
t11FspfNotifications = MibIdentifier((1, 3, 6, 1, 2, 1, 143, 0))
t11FspfObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 143, 1))
t11FspfConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 143, 2))
t11FspfConfiguration = MibIdentifier((1, 3, 6, 1, 2, 1, 143, 1, 1))
t11FspfDatabase = MibIdentifier((1, 3, 6, 1, 2, 1, 143, 1, 2))
class T11FspfLsrType(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(0,255)

class T11FspfLinkType(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(0,255)

class T11FspfInterfaceState(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6,))
    namedValues = NamedValues(("down", 1), ("init", 2), ("dbExchange", 3), ("dbAckwait", 4), ("dbWait", 5), ("full", 6),)

class T11FspfLastCreationTime(TimeTicks, TextualConvention):
    pass

t11FspfTable = MibTable((1, 3, 6, 1, 2, 1, 143, 1, 1, 1), )
if mibBuilder.loadTexts: t11FspfTable.setDescription("This table allows the users to configure and monitor FSPF's\n           per-Fabric parameters and statistics on all Fabrics known to\n           locally managed switches.\n\n           Entries are created/removed by the agent if and when\n           (Virtual) Fabrics are created/deleted.")
t11FspfEntry = MibTableRow((1, 3, 6, 1, 2, 1, 143, 1, 1, 1, 1), ).setIndexNames((0, "FC-MGMT-MIB", "fcmInstanceIndex"), (0, "FC-MGMT-MIB", "fcmSwitchIndex"), (0, "T11-FC-FSPF-MIB", "t11FspfFabricIndex"))
if mibBuilder.loadTexts: t11FspfEntry.setDescription("An entry containing FSPF variables, parameters, and\n           statistics on a particular switch (identified by values\n           of fcmInstanceIndex and fcmSwitchIndex) for a particular\n           Fabric (identified by a t11FspfFabricIndex value).\n\n           (Note that the local switch's per-fabric Domain-ID is\n           available in t11FamConfigDomainId, which is defined in\n           T11-FC-FABRIC-ADDR-MGR-MIB.)")
t11FspfFabricIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 1, 1, 1), T11FabricIndex())
if mibBuilder.loadTexts: t11FspfFabricIndex.setDescription('A unique index value that uniquely identifies a\n           particular Fabric.\n\n           In a Fabric conformant to FC-SW-4, multiple Virtual Fabrics\n           can operate within one (or more) physical infrastructures.\n           In such a case, index value is used to uniquely identify a\n           particular Fabric within a physical infrastructure.\n\n           In a Fabric that has (can have) only a single Fabric\n           operating within the physical infrastructure, the\n           value of this Fabric Index will always be 1.')
t11FspfMinLsArrival = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 1, 1, 2), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,65535)).clone(1000)).setUnits('milliSeconds').setMaxAccess("readwrite")
if mibBuilder.loadTexts: t11FspfMinLsArrival.setDescription('The minimum time after accepting a Link State Record\n           (LSR) on this Fabric before accepting another update of\n           the same LSR on the same Fabric.\n\n           An LSR update that is not accepted because of this time\n           interval is discarded.')
t11FspfMinLsInterval = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 1, 1, 3), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,65535)).clone(5000)).setUnits('milliSeconds').setMaxAccess("readwrite")
if mibBuilder.loadTexts: t11FspfMinLsInterval.setDescription('The minimum time after this switch sends an LSR on this\n           Fabric before it will send another update of the same LSR\n           on the same Fabric.')
t11FspfLsRefreshTime = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 1, 1, 4), Unsigned32().clone(30)).setUnits('Minutes').setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfLsRefreshTime.setDescription('The interval between transmission of refresh LSRs on this\n           Fabric.')
t11FspfMaxAge = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 1, 1, 5), Unsigned32().clone(60)).setUnits('Minutes').setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfMaxAge.setDescription('The maximum age an LSR will be retained in the FSPF\n           database on this Fabric.  An LSR is removed from the\n           database after MaxAge is reached.')
t11FspfMaxAgeDiscards = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 1, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfMaxAgeDiscards.setDescription('The number of LSRs discarded due to their age reaching\n           t11FspfMaxAge in this Fabric.  The last discontinuity of\n           this counter is indicated by t11FspfCreateTime.')
t11FspfPathComputations = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 1, 1, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfPathComputations.setDescription('The number of times that the path computation algorithm\n           has been invoked by this Switch on this Fabric to compute\n           a set of minimum cost paths for this Fabric.  The last\n\n\n\n           discontinuity of this counter is indicated by\n           t11FspfCreateTime.')
t11FspfChecksumErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 1, 1, 8), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfChecksumErrors.setDescription('The number of FSPF checksum errors that were detected\n           locally (and therefore discarded) on this Fabric.\n           The last discontinuity of this counter is indicated by\n           t11FspfCreateTime.')
t11FspfLsrs = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 1, 1, 9), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfLsrs.setDescription('The current number of entries for this Fabric in the\n           t11FspfLsrTable.')
t11FspfCreateTime = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 1, 1, 10), T11FspfLastCreationTime()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfCreateTime.setDescription('The value of sysUpTime when this entry was last created.')
t11FspfAdminStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 1, 1, 11), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("up", 1), ("down", 2),)).clone('up')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: t11FspfAdminStatus.setDescription("The desired state of FSPF in this Fabric.  If value of\n           this object is set to 'up', then FSPF is enabled in\n           this Fabric.  If set to 'down', then FSPF is disabled\n           in this Fabric -- when FSPF is disabled, FSPF provides\n\n\n\n           no routes to be included in the T11-FC-ROUTE-MIB module.\n           (see the T11-FC-ROUTE-MIB).")
t11FspfOperStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 1, 1, 12), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("up", 1), ("down", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfOperStatus.setDescription("State of FSPF in this Fabric.  If 't11FspfAdminStatus' is\n           'down', then the 't11FspfOperStatus' should be 'down'.\n           If 't11FspfAdminStatus' is changed to 'up', then\n           't11FspfOperStatus' should change to 'up' as and when\n           FSPF is active in this Fabric.")
t11FspfNbrStateChangNotifyEnable = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 1, 1, 13), TruthValue().clone('false')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: t11FspfNbrStateChangNotifyEnable.setDescription("Specifies whether or not the local agent should\n           issue the notification 't11FspfNbrStateChangNotify'\n           when the local switch learns of a change of state\n           in the FSPF Neighbor Finite State Machine on an\n           interface in this Fabric.\n           If the value of the object is 'true, then the\n           notification is generated.  If the value is 'false',\n           notification is not generated.")
t11FspfSetToDefault = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 1, 1, 14), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("default", 1), ("noOp", 2),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: t11FspfSetToDefault.setDescription("Setting this value to 'default' changes the value of each\n           and every writable object in this row to its default\n\n\n\n           value.\n\n           No action is taken if this object is set to 'noOp'.\n           The value of the object, when read, is always 'noOp'.")
t11FspfStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 1, 1, 15), StorageType().clone('nonVolatile')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: t11FspfStorageType.setDescription("The storage type for read-write objects in this\n           conceptual row.\n\n           Conceptual rows having the value 'permanent' need not\n           allow write-access to any columnar objects in the row.")
t11FspfIfTable = MibTable((1, 3, 6, 1, 2, 1, 143, 1, 1, 2), )
if mibBuilder.loadTexts: t11FspfIfTable.setDescription("This table allows the users to configure and monitor\n           the FSPF parameters that are per-interface (identified\n           by a t11FspfIfIndex value), per-Fabric (identified by a\n           t11FspfFabricIndex value), and per-switch (identified by\n           values of fcmInstanceIndex and fcmSwitchIndex).\n\n           Creating a row in this table via t11FspfIfRowStatus\n           provides the means to specify non-default parameter value(s)\n           for an interface at a time when the relevant row in this\n           table would not otherwise exist because the interface is\n           either down or it is not an E_Port, but the corresponding\n           row in the t11FspfTable must already exist.\n\n           After the non-default values have been specified for a\n           port's parameters, they need to be retained in this table,\n           even when the port becomes 'isolated'.  However, having\n           unnecessary rows in this table clutters it up and makes\n           those rows that are useful harder for an NMS to find.\n           Therefore, when an E_Port becomes isolated, its row gets\n           deleted if and only if all of its parameter values are the\n           default values; also, when an E_Port becomes non-isolated\n\n\n\n           in a particular Fabric, a row in this table needs to exist\n           and is automatically created, if necessary.\n\n           The specific conditions for an automated/implicit deletion\n           of a row are:\n           a) if the corresponding interface is no longer an E_Port\n              (e.g., a G_Port which is dynamically determined to be an\n              F_Port), and all configurable parameters have default\n              values; or\n           b) if the interface identified by t11FspfIfIndex no longer\n              exists (e.g., because a line-card is physically removed);\n              or\n           c) if the corresponding row in the t11FspfTable is deleted.\n           ")
t11FspfIfEntry = MibTableRow((1, 3, 6, 1, 2, 1, 143, 1, 1, 2, 1), ).setIndexNames((0, "FC-MGMT-MIB", "fcmInstanceIndex"), (0, "FC-MGMT-MIB", "fcmSwitchIndex"), (0, "T11-FC-FSPF-MIB", "t11FspfFabricIndex"), (0, "T11-FC-FSPF-MIB", "t11FspfIfIndex"))
if mibBuilder.loadTexts: t11FspfIfEntry.setDescription('An entry containing FSPF information for the interface\n           identified by t11FspfIfIndex, on the fabric identified\n           by t11FspfFabricIndex, on the switch identified by\n           fcmSwitchIndex.')
t11FspfIfIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 2, 1, 1), InterfaceIndex())
if mibBuilder.loadTexts: t11FspfIfIndex.setDescription('The value of ifIndex that identifies the local\n           Fibre Channel interface for which this entry\n           contains FSPF information.')
t11FspfIfHelloInterval = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 2, 1, 2), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,65535)).clone(20)).setUnits('Seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: t11FspfIfHelloInterval.setDescription('Interval between the periodic HELLO messages sent on this\n           interface in this Fabric to verify the link health.  Note\n           that this value must be same at both ends of a link in\n           this Fabric.')
t11FspfIfDeadInterval = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 2, 1, 3), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(2,65535)).clone(80)).setUnits('Seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: t11FspfIfDeadInterval.setDescription('Maximum time for which no HELLO messages can be received\n           on this interface in this Fabric.  After this time, the\n           interface is assumed to be broken and removed from the\n           database.  Note that this value must be greater than the\n           HELLO interval specified on this interface in this Fabric.')
t11FspfIfRetransmitInterval = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 2, 1, 4), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,65535)).clone(5)).setUnits('Seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: t11FspfIfRetransmitInterval.setDescription('The time after which an unacknowledged LSR is\n           retransmitted on this interface in this Fabric.')
t11FspfIfInLsuPkts = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 2, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfIfInLsuPkts.setDescription('Number of Link State Update (LSU) packets received on\n           this interface in this Fabric.  The last discontinuity\n           of this counter is indicated by t11FspfIfCreateTime.')
t11FspfIfInLsaPkts = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 2, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfIfInLsaPkts.setDescription('Number of Link State Acknowledgement (LSA) packets\n           received on this interface in this Fabric.  The last\n           discontinuity of this counter is indicated by\n           t11FspfIfCreateTime.')
t11FspfIfOutLsuPkts = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 2, 1, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfIfOutLsuPkts.setDescription('Number of Link State Update (LSU) packets transmitted\n           on this interface in this Fabric.  The last\n           discontinuity of this counter is indicated by\n           t11FspfIfCreateTime.')
t11FspfIfOutLsaPkts = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 2, 1, 8), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfIfOutLsaPkts.setDescription('Number of Link State Acknowledgement (LSA) packets\n           transmitted on this interface in this Fabric.  The\n           last discontinuity of this counter is indicated by\n           t11FspfIfCreateTime.')
t11FspfIfOutHelloPkts = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 2, 1, 9), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfIfOutHelloPkts.setDescription('Number of HELLO packets transmitted on this interface in\n           this Fabric.  The last discontinuity of this counter is\n           indicated by t11FspfIfCreateTime.')
t11FspfIfInHelloPkts = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 2, 1, 10), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfIfInHelloPkts.setDescription('Number of HELLO packets received on this interface in\n           this Fabric.  The last discontinuity of this counter is\n           indicated by t11FspfIfCreateTime.')
t11FspfIfRetransmittedLsuPkts = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 2, 1, 11), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfIfRetransmittedLsuPkts.setDescription('The number of LSU packets that contained one or more\n           retransmitted LSRs, and that were transmitted on this\n           interface in this Fabric.  The last discontinuity of\n           this counter is indicated by t11FspfIfCreateTime.')
t11FspfIfInErrorPkts = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 2, 1, 12), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfIfInErrorPkts.setDescription('Number of invalid FSPF control packets received on this\n           interface in this Fabric.  The last discontinuity of\n           this counter is indicated by t11FspfIfCreateTime.')
t11FspfIfNbrState = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 2, 1, 13), T11FspfInterfaceState()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfIfNbrState.setDescription("The state of FSPF's 'neighbor state machine', which is\n           the operational state of the interaction with the\n\n\n\n           neighbor's interface that is connected to this interface.\n\n           If the 't11FspfIfAdminStatus' is 'down', then this object\n           should be 'down'.  If the 't11FspfIfAdminStatus' is 'up',\n           then this object's value depends on the state of FSPF's\n           'neighbor state machine' on this interface in this\n           Fabric.")
t11FspfIfNbrDomainId = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 2, 1, 14), FcDomainIdOrZero()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfIfNbrDomainId.setDescription('The Domain Id of the neighbor in this Fabric.')
t11FspfIfNbrPortIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 2, 1, 15), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,16777215))).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfIfNbrPortIndex.setDescription("The index, as known by the neighbor, of the neighbor's\n           interface that is connected to this interface in this\n           Fabric.")
t11FspfIfAdminStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 2, 1, 16), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("up", 1), ("down", 2),)).clone('up')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: t11FspfIfAdminStatus.setDescription("The desired state of FSPF on this interface in this\n           Fabric, whenever 't11FspfAdminStatus' is 'up'.\n           If the value of this object is set to 'up', then FSPF is\n           enabled on this interface in this Fabric.  If set to\n           'down', then FSPF is disabled on this interface in this\n           Fabric.  Note that the operational state of FSPF on an\n           interface is given by t11FspfIfNbrState.")
t11FspfIfCreateTime = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 2, 1, 17), T11FspfLastCreationTime()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfIfCreateTime.setDescription('The value of sysUpTime when this entry was last\n           created.')
t11FspfIfSetToDefault = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 2, 1, 18), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("default", 1), ("noOp", 2),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: t11FspfIfSetToDefault.setDescription("Setting this value to 'default' changes the value of each\n           and every writable object in this row to its default\n           value.\n\n           If all the configuration parameters have their default\n           values, and if the interface is down, then the row is\n           deleted automatically.\n\n           No action is taken if this object is set to 'noOp'.\n           The value of the object, when read, is always 'noOp'.")
t11FspfIfLinkCostFactor = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 2, 1, 19), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,65535)).clone(100)).setMaxAccess("readcreate")
if mibBuilder.loadTexts: t11FspfIfLinkCostFactor.setDescription('The administrative factor used in calculating the cost\n           of sending a frame on this interface in this Fabric.\n\n           The formula used to calculate the link cost is:\n\n                    Link Cost = S * (1.0625e12 / ifSpeed)\n           where:\n             S = (the value of this object / 100)\n             ifSpeed = interface speed (as defined in the IF-MIB).\n           ')
t11FspfIfStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 2, 1, 20), StorageType().clone('nonVolatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: t11FspfIfStorageType.setDescription("The storage type for this conceptual row.\n            Conceptual rows having the value 'permanent' need not\n            allow write-access to any columnar objects in the row.")
t11FspfIfRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 2, 1, 21), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: t11FspfIfRowStatus.setDescription("The status of the conceptual row.\n\n           This object can be used to create an entry only if there\n           is an entry in the t11FspfTable for the corresponding\n           Fabric, and if the interface is either isolated or is a\n           non-E_port.\n\n           Setting this object to 'destroy' will typically fail;\n           to reverse the creation process, set the corresponding\n           instance of t11FspfIfSetToDefault to 'default'.")
t11FspfLsrTable = MibTable((1, 3, 6, 1, 2, 1, 143, 1, 2, 1), )
if mibBuilder.loadTexts: t11FspfLsrTable.setDescription("This table is the database of all the latest\n           incarnations of the Link State Records (LSRs) that\n           are currently contained in the topology database,\n           for all interfaces on all Fabrics known to\n           locally managed switches.\n\n           A Fabric's topology database contains the LSRs that\n           have been either issued or received by a local switch on\n           that Fabric, and that have not reached t11FspfMaxAge.")
t11FspfLsrEntry = MibTableRow((1, 3, 6, 1, 2, 1, 143, 1, 2, 1, 1), ).setIndexNames((0, "FC-MGMT-MIB", "fcmInstanceIndex"), (0, "FC-MGMT-MIB", "fcmSwitchIndex"), (0, "T11-FC-FSPF-MIB", "t11FspfFabricIndex"), (0, "T11-FC-FSPF-MIB", "t11FspfLsrDomainId"), (0, "T11-FC-FSPF-MIB", "t11FspfLsrType"))
if mibBuilder.loadTexts: t11FspfLsrEntry.setDescription('This gives information for the most recent update of an\n           LSR.  There is one entry for every LSR issued or received\n           by a locally managed switch (identified by\n           fcmInstanceIndex and fcmSwitchIndex) in a Fabric\n           (identified by t11FspfFabricIndex).')
t11FspfLsrDomainId = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 2, 1, 1, 1), FcDomainIdOrZero())
if mibBuilder.loadTexts: t11FspfLsrDomainId.setDescription('Domain Id of the LSR owner in this Fabric.  It is the\n           Link State Id of this LSR.')
t11FspfLsrType = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 2, 1, 1, 2), T11FspfLsrType())
if mibBuilder.loadTexts: t11FspfLsrType.setDescription('Type of this LSR.')
t11FspfLsrAdvDomainId = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 2, 1, 1, 3), FcDomainIdOrZero()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfLsrAdvDomainId.setDescription('Domain Id of the switch that is advertising the LSR on\n           the behalf of the switch owning it.')
t11FspfLsrAge = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 2, 1, 1, 4), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setUnits('Seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfLsrAge.setDescription('The time since this LSR was inserted into the database.')
t11FspfLsrIncarnationNumber = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 2, 1, 1, 5), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,4294967295))).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfLsrIncarnationNumber.setDescription('The link state incarnation number of this LSR.  This is\n           used to identify most recent instance of an LSR while\n           updating the topology database when an LSR is received.\n           The updating of an LSR includes incrementing its\n           incarnation number prior to transmission of the updated\n           LSR.  So, the most recent LSR is the one with the\n           largest incarnation number.')
t11FspfLsrCheckSum = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 2, 1, 1, 6), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfLsrCheckSum.setDescription('The checksum of the LSR.')
t11FspfLsrLinks = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 2, 1, 1, 7), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,65355))).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfLsrLinks.setDescription('Number of entries in the t11FspfLinkTable associated with\n           this LSR.')
t11FspfLinkNumber = MibScalar((1, 3, 6, 1, 2, 1, 143, 1, 2, 3), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,2147483647))).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfLinkNumber.setDescription('The number of rows in the t11FspfLinkTable.')
t11FspfLinkTable = MibTable((1, 3, 6, 1, 2, 1, 143, 1, 2, 4), )
if mibBuilder.loadTexts: t11FspfLinkTable.setDescription('This table contains the list of Inter-Switch Links and\n           their information that is part of an LSR, either\n           received or transmitted.')
t11FspfLinkEntry = MibTableRow((1, 3, 6, 1, 2, 1, 143, 1, 2, 4, 1), ).setIndexNames((0, "FC-MGMT-MIB", "fcmInstanceIndex"), (0, "FC-MGMT-MIB", "fcmSwitchIndex"), (0, "T11-FC-FSPF-MIB", "t11FspfFabricIndex"), (0, "T11-FC-FSPF-MIB", "t11FspfLsrDomainId"), (0, "T11-FC-FSPF-MIB", "t11FspfLsrType"), (0, "T11-FC-FSPF-MIB", "t11FspfLinkIndex"))
if mibBuilder.loadTexts: t11FspfLinkEntry.setDescription('An entry that contains information about a link\n           contained in an LSR in this Fabric.  An entry is created\n           whenever a new link appears in an (issued or received)\n           LSR.  An entry is deleted when a link no longer appears\n           in an (issued or received) LSR.')
t11FspfLinkIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 2, 4, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295)))
if mibBuilder.loadTexts: t11FspfLinkIndex.setDescription('An arbitrary index of this link.')
t11FspfLinkNbrDomainId = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 2, 4, 1, 2), FcDomainIdOrZero()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfLinkNbrDomainId.setDescription('The Domain Id of the neighbor on the other end of this\n           link in this Fabric.')
t11FspfLinkPortIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 2, 4, 1, 3), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,16777215))).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfLinkPortIndex.setDescription("The source E_port of this link, as indicated by the index\n           value in the LSR received from the switch identified by\n           't11FspfLsrDomainId'.")
t11FspfLinkNbrPortIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 2, 4, 1, 4), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,16777215))).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfLinkNbrPortIndex.setDescription("The destination E_port of this link, as indicated by the\n           index value in the LSR received from the switch identified\n           by 't11FspfLinkNbrDomainId'.")
t11FspfLinkType = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 2, 4, 1, 5), T11FspfLinkType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfLinkType.setDescription('The type of this link.')
t11FspfLinkCost = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 2, 4, 1, 6), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfLinkCost.setDescription('The cost of sending a frame on this link in this Fabric.\n           Link cost is calculated using the formula:\n\n                 link cost = S * (1.0625e12 / Signalling Rate)\n\n           For issued LSRs, S is determined by the value of\n           t11FspfIfLinkCostFactor for the corresponding interface\n\n\n\n           and Fabric.')
t11FspfIfPrevNbrState = MibScalar((1, 3, 6, 1, 2, 1, 143, 1, 1, 3), T11FspfInterfaceState()).setMaxAccess("accessiblefornotify")
if mibBuilder.loadTexts: t11FspfIfPrevNbrState.setDescription("The previous state of FSPF's Neighbor Finite State\n           Machine on an interface.\n\n           This object is only used in the\n           't11FspfNbrStateChangNotify' notification.")
t11FspfNbrStateChangNotify = NotificationType((1, 3, 6, 1, 2, 1, 143, 0, 1)).setObjects(*(("T11-FC-FSPF-MIB", "ifIndex"), ("T11-FC-FSPF-MIB", "t11FamConfigDomainId"), ("T11-FC-FSPF-MIB", "t11FspfIfNbrDomainId"), ("T11-FC-FSPF-MIB", "t11FspfIfNbrState"), ("T11-FC-FSPF-MIB", "t11FspfIfPrevNbrState"),))
if mibBuilder.loadTexts: t11FspfNbrStateChangNotify.setDescription("This notification signifies that there has been a change in\n           the state of an FSPF neighbor.  This is generated when the\n           FSPF state changes to a terminal state, through either\n           regression (i.e., goes from Full to Init or Down) or\n           progression (i.e., from any state to Full).  The value of\n           't11FspfIfNbrState' is the state of the neighbor after the\n           change.")
t11FspfMIBCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 143, 2, 1))
t11FspfMIBGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 143, 2, 2))
t11FspfMIBCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 143, 2, 1, 1)).setObjects(*(("T11-FC-FSPF-MIB", "t11FspfGeneralGroup"), ("T11-FC-FSPF-MIB", "t11FspfIfGroup"), ("T11-FC-FSPF-MIB", "t11FspfDatabaseGroup"), ("T11-FC-FSPF-MIB", "t11FspfNotificationGroup"), ("T11-FC-FSPF-MIB", "t11FspfIfCounterGroup"),))
if mibBuilder.loadTexts: t11FspfMIBCompliance.setDescription('The compliance statement for entities that\n           implement the FSPF.')
t11FspfGeneralGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 143, 2, 2, 1)).setObjects(*(("T11-FC-FSPF-MIB", "t11FspfMinLsArrival"), ("T11-FC-FSPF-MIB", "t11FspfMinLsInterval"), ("T11-FC-FSPF-MIB", "t11FspfLsRefreshTime"), ("T11-FC-FSPF-MIB", "t11FspfMaxAge"), ("T11-FC-FSPF-MIB", "t11FspfMaxAgeDiscards"), ("T11-FC-FSPF-MIB", "t11FspfPathComputations"), ("T11-FC-FSPF-MIB", "t11FspfChecksumErrors"), ("T11-FC-FSPF-MIB", "t11FspfLsrs"), ("T11-FC-FSPF-MIB", "t11FspfCreateTime"), ("T11-FC-FSPF-MIB", "t11FspfAdminStatus"), ("T11-FC-FSPF-MIB", "t11FspfOperStatus"), ("T11-FC-FSPF-MIB", "t11FspfNbrStateChangNotifyEnable"), ("T11-FC-FSPF-MIB", "t11FspfSetToDefault"), ("T11-FC-FSPF-MIB", "t11FspfStorageType"),))
if mibBuilder.loadTexts: t11FspfGeneralGroup.setDescription('A collection of objects for displaying and\n           configuring FSPF parameters.')
t11FspfIfGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 143, 2, 2, 2)).setObjects(*(("T11-FC-FSPF-MIB", "t11FspfIfHelloInterval"), ("T11-FC-FSPF-MIB", "t11FspfIfDeadInterval"), ("T11-FC-FSPF-MIB", "t11FspfIfRetransmitInterval"), ("T11-FC-FSPF-MIB", "t11FspfIfNbrState"), ("T11-FC-FSPF-MIB", "t11FspfIfNbrDomainId"), ("T11-FC-FSPF-MIB", "t11FspfIfNbrPortIndex"), ("T11-FC-FSPF-MIB", "t11FspfIfAdminStatus"), ("T11-FC-FSPF-MIB", "t11FspfIfCreateTime"), ("T11-FC-FSPF-MIB", "t11FspfIfSetToDefault"), ("T11-FC-FSPF-MIB", "t11FspfIfLinkCostFactor"), ("T11-FC-FSPF-MIB", "t11FspfIfRowStatus"), ("T11-FC-FSPF-MIB", "t11FspfIfStorageType"), ("T11-FC-FSPF-MIB", "t11FspfIfPrevNbrState"),))
if mibBuilder.loadTexts: t11FspfIfGroup.setDescription('A collection of objects for displaying the FSPF\n           interface information.')
t11FspfIfCounterGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 143, 2, 2, 3)).setObjects(*(("T11-FC-FSPF-MIB", "t11FspfIfInLsuPkts"), ("T11-FC-FSPF-MIB", "t11FspfIfInLsaPkts"), ("T11-FC-FSPF-MIB", "t11FspfIfOutLsuPkts"), ("T11-FC-FSPF-MIB", "t11FspfIfOutLsaPkts"), ("T11-FC-FSPF-MIB", "t11FspfIfOutHelloPkts"), ("T11-FC-FSPF-MIB", "t11FspfIfInHelloPkts"), ("T11-FC-FSPF-MIB", "t11FspfIfRetransmittedLsuPkts"), ("T11-FC-FSPF-MIB", "t11FspfIfInErrorPkts"),))
if mibBuilder.loadTexts: t11FspfIfCounterGroup.setDescription('A collection of objects for counting particular\n            FSPF-packet occurrences on an interface.')
t11FspfDatabaseGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 143, 2, 2, 4)).setObjects(*(("T11-FC-FSPF-MIB", "t11FspfLsrAdvDomainId"), ("T11-FC-FSPF-MIB", "t11FspfLsrAge"), ("T11-FC-FSPF-MIB", "t11FspfLsrIncarnationNumber"), ("T11-FC-FSPF-MIB", "t11FspfLsrCheckSum"), ("T11-FC-FSPF-MIB", "t11FspfLsrLinks"), ("T11-FC-FSPF-MIB", "t11FspfLinkNbrDomainId"), ("T11-FC-FSPF-MIB", "t11FspfLinkPortIndex"), ("T11-FC-FSPF-MIB", "t11FspfLinkNbrPortIndex"), ("T11-FC-FSPF-MIB", "t11FspfLinkType"), ("T11-FC-FSPF-MIB", "t11FspfLinkCost"), ("T11-FC-FSPF-MIB", "t11FspfLinkNumber"),))
if mibBuilder.loadTexts: t11FspfDatabaseGroup.setDescription('A collection of objects for displaying the FSPF\n           topology database information.')
t11FspfNotificationGroup = NotificationGroup((1, 3, 6, 1, 2, 1, 143, 2, 2, 5)).setObjects(*(("T11-FC-FSPF-MIB", "t11FspfNbrStateChangNotify"),))
if mibBuilder.loadTexts: t11FspfNotificationGroup.setDescription('A collection of notifications for FSPF.')
mibBuilder.exportSymbols("T11-FC-FSPF-MIB", T11FspfLinkType=T11FspfLinkType, t11FspfIfAdminStatus=t11FspfIfAdminStatus, t11FspfLinkIndex=t11FspfLinkIndex, t11FspfIfNbrPortIndex=t11FspfIfNbrPortIndex, t11FspfIfRowStatus=t11FspfIfRowStatus, t11FspfIfInErrorPkts=t11FspfIfInErrorPkts, t11FspfLsrIncarnationNumber=t11FspfLsrIncarnationNumber, t11FspfIfOutHelloPkts=t11FspfIfOutHelloPkts, t11FspfLinkTable=t11FspfLinkTable, t11FspfLinkEntry=t11FspfLinkEntry, t11FspfFabricIndex=t11FspfFabricIndex, T11FspfInterfaceState=T11FspfInterfaceState, t11FspfMinLsInterval=t11FspfMinLsInterval, t11FspfEntry=t11FspfEntry, t11FspfIfNbrDomainId=t11FspfIfNbrDomainId, t11FspfMIBCompliance=t11FspfMIBCompliance, t11FspfLinkType=t11FspfLinkType, t11FspfAdminStatus=t11FspfAdminStatus, t11FspfIfRetransmitInterval=t11FspfIfRetransmitInterval, t11FspfMIBCompliances=t11FspfMIBCompliances, t11FspfLsrLinks=t11FspfLsrLinks, t11FspfMinLsArrival=t11FspfMinLsArrival, t11FspfLinkNbrPortIndex=t11FspfLinkNbrPortIndex, t11FspfIfOutLsuPkts=t11FspfIfOutLsuPkts, t11FspfMaxAgeDiscards=t11FspfMaxAgeDiscards, t11FspfIfDeadInterval=t11FspfIfDeadInterval, t11FspfLsrAge=t11FspfLsrAge, t11FspfLinkCost=t11FspfLinkCost, t11FcFspfMIB=t11FcFspfMIB, t11FspfChecksumErrors=t11FspfChecksumErrors, t11FspfIfEntry=t11FspfIfEntry, t11FspfLinkNumber=t11FspfLinkNumber, t11FspfIfIndex=t11FspfIfIndex, t11FspfIfHelloInterval=t11FspfIfHelloInterval, PYSNMP_MODULE_ID=t11FcFspfMIB, t11FspfCreateTime=t11FspfCreateTime, t11FspfStorageType=t11FspfStorageType, t11FspfIfTable=t11FspfIfTable, t11FspfIfNbrState=t11FspfIfNbrState, t11FspfLsrAdvDomainId=t11FspfLsrAdvDomainId, t11FspfIfSetToDefault=t11FspfIfSetToDefault, t11FspfGeneralGroup=t11FspfGeneralGroup, t11FspfIfOutLsaPkts=t11FspfIfOutLsaPkts, t11FspfNotificationGroup=t11FspfNotificationGroup, t11FspfIfPrevNbrState=t11FspfIfPrevNbrState, t11FspfPathComputations=t11FspfPathComputations, t11FspfTable=t11FspfTable, t11FspfIfInLsuPkts=t11FspfIfInLsuPkts, t11FspfIfLinkCostFactor=t11FspfIfLinkCostFactor, t11FspfIfGroup=t11FspfIfGroup, t11FspfLsrDomainId=t11FspfLsrDomainId, t11FspfLsrType=t11FspfLsrType, t11FspfNbrStateChangNotify=t11FspfNbrStateChangNotify, t11FspfLinkNbrDomainId=t11FspfLinkNbrDomainId, t11FspfLinkPortIndex=t11FspfLinkPortIndex, T11FspfLastCreationTime=T11FspfLastCreationTime, t11FspfObjects=t11FspfObjects, t11FspfNotifications=t11FspfNotifications, t11FspfMaxAge=t11FspfMaxAge, t11FspfIfRetransmittedLsuPkts=t11FspfIfRetransmittedLsuPkts, t11FspfLsrEntry=t11FspfLsrEntry, t11FspfNbrStateChangNotifyEnable=t11FspfNbrStateChangNotifyEnable, t11FspfLsrTable=t11FspfLsrTable, t11FspfLsrs=t11FspfLsrs, t11FspfLsrCheckSum=t11FspfLsrCheckSum, t11FspfDatabaseGroup=t11FspfDatabaseGroup, t11FspfIfStorageType=t11FspfIfStorageType, t11FspfSetToDefault=t11FspfSetToDefault, t11FspfIfInHelloPkts=t11FspfIfInHelloPkts, t11FspfIfInLsaPkts=t11FspfIfInLsaPkts, t11FspfIfCreateTime=t11FspfIfCreateTime, T11FspfLsrType=T11FspfLsrType, t11FspfConformance=t11FspfConformance, t11FspfMIBGroups=t11FspfMIBGroups, t11FspfIfCounterGroup=t11FspfIfCounterGroup, t11FspfDatabase=t11FspfDatabase, t11FspfConfiguration=t11FspfConfiguration, t11FspfOperStatus=t11FspfOperStatus, t11FspfLsRefreshTime=t11FspfLsRefreshTime)
