#
# PySNMP MIB module DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:09:52 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( ObjectIdentifier, Integer, OctetString, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "Integer", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueRangeConstraint, SingleValueConstraint, ConstraintsIntersection, ConstraintsUnion, ValueSizeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueRangeConstraint", "SingleValueConstraint", "ConstraintsIntersection", "ConstraintsUnion", "ValueSizeConstraint")
( docsDevEvLevel, docsDevServerTime, docsDevSwServer, docsDevEvText, docsDevSwFilename, docsDevServerDhcp, docsDevEvId, ) = mibBuilder.importSymbols("DOCS-CABLE-DEVICE-MIB", "docsDevEvLevel", "docsDevServerTime", "docsDevSwServer", "docsDevEvText", "docsDevSwFilename", "docsDevServerDhcp", "docsDevEvId")
( docsIfCmStatusModulationType, docsIfCmStatusDocsisOperMode, docsIfCmtsCmStatusMacAddress, docsIfCmtsCmStatusDocsisRegMode, docsIfDocsisBaseCapability, docsIfCmCmtsAddress, docsIfCmtsCmStatusModulationType, ) = mibBuilder.importSymbols("DOCS-IF-MIB", "docsIfCmStatusModulationType", "docsIfCmStatusDocsisOperMode", "docsIfCmtsCmStatusMacAddress", "docsIfCmtsCmStatusDocsisRegMode", "docsIfDocsisBaseCapability", "docsIfCmCmtsAddress", "docsIfCmtsCmStatusModulationType")
( ifPhysAddress, ) = mibBuilder.importSymbols("IF-MIB", "ifPhysAddress")
( ObjectGroup, ModuleCompliance, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ObjectGroup", "ModuleCompliance", "NotificationGroup")
( ModuleIdentity, MibIdentifier, Integer32, Counter64, Gauge32, IpAddress, Bits, MibScalar, MibTable, MibTableRow, MibTableColumn, NotificationType, ObjectIdentity, iso, TimeTicks, mib_2, Unsigned32, Counter32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "ModuleIdentity", "MibIdentifier", "Integer32", "Counter64", "Gauge32", "IpAddress", "Bits", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "NotificationType", "ObjectIdentity", "iso", "TimeTicks", "mib-2", "Unsigned32", "Counter32")
( DisplayString, TextualConvention, ) = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString", "TextualConvention")
docsDevNotifMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 132)).setRevisions(("2006-05-24 00:00",))
if mibBuilder.loadTexts: docsDevNotifMIB.setLastUpdated('200605240000Z')
if mibBuilder.loadTexts: docsDevNotifMIB.setOrganization('IETF IP over Cable Data Network\n                         Working Group')
if mibBuilder.loadTexts: docsDevNotifMIB.setContactInfo('        Azlina Ahmad\n             Postal: Cisco Systems, Inc.\n                     170 West Tasman Drive\n                     San Jose, CA 95134, U.S.A.\n             Phone:   408 853 7927\n             E-mail: azlina@cisco.com\n\n                     Greg Nakanishi\n             Postal: Motorola\n                     6450 Sequence Drive\n                     San Diego, CA 92121, U.S.A.\n             Phone:   858 404 2366\n             E-mail: gnakanishi@motorola.com\n\n             IETF IPCDN Working Group\n             General Discussion: ipcdn@ietf.org\n\n\n\n             Subscribe: http://www.ietf.org/mailman/listinfo/ipcdn\n             Archive: ftp://ftp.ietf.org/ietf-mail-archive/ipcdn\n             Co-chairs: Richard Woundy,\n                          richard_woundy@cable.comcast.com\n                        Jean-Francois Mule, jf.mule@cablelabs.com')
if mibBuilder.loadTexts: docsDevNotifMIB.setDescription('The Event Notification MIB is an extension of the\n            CABLE DEVICE MIB.  It defines various notification\n            objects for both cable modem and cable modem termination\n            systems.  Two groups of SNMP notification objects are\n            defined.  One group is for notifying cable modem events,\n            and one group is for notifying cable modem termination\n            system events.\n\n            DOCSIS defines numerous events, and each event is\n            assigned to a functional category.  This MIB defines\n            a notification object for each functional category.\n            The varbinding list of each notification includes\n            information about the event that occurred on the\n            device.\n\n            Copyright (C) The Internet Society (2006).  This version\n            of this MIB module is part of RFC 4547; see the RFC\n            itself for full legal notices.')
docsDevNotifControl = MibIdentifier((1, 3, 6, 1, 2, 1, 132, 1))
docsDevCmNotifs = MibIdentifier((1, 3, 6, 1, 2, 1, 132, 2, 0))
docsDevCmtsNotifs = MibIdentifier((1, 3, 6, 1, 2, 1, 132, 3, 0))
docsDevCmNotifControl = MibScalar((1, 3, 6, 1, 2, 1, 132, 1, 1), Bits().clone(namedValues=NamedValues(("cmInitTLVUnknownNotif", 0), ("cmDynServReqFailNotif", 1), ("cmDynServRspFailNotif", 2), ("cmDynServAckFailNotif", 3), ("cmBpiInitNotif", 4), ("cmBPKMNotif", 5), ("cmDynamicSANotif", 6), ("cmDHCPFailNotif", 7), ("cmSwUpgradeInitNotif", 8), ("cmSwUpgradeFailNotif", 9), ("cmSwUpgradeSuccessNotif", 10), ("cmSwUpgradeCVCNotif", 11), ("cmTODFailNotif", 12), ("cmDCCReqFailNotif", 13), ("cmDCCRspFailNotif", 14), ("cmDCCAckFailNotif", 15),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: docsDevCmNotifControl.setDescription('The object is used to enable specific CM notifications.\n        For example, if the first bit is set, then\n        docsDevCmInitTLVUnknownNotif is enabled.  If it is not set,\n        the notification is disabled.  Note that notifications are\n        also under the control of the MIB modules defined in\n        RFC3413.\n\n        If the device is rebooted,the value of this object SHOULD\n        revert to the default value.\n       ')
docsDevCmtsNotifControl = MibScalar((1, 3, 6, 1, 2, 1, 132, 1, 2), Bits().clone(namedValues=NamedValues(("cmtsInitRegReqFailNotif", 0), ("cmtsInitRegRspFailNotif", 1), ("cmtsInitRegAckFailNotif", 2), ("cmtsDynServReqFailNotif", 3), ("cmtsDynServRspFailNotif", 4), ("cmtsDynServAckFailNotif", 5), ("cmtsBpiInitNotif", 6), ("cmtsBPKMNotif", 7), ("cmtsDynamicSANotif", 8), ("cmtsDCCReqFailNotif", 9), ("cmtsDCCRspFailNotif", 10), ("cmtsDCCAckFailNotif", 11),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: docsDevCmtsNotifControl.setDescription('The object is used to enable specific CMTS notifications.\n        For example, if the first bit is set, then\n        docsDevCmtsInitRegRspFailNotif is enabled.  If it is not set,\n        the notification is disabled.  Note that notifications are\n        also under the control of the MIB modules defined in\n        RFC3413.\n\n\n\n\n        If the device is rebooted,the value of this object SHOULD\n        revert to the default value.\n       ')
docsDevCmInitTLVUnknownNotif = NotificationType((1, 3, 6, 1, 2, 1, 132, 2, 0, 1)).setObjects(*(("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvLevel"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvId"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvText"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "ifPhysAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmCmtsAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfDocsisBaseCapability"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmStatusDocsisOperMode"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmStatusModulationType"),))
if mibBuilder.loadTexts: docsDevCmInitTLVUnknownNotif.setDescription('Notification to indicate that an unknown TLV was\n          encountered during the TLV parsing process.\n\n         This notification sends additional information about\n         the event by including the following objects in its\n         varbinding list.\n         - docsDevEvLevel: the priority level associated with the\n           event.\n         - docsDevEvId: the unique identifier of the event that\n           occurred.\n         - docsDevEvText: a textual description of the event.\n         - ifPhysAddress: the MAC address of the cable\n           interface of this cable modem.\n         - docsIfCmCmtsAddress: the MAC address of the CMTS\n           to which the CM is connected (if there is a cable\n           card/interface in the CMTS, then it is actually the\n           MAC address of the cable interface to which it is\n           connected).\n         - docsIfDocsisBaseCapability: the highest\n           version of the DOCSIS specification (1.0, 1.1, 2.0)\n           that the device is capable of supporting.\n         - docsIfCmStatusDocsisOperMode: the QOS level (1.0, 1.1)\n           that the CM is operating in.\n         - docsIfCmStatusModulationType: the upstream modulation\n           methodology used by the CM.\n        ')
docsDevCmDynServReqFailNotif = NotificationType((1, 3, 6, 1, 2, 1, 132, 2, 0, 2)).setObjects(*(("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvLevel"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvId"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvText"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "ifPhysAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmCmtsAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfDocsisBaseCapability"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmStatusDocsisOperMode"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmStatusModulationType"),))
if mibBuilder.loadTexts: docsDevCmDynServReqFailNotif.setDescription('A notification to report the failure of a dynamic service\n         request during the dynamic services process.\n\n         This notification sends additional information about\n         the event by including the following objects in its\n         varbinding list.\n         - docsDevEvLevel: the priority level associated with the\n           event.\n         - docsDevEvId: the unique identifier of the event that\n           occurred.\n         - docsDevEvText: a textual description of the event.\n         - ifPhysAddress: the MAC address of the cable\n           interface of this cable modem.\n         - docsIfCmCmtsAddress: the MAC address of the CMTS\n           to which the CM is connected to (if there is a cable\n           card/interface in the CMTS, then it is actually the\n           MAC address of the cable interface to which it is\n           connected).\n         - docsIfDocsisBaseCapability: the highest\n           version of the DOCSIS specification (1.0, 1.1, 2.0)\n           that the device is capable of supporting.\n         - docsIfCmStatusDocsisOperMode: the QOS level (1.0, 1.1)\n           that the CM is operating in.\n         - docsIfCmStatusModulationType: the upstream modulation\n           methodology used by the CM.\n        ')
docsDevCmDynServRspFailNotif = NotificationType((1, 3, 6, 1, 2, 1, 132, 2, 0, 3)).setObjects(*(("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvLevel"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvId"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvText"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "ifPhysAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmCmtsAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfDocsisBaseCapability"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmStatusDocsisOperMode"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmStatusModulationType"),))
if mibBuilder.loadTexts: docsDevCmDynServRspFailNotif.setDescription(' A notification to report the failure of a dynamic service\n         response during the dynamic services process.\n\n         This notification sends additional information about\n         the event by including the following objects in its\n         varbinding list.\n         - docsDevEvLevel: the priority level associated with the\n           event.\n         - docsDevEvId: the unique identifier of the event that\n           occurred.\n         - docsDevEvText: a textual description of the event.\n         - ifPhysAddress: the MAC address of the cable\n           interface of this cable modem.\n         - docsIfCmCmtsAddress: the MAC address of the CMTS\n           to which the CM is connected (if there is a cable\n           card/interface in the CMTS, then it is actually the\n           MAC address of the cable interface to which it is\n           connected).\n         - docsIfDocsisBaseCapability: the highest\n           version of the DOCSIS specification (1.0, 1.1, 2.0)\n           that the device is capable of supporting.\n         - docsIfCmStatusDocsisOperMode: the QOS level (1.0, 1.1)\n           that the CM is operating in.\n         - docsIfCmStatusModulationType: the upstream modulation\n           methodology used by the CM.\n        ')
docsDevCmDynServAckFailNotif = NotificationType((1, 3, 6, 1, 2, 1, 132, 2, 0, 4)).setObjects(*(("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvLevel"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvId"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvText"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "ifPhysAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmCmtsAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfDocsisBaseCapability"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmStatusDocsisOperMode"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmStatusModulationType"),))
if mibBuilder.loadTexts: docsDevCmDynServAckFailNotif.setDescription('A notification to report the failure of a dynamic service\n         acknowledgement during the dynamic services process.\n\n         This notification sends additional information about\n         the event by including the following objects in its\n         varbinding list.\n         - docsDevEvLevel: the priority level associated with the\n           event.\n         - docsDevEvId: the unique identifier of the event that\n           occurred.\n         - docsDevEvText: a textual description of the event.\n         - ifPhysAddress: the MAC address of the cable\n           interface of this cable modem.\n         - docsIfCmCmtsAddress: the MAC address of the CMTS\n           to which the CM is connected (if there is a cable\n           card/interface in the CMTS, then it is actually the\n           MAC address of the cable interface to which it is\n           connected).\n         - docsIfDocsisBaseCapability: the highest\n           version of the DOCSIS specification (1.0, 1.1, 2.0)\n           that the device is capable of supporting.\n         - docsIfCmStatusDocsisOperMode: the QOS level (1.0, 1.1)\n           that the CM is operating in.\n         - docsIfCmStatusModulationType: the upstream modulation\n           methodology used by the CM.\n        ')
docsDevCmBpiInitNotif = NotificationType((1, 3, 6, 1, 2, 1, 132, 2, 0, 5)).setObjects(*(("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvLevel"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvId"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvText"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "ifPhysAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmCmtsAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfDocsisBaseCapability"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmStatusDocsisOperMode"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmStatusModulationType"),))
if mibBuilder.loadTexts: docsDevCmBpiInitNotif.setDescription('A notification to report the failure of a BPI\n         initialization attempt during the registration process.\n\n         This notification sends additional information about\n         the event by including the following objects in its\n         varbinding list.\n         - docsDevEvLevel: the priority level associated with the\n\n\n\n           event.\n         - docsDevEvId: the unique identifier of the event that\n           occurred.\n         - docsDevEvText: a textual description of the event.\n         - ifPhysAddress: the MAC address of the cable\n           interface of this cable modem.\n         - docsIfCmCmtsAddress: the MAC address of the CMTS\n           to which the CM is connected (if there is a cable\n           card/interface in the CMTS, then it is actually the\n           MAC address of the cable interface to which it is\n           connected).\n         - docsIfDocsisBaseCapability: the highest\n           version of the DOCSIS specification (1.0, 1.1, 2.0)\n           that the device is capable of supporting.\n         - docsIfCmStatusDocsisOperMode: the QOS level (1.0, 1.1)\n           that the CM is operating in.\n         - docsIfCmStatusModulationType: the upstream modulation\n           methodology used by the CM.\n        ')
docsDevCmBPKMNotif = NotificationType((1, 3, 6, 1, 2, 1, 132, 2, 0, 6)).setObjects(*(("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvLevel"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvId"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvText"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "ifPhysAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmCmtsAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfDocsisBaseCapability"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmStatusDocsisOperMode"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmStatusModulationType"),))
if mibBuilder.loadTexts: docsDevCmBPKMNotif.setDescription('A notification to report the failure of a Baseline\n         Privacy Key Management (BPKM) operation.\n\n         This notification sends additional information about\n         the event by including the following objects in its\n         varbinding list.\n         - docsDevEvLevel: the priority level associated with the\n           event.\n         - docsDevEvId: the unique identifier of the event that\n           occurred.\n         - docsDevEvText: a textual description of the event.\n         - ifPhysAddress: the MAC address of the cable\n           interface of this cable modem.\n         - docsIfCmCmtsAddress: the MAC address of the CMTS\n\n\n\n           to which the CM is connected (if there is a cable\n           card/interface in the CMTS, then it is actually the\n           MAC address of the cable interface to which it is\n           connected).\n         - docsIfDocsisBaseCapability: the highest\n           version of the DOCSIS specification (1.0, 1.1, 2.0)\n           that the device is capable of supporting.\n         - docsIfCmStatusDocsisOperMode: the QOS level (1.0, 1.1)\n           that the CM is operating in.\n         - docsIfCmStatusModulationType: the upstream modulation\n           methodology used by the CM.\n        ')
docsDevCmDynamicSANotif = NotificationType((1, 3, 6, 1, 2, 1, 132, 2, 0, 7)).setObjects(*(("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvLevel"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvId"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvText"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "ifPhysAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmCmtsAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfDocsisBaseCapability"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmStatusDocsisOperMode"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmStatusModulationType"),))
if mibBuilder.loadTexts: docsDevCmDynamicSANotif.setDescription('A notification to report the failure of a dynamic security\n         association operation.\n\n         This notification sends additional information about\n         the event by including the following objects in its\n         varbinding list.\n         - docsDevEvLevel: the priority level associated with the\n           event.\n         - docsDevEvId: the unique identifier of the event that\n           occurred.\n         - docsDevEvText: a textual description of the event.\n         - ifPhysAddress: the MAC address of the cable\n           interface of this cable modem.\n         - docsIfCmCmtsAddress: the MAC address of the CMTS\n           to which the CM is connected (if there is a cable\n           card/interface in the CMTS, then it is actually the\n           MAC address of the cable interface to which it is\n           connected).\n         - docsIfDocsisBaseCapability: the highest\n           version of the DOCSIS specification (1.0, 1.1, 2.0)\n           that the device is capable of supporting.\n\n\n\n         - docsIfCmStatusDocsisOperMode: the QOS level (1.0, 1.1)\n           that the CM is operating in.\n         - docsIfCmStatusModulationType: the upstream modulation\n           methodology used by the CM.\n        ')
docsDevCmDHCPFailNotif = NotificationType((1, 3, 6, 1, 2, 1, 132, 2, 0, 8)).setObjects(*(("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvLevel"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvId"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvText"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "ifPhysAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmCmtsAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevServerDhcp"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfDocsisBaseCapability"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmStatusDocsisOperMode"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmStatusModulationType"),))
if mibBuilder.loadTexts: docsDevCmDHCPFailNotif.setDescription('A notification to report the failure of a DHCP operation.\n\n         This notification sends additional information about\n         the event by including the following objects in its\n         varbinding list.\n         - docsDevEvLevel: the priority level associated with the\n           event.\n         - docsDevEvId: the unique identifier of the event that\n           occurred.\n         - docsDevEvText: a textual description of the event.\n         - ifPhysAddress: the MAC address of the cable\n           interface of this cable modem.\n         - docsIfCmCmtsAddress: the MAC address of the CMTS\n           to which the CM is connected (if there is a cable\n           card/interface in the CMTS, then it is actually the\n           MAC address of the cable interface to which it is\n           connected).\n         - docsDevServerDhcp: the IP address of the DHCP server.\n         - docsIfDocsisBaseCapability: the highest\n           version of the DOCSIS specification (1.0, 1.1, 2.0)\n           that the device is capable of supporting.\n         - docsIfCmStatusDocsisOperMode: the QOS level (1.0, 1.1)\n           that the CM is operating in.\n         - docsIfCmStatusModulationType: the upstream modulation\n           methodology used by the CM.\n        ')
docsDevCmSwUpgradeInitNotif = NotificationType((1, 3, 6, 1, 2, 1, 132, 2, 0, 9)).setObjects(*(("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvLevel"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvId"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvText"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "ifPhysAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmCmtsAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevSwFilename"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevSwServer"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfDocsisBaseCapability"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmStatusDocsisOperMode"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmStatusModulationType"),))
if mibBuilder.loadTexts: docsDevCmSwUpgradeInitNotif.setDescription('A notification to indicate that a software upgrade\n         has been initiated on the device.\n\n         This notification sends additional information about\n         the event by including the following objects in its\n         varbinding list.\n         - docsDevEvLevel: the priority level associated with the\n           event.\n         - docsDevEvId: the unique identifier of the event that\n           occurred.\n         - docsDevEvText: a textual description of the event.\n         - ifPhysAddress: the MAC address of the cable\n           interface of this cable modem.\n         - docsIfCmCmtsAddress: the MAC address of the CMTS\n           to which the CM is connected (if there is a cable\n           card/interface in the CMTS, then it is actually the\n           MAC address of the cable interface to which it is\n           connected).\n         - docsIfDocsisBaseCapability: the highest\n           version of the DOCSIS specification (1.0, 1.1, 2.0)\n           that the device is capable of supporting.\n         - docsIfCmStatusDocsisOperMode: the QOS level (1.0, 1.1)\n           that the CM is operating in.\n         - docsIfCmStatusModulationType: the upstream modulation\n           methodology used by the CM.\n        ')
docsDevCmSwUpgradeFailNotif = NotificationType((1, 3, 6, 1, 2, 1, 132, 2, 0, 10)).setObjects(*(("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvLevel"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvId"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvText"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "ifPhysAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmCmtsAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevSwFilename"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevSwServer"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfDocsisBaseCapability"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmStatusDocsisOperMode"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmStatusModulationType"),))
if mibBuilder.loadTexts: docsDevCmSwUpgradeFailNotif.setDescription('A notification to report the failure of a software upgrade\n         attempt.\n\n         This notification sends additional information about\n         the event by including the following objects in its\n         varbinding list.\n         - docsDevEvLevel: the priority level associated with the\n           event.\n         - docsDevEvId: the unique identifier of the event that\n           occurred.\n         - docsDevEvText: a textual description of the event.\n         - ifPhysAddress: the MAC address of the cable\n           interface of this cable modem.\n         - docsIfCmCmtsAddress: the MAC address of the CMTS\n           to which the CM is connected (if there is a cable\n           card/interface in the CMTS, then it is actually the\n           MAC address of the cable interface to which it is\n           connected).\n         - docsDevSwFilename: the software image file name\n         - docsDevSwServer: the IP address of the server that\n           the image is retrieved from.\n         - docsIfDocsisBaseCapability: the highest\n           version of the DOCSIS specification (1.0, 1.1, 2.0)\n           that the device is capable of supporting.\n         - docsIfCmStatusDocsisOperMode: the QOS level (1.0, 1.1)\n           that the CM is operating in.\n         - docsIfCmStatusModulationType: the upstream modulation\n           methodology used by the CM.\n        ')
docsDevCmSwUpgradeSuccessNotif = NotificationType((1, 3, 6, 1, 2, 1, 132, 2, 0, 11)).setObjects(*(("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvLevel"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvId"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvText"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "ifPhysAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmCmtsAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevSwFilename"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevSwServer"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfDocsisBaseCapability"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmStatusDocsisOperMode"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmStatusModulationType"),))
if mibBuilder.loadTexts: docsDevCmSwUpgradeSuccessNotif.setDescription('A notification to report the software upgrade success\n         status.\n\n         This notification sends additional information about\n         the event by including the following objects in its\n         varbinding list.\n         - docsDevEvLevel: the priority level associated with the\n           event.\n         - docsDevEvId: the unique identifier of the event that\n           occurred.\n         - docsDevEvText: a textual description of the event.\n         - ifPhysAddress: the MAC address of the cable\n           interface of this cable modem.\n         - docsIfCmCmtsAddress: the MAC address of the CMTS\n           to which the CM is connected (if there is a cable\n           card/interface in the CMTS, then it is actually the\n           MAC address of the cable interface to which it is\n           connected).\n         - docsDevSwFilename: the software image file name\n         - docsDevSwServer: the IP address of the server that\n           the image is retrieved from.\n         - docsIfDocsisBaseCapability: the highest\n           version of the DOCSIS specification (1.0, 1.1, 2.0)\n           that the device is capable of supporting.\n         - docsIfCmStatusDocsisOperMode: the QOS level (1.0, 1.1)\n           that the CM is operating in.\n         - docsIfCmStatusModulationType: the upstream modulation\n           methodology used by the CM.\n        ')
docsDevCmSwUpgradeCVCFailNotif = NotificationType((1, 3, 6, 1, 2, 1, 132, 2, 0, 12)).setObjects(*(("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvLevel"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvId"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvText"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "ifPhysAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmCmtsAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfDocsisBaseCapability"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmStatusDocsisOperMode"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmStatusModulationType"),))
if mibBuilder.loadTexts: docsDevCmSwUpgradeCVCFailNotif.setDescription('A notification to report that the verification of the\n         code file has failed during a secure software upgrade\n         attempt.\n\n         This notification sends additional information about\n         the event by including the following objects in its\n         varbinding list.\n         - docsDevEvLevel: the priority level associated with the\n           event.\n         - docsDevEvId: the unique identifier of the event that\n           occurred.\n         - docsDevEvText: a textual description of the event.\n         - ifPhysAddress: the MAC address of the cable\n           interface of this cable modem.\n         - docsIfCmCmtsAddress: the MAC address of the CMTS\n           to which the CM is connected (if there is a cable\n           card/interface in the CMTS, then it is actually the\n           MAC address of the cable interface to which it is\n           connected).\n         - docsIfDocsisBaseCapability: the highest\n           version of the DOCSIS specification (1.0, 1.1, 2.0)\n           that the device is capable of supporting.\n         - docsIfCmStatusDocsisOperMode: the QOS level (1.0, 1.1)\n           that the CM is operating in.\n         - docsIfCmStatusModulationType: the upstream modulation\n           methodology used by the CM.\n        ')
docsDevCmTODFailNotif = NotificationType((1, 3, 6, 1, 2, 1, 132, 2, 0, 13)).setObjects(*(("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvLevel"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvId"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvText"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "ifPhysAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmCmtsAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevServerTime"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfDocsisBaseCapability"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmStatusDocsisOperMode"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmStatusModulationType"),))
if mibBuilder.loadTexts: docsDevCmTODFailNotif.setDescription('A notification to report the failure of a time of day\n\n\n\n         operation.\n\n         This notification sends additional information about\n         the event by including the following objects in its\n         varbinding list.\n         - docsDevEvLevel: the priority level associated with the\n           event.\n         - docsDevEvId: the unique identifier of the event that\n           occurred.\n         - docsDevEvText: a textual description of the event.\n         - ifPhysAddress: the MAC address of the cable\n           interface of this cable modem.\n         - docsIfCmCmtsAddress: the MAC address of the CMTS\n           to which the CM is connected (if there is a cable\n           card/interface in the CMTS, then it is actually the\n           MAC address of the cable interface to which it is\n           connected).\n         - docsDevServerTime: the IP address of the time server.\n         - docsIfDocsisBaseCapability: the highest\n           version of the DOCSIS specification (1.0, 1.1, 2.0)\n           that the device is capable of supporting.\n         - docsIfCmStatusDocsisOperMode: the QOS level (1.0, 1.1)\n           that the CM is operating in.\n         - docsIfCmStatusModulationType: the upstream modulation\n           methodology used by the CM.\n        ')
docsDevCmDCCReqFailNotif = NotificationType((1, 3, 6, 1, 2, 1, 132, 2, 0, 14)).setObjects(*(("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvLevel"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvId"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvText"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "ifPhysAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmCmtsAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfDocsisBaseCapability"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmStatusDocsisOperMode"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmStatusModulationType"),))
if mibBuilder.loadTexts: docsDevCmDCCReqFailNotif.setDescription(' A notification to report the failure of a dynamic channel\n         change request during the dynamic channel change process\n         on the CM.\n\n         This notification sends additional information about\n         the event by including the following objects in its\n         varbinding list.\n\n\n\n         - docsDevEvLevel: the priority level associated with the\n           event.\n         - docsDevEvId: the unique identifier of the event that\n           occurred.\n         - docsDevEvText: a textual description of the event.\n         - ifPhysAddress: the MAC address of the cable\n           interface of this cable modem.\n         - docsIfCmCmtsAddress: the MAC address of the CMTS\n           to which the CM is connected (if there is a cable\n           card/interface in the CMTS, then it is actually the\n           MAC address of the cable interface to which it is\n           connected).\n         - docsIfDocsisBaseCapability: the highest\n           version of the DOCSIS specification (1.0, 1.1, 2.0)\n           that the device is capable of supporting.\n         - docsIfCmStatusDocsisOperMode: the QOS level (1.0, 1.1)\n           that the CM is operating in.\n         - docsIfCmStatusModulationType: the upstream modulation\n           methodology used by the CM.\n        ')
docsDevCmDCCRspFailNotif = NotificationType((1, 3, 6, 1, 2, 1, 132, 2, 0, 15)).setObjects(*(("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvLevel"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvId"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvText"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "ifPhysAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmCmtsAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfDocsisBaseCapability"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmStatusDocsisOperMode"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmStatusModulationType"),))
if mibBuilder.loadTexts: docsDevCmDCCRspFailNotif.setDescription('A notification to report the failure of a dynamic channel\n         change response during the dynamic channel\n         change process on the CM.\n\n         This notification sends additional information about\n         the event by including the following objects in its\n         varbinding list.\n         - docsDevEvLevel: the priority level associated with the\n           event.\n         - docsDevEvId: the unique identifier of the event that\n           occurred.\n         - docsDevEvText: a textual description of the event.\n         - ifPhysAddress: the MAC address of the cable\n\n\n\n           interface of this cable modem.\n         - docsIfCmCmtsAddress: the MAC address of the CMTS\n           to which the CM is connected (if there is a cable\n           card/interface in the CMTS, then it is actually the\n           MAC address of the cable interface to which it is\n           connected).\n         - docsIfDocsisBaseCapability: the highest\n           version of the DOCSIS specification (1.0, 1.1, 2.0)\n           that the device is capable of supporting.\n         - docsIfCmStatusDocsisOperMode: the QOS level (1.0, 1.1)\n           that the CM is operating in.\n         - docsIfCmStatusModulationType: the upstream modulation\n           methodology used by the CM.\n        ')
docsDevCmDCCAckFailNotif = NotificationType((1, 3, 6, 1, 2, 1, 132, 2, 0, 16)).setObjects(*(("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvLevel"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvId"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvText"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "ifPhysAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmCmtsAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfDocsisBaseCapability"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmStatusDocsisOperMode"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmStatusModulationType"),))
if mibBuilder.loadTexts: docsDevCmDCCAckFailNotif.setDescription('A notification to report the failure of a dynamic channel\n         change acknowledgement during the dynamic channel\n         change process on the CM.\n\n         This notification sends additional information about\n         the event by including the following objects in its\n\n         varbinding list.\n         - docsDevEvLevel: the priority level associated with the\n           event.\n         - docsDevEvId: the unique identifier of the event that\n           occurred.\n         - docsDevEvText: a textual description of the event.\n         - ifPhysAddress: the MAC address of the cable\n           interface of this cable modem.\n         - docsIfCmCmtsAddress: the MAC address of the CMTS\n           to which the CM is connected (if there is a cable\n           card/interface in the CMTS, then it is actually the\n           MAC address of the cable interface to which it is\n\n\n\n           connected).\n         - docsIfDocsisBaseCapability: the highest\n           version of the DOCSIS specification (1.0, 1.1, 2.0)\n           that the device is capable of supporting.\n         - docsIfCmStatusDocsisOperMode: the QOS level (1.0, 1.1)\n           that the CM is operating in.\n         - docsIfCmtsCmStatusModulationType the upstream modulation\n           methodology used by the CM.\n        ')
docsDevCmtsInitRegReqFailNotif = NotificationType((1, 3, 6, 1, 2, 1, 132, 3, 0, 1)).setObjects(*(("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvLevel"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvId"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvText"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmtsCmStatusMacAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "ifPhysAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmtsCmStatusDocsisRegMode"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfDocsisBaseCapability"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmtsCmStatusModulationType"),))
if mibBuilder.loadTexts: docsDevCmtsInitRegReqFailNotif.setDescription('A notification to report the failure of a registration\n         request from a CM during the CM initialization\n         process that was detected on the CMTS.\n\n         This notification sends additional information about\n         the event by including the following objects in its\n         varbinding list.\n         - docsDevEvLevel: the priority level associated with the\n           event.\n         - docsDevEvId: the unique identifier of the event that\n           occurred.\n         - docsDevEvText: a textual description of the event.\n         - docsIfCmtsCmStatusMacAddress: the MAC address of the CM\n           with which this notification is associated.\n         - ifPhysAddress: the MAC address of the CMTS\n           (if there is a cable card/interface in the CMTS,\n           then it is actually the MAC address of the cable\n           interface that connected to the CM) cable interface\n           connected to the CM.\n         - docsIfCmtsCmStatusDocsisRegMode: the QOS level (1.0, 1.1)\n           that the reporting CM is operating in.\n         - docsIfDocsisBaseCapability: the highest\n           version of the DOCSIS specification (1.0, 1.1, 2.0)\n           that the device is capable of supporting.\n\n\n\n         - docsIfCmtsCmStatusModulationType: the upstream\n           modulation methodology used by the CM.\n        ')
docsDevCmtsInitRegRspFailNotif = NotificationType((1, 3, 6, 1, 2, 1, 132, 3, 0, 2)).setObjects(*(("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvLevel"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvId"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvText"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmtsCmStatusMacAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "ifPhysAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmtsCmStatusDocsisRegMode"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfDocsisBaseCapability"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmtsCmStatusModulationType"),))
if mibBuilder.loadTexts: docsDevCmtsInitRegRspFailNotif.setDescription('A notification to report the failure of a registration\n         response during the CM initialization\n         process that was detected by the CMTS.\n\n         This notification sends additional information about\n         the event by including the following objects in its\n         varbinding list.\n         - docsDevEvLevel: the priority level associated with the\n           event.\n         - docsDevEvId: the unique identifier of the event that\n           occurred.\n         - docsDevEvText: a textual description of the event.\n         - docsIfCmtsCmStatusMacAddress: the MAC address of the CM\n           with which this notification is associated.\n         - ifPhysAddress: the MAC address of the CMTS\n           (if there is a cable card/interface in the CMTS,\n           then it is actually the MAC address of the cable\n           interface that connected to the CM) cable interface\n           connected to the CM.\n         - docsIfCmtsCmStatusDocsisRegMode: the QOS level (1.0, 1.1)\n           that the reporting CM is operating in.\n         - docsIfDocsisBaseCapability: the highest\n           version of the DOCSIS specification (1.0, 1.1, 2.0)\n           that the device is capable of supporting.\n         - docsIfCmtsCmStatusModulationType: the upstream\n           modulation methodology used by the CM.\n        ')
docsDevCmtsInitRegAckFailNotif = NotificationType((1, 3, 6, 1, 2, 1, 132, 3, 0, 3)).setObjects(*(("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvLevel"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvId"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvText"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmtsCmStatusMacAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "ifPhysAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmtsCmStatusDocsisRegMode"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfDocsisBaseCapability"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmtsCmStatusModulationType"),))
if mibBuilder.loadTexts: docsDevCmtsInitRegAckFailNotif.setDescription('A notification to report the failure of a registration\n         acknowledgement from the CM during the CM\n         initialization process that was detected by the CMTS.\n\n         This notification sends additional information about\n         the event by including the following objects in its\n         varbinding list.\n         - docsDevEvLevel: the priority level associated with the\n           event.\n         - docsDevEvId: the unique identifier of the event that\n           occurred.\n         - docsDevEvText: a textual description of the event.\n         - docsIfCmtsCmStatusMacAddress: the MAC address of the CM\n           with which this notification is associated.\n         - ifPhysAddress: the MAC address of the CMTS\n           (if there is a cable card/interface in the CMTS,\n           then it is actually the MAC address of the cable\n           interface that connected to the CM) cable interface\n           connected to the CM.\n         - docsIfCmtsCmStatusDocsisRegMode: the QOS level (1.0, 1.1)\n           that the reporting CM is operating in.\n         - docsIfDocsisBaseCapability: the highest\n           version of the DOCSIS specification (1.0, 1.1, 2.0)\n           that the device is capable of supporting.\n         - docsIfCmtsCmStatusModulationType: the upstream\n           modulation methodology used by the CM.\n        ')
docsDevCmtsDynServReqFailNotif = NotificationType((1, 3, 6, 1, 2, 1, 132, 3, 0, 4)).setObjects(*(("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvLevel"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvId"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvText"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmtsCmStatusMacAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "ifPhysAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmtsCmStatusDocsisRegMode"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfDocsisBaseCapability"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmtsCmStatusModulationType"),))
if mibBuilder.loadTexts: docsDevCmtsDynServReqFailNotif.setDescription('A notification to report the failure of a dynamic service\n         request during the dynamic services process\n         that was detected by the CMTS.\n\n         This notification sends additional information about\n         the event by including the following objects in its\n         varbinding list.\n         - docsDevEvLevel: the priority level associated with the\n           event.\n         - docsDevEvId: the unique identifier of the event that\n           occurred.\n         - docsDevEvText: a textual description of the event.\n         - docsIfCmtsCmStatusMacAddress: the MAC address of the CM\n           with which this notification is associated.\n         - ifPhysAddress: the MAC address of the CMTS\n           (if there is a cable card/interface in the CMTS,\n           then it is actually the MAC address of the cable\n           interface that connected to the CM) cable interface\n           connected to the CM.\n         - docsIfCmtsCmStatusDocsisRegMode: the QOS level (1.0, 1.1)\n           that the reporting CM is operating in.\n         - docsIfDocsisBaseCapability: the highest\n           version of the DOCSIS specification (1.0, 1.1, 2.0)\n           that the device is capable of supporting.\n         - docsIfCmtsCmStatusModulationType: the upstream\n           modulation methodology used by the CM.\n        ')
docsDevCmtsDynServRspFailNotif = NotificationType((1, 3, 6, 1, 2, 1, 132, 3, 0, 5)).setObjects(*(("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvLevel"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvId"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvText"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmtsCmStatusMacAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "ifPhysAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmtsCmStatusDocsisRegMode"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfDocsisBaseCapability"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmtsCmStatusModulationType"),))
if mibBuilder.loadTexts: docsDevCmtsDynServRspFailNotif.setDescription('A notification to report the failure of a dynamic service\n         response during the dynamic services process\n         that was detected by the CMTS.\n\n         This notification sends additional information about\n         the event by including the following objects in its\n         varbinding list.\n         - docsDevEvLevel: the priority level associated with the\n           event.\n         - docsDevEvId: the unique identifier of the event that\n           occurred.\n         - docsDevEvText: a textual description of the event.\n         - docsIfCmtsCmStatusMacAddress: the MAC address of the CM\n           with which this notification is associated.\n         - ifPhysAddress: the MAC address of the CMTS\n           (if there is a cable card/interface in the CMTS,\n           then it is actually the MAC address of the cable\n           interface that connected to the CM) cable interface\n           connected to the CM.\n         - docsIfCmtsCmStatusDocsisRegMode: the QOS level (1.0, 1.1)\n           that the reporting CM is operating in.\n         - docsIfDocsisBaseCapability: the highest\n           version of the DOCSIS specification (1.0, 1.1, 2.0)\n           that the device is capable of supporting.\n         - docsIfCmtsCmStatusModulationType: the upstream\n           modulation methodology used by the CM.\n        ')
docsDevCmtsDynServAckFailNotif = NotificationType((1, 3, 6, 1, 2, 1, 132, 3, 0, 6)).setObjects(*(("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvLevel"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvId"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvText"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmtsCmStatusMacAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "ifPhysAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmtsCmStatusDocsisRegMode"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfDocsisBaseCapability"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmtsCmStatusModulationType"),))
if mibBuilder.loadTexts: docsDevCmtsDynServAckFailNotif.setDescription('A notification to report the failure of a dynamic service\n         acknowledgement during the dynamic services\n         process that was detected by the CMTS.\n\n         This notification sends additional information about\n         the event by including the following objects in its\n\n\n\n         varbinding list.\n         - docsDevEvLevel: the priority level associated with the\n           event.\n         - docsDevEvId: the unique identifier of the event that\n           occurred.\n         - docsDevEvText: a textual description of the event.\n         - docsIfCmtsCmStatusMacAddress: the MAC address of the CM\n           with which this notification is associated.\n         - ifPhysAddress: the MAC address of the CMTS\n           (if there is a cable card/interface in the CMTS,\n           then it is actually the MAC address of the cable\n           interface that connected to the CM) cable interface\n           connected to the CM.\n         - docsIfCmtsCmStatusDocsisRegMode: the QOS level (1.0, 1.1)\n           that the reporting CM is operating in.\n         - docsIfDocsisBaseCapability: the highest\n           version of the DOCSIS specification (1.0, 1.1, 2.0)\n           that the device is capable of supporting.\n         - docsIfCmtsCmStatusModulationType: the upstream\n           modulation methodology used by the CM.\n        ')
docsDevCmtsBpiInitNotif = NotificationType((1, 3, 6, 1, 2, 1, 132, 3, 0, 7)).setObjects(*(("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvLevel"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvId"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvText"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmtsCmStatusMacAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "ifPhysAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmtsCmStatusDocsisRegMode"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfDocsisBaseCapability"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmtsCmStatusModulationType"),))
if mibBuilder.loadTexts: docsDevCmtsBpiInitNotif.setDescription('A notification to report the failure of a BPI\n         initialization attempt during the CM registration process\n         that was detected by the CMTS.\n\n         This notification sends additional information about\n         the event by including the following objects in its\n         varbinding list.\n         - docsDevEvLevel: the priority level associated with the\n           event.\n         - docsDevEvId: the unique identifier of the event that\n           occurred.\n\n\n\n         - docsDevEvText: a textual description of the event.\n         - docsIfCmtsCmStatusMacAddress: the MAC address of the CM\n           with which this notification is associated.\n         - ifPhysAddress: the MAC address of the CMTS\n           (if there is a cable card/interface in the CMTS,\n           then it is actually the MAC address of the cable\n           interface that connected to the CM) cable interface\n           connected to the CM.\n         - docsIfCmtsCmStatusDocsisRegMode: the QOS level (1.0, 1.1)\n           that the reporting CM is operating in.\n         - docsIfDocsisBaseCapability: the highest\n           version of the DOCSIS specification (1.0, 1.1, 2.0)\n           that the device is capable of supporting.\n         - docsIfCmtsCmStatusModulationType: the upstream\n           modulation methodology used by the CM.\n        ')
docsDevCmtsBPKMNotif = NotificationType((1, 3, 6, 1, 2, 1, 132, 3, 0, 8)).setObjects(*(("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvLevel"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvId"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvText"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmtsCmStatusMacAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "ifPhysAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmtsCmStatusDocsisRegMode"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfDocsisBaseCapability"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmtsCmStatusModulationType"),))
if mibBuilder.loadTexts: docsDevCmtsBPKMNotif.setDescription('A notification to report the failure of a BPKM operation\n         that is detected by the CMTS.\n\n         This notification sends additional information about\n         the event by including the following objects in its\n         varbinding list.\n         - docsDevEvLevel: the priority level associated with the\n           event.\n         - docsDevEvId: the unique identifier of the event that\n           occurred.\n         - docsDevEvText: a textual description of the event.\n         - docsIfCmtsCmStatusMacAddress: the MAC address of the CM\n           with which this notification is associated.\n         - ifPhysAddress: the MAC address of the CMTS\n           (if there is a cable card/interface in the CMTS,\n           then it is actually the MAC address of the cable\n           interface that connected to the CM) cable interface\n\n\n\n           connected to the CM.\n         - docsIfCmtsCmStatusDocsisRegMode: the QOS level (1.0, 1.1)\n           that the reporting CM is operating in.\n         - docsIfDocsisBaseCapability: the highest\n           version of the DOCSIS specification (1.0, 1.1, 2.0)\n           that the device is capable of supporting.\n         - docsIfCmtsCmStatusModulationType: the upstream\n           modulation methodology used by the CM.\n        ')
docsDevCmtsDynamicSANotif = NotificationType((1, 3, 6, 1, 2, 1, 132, 3, 0, 9)).setObjects(*(("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvLevel"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvId"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvText"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmtsCmStatusMacAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "ifPhysAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmtsCmStatusDocsisRegMode"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfDocsisBaseCapability"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmtsCmStatusModulationType"),))
if mibBuilder.loadTexts: docsDevCmtsDynamicSANotif.setDescription('A notification to report the failure of a dynamic security\n         association operation that is detected by the CMTS.\n\n         This notification sends additional information about\n         the event by including the following objects in its\n         varbinding list.\n\n         - docsDevEvLevel: the priority level associated with the\n           event.\n         - docsDevEvId: the unique identifier of the event that\n           occurred.\n         - docsDevEvText: a textual description of the event.\n         - docsIfCmtsCmStatusMacAddress: the MAC address of the CM\n           with which this notification is associated.\n         - ifPhysAddress: the MAC address of the CMTS\n           (if there is a cable card/interface in the CMTS,\n           then it is actually the MAC address of the cable\n           interface that connected to the CM) cable interface\n           connected to the CM.\n         - docsIfCmtsCmStatusDocsisRegMode: the QOS level (1.0, 1.1)\n           that the reporting CM is operating in.\n         - docsIfDocsisBaseCapability: the highest\n           version of the DOCSIS specification (1.0, 1.1, 2.0)\n           that the device is capable of supporting.\n\n\n\n         - docsIfCmtsCmStatusModulationType: the upstream\n           modulation methodology used by the CM.\n        ')
docsDevCmtsDCCReqFailNotif = NotificationType((1, 3, 6, 1, 2, 1, 132, 3, 0, 10)).setObjects(*(("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvLevel"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvId"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvText"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmtsCmStatusMacAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "ifPhysAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmtsCmStatusDocsisRegMode"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfDocsisBaseCapability"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmtsCmStatusModulationType"),))
if mibBuilder.loadTexts: docsDevCmtsDCCReqFailNotif.setDescription('A notification to report the failure of a dynamic channel\n         change request during the dynamic channel\n         change process and is detected by the CMTS.\n\n         This notification sends additional information about\n         the event by including the following objects in its\n         varbinding list.\n         - docsDevEvLevel: the priority level associated with the\n           event.\n         - docsDevEvId: the unique identifier of the event that\n           occurred.\n         - docsDevEvText: a textual description of the event.\n         - docsIfCmtsCmStatusMacAddress: the MAC address of the CM\n           with which this notification is associated.\n         - ifPhysAddress: the MAC address of the CMTS\n           (if there is a cable card/interface in the CMTS,\n           then it is actually the MAC address of the cable\n           interface that connected to the CM) cable interface\n           connected to the CM.\n         - docsIfCmtsCmStatusDocsisRegMode: the QOS level (1.0, 1.1)\n           that the reporting CM is operating in.\n         - docsIfDocsisBaseCapability: the highest\n           version of the DOCSIS specification (1.0, 1.1, 2.0)\n           that the device is capable of supporting.\n         - docsIfCmtsCmStatusModulationType: the upstream\n           modulation methodology used by the CM.\n        ')
docsDevCmtsDCCRspFailNotif = NotificationType((1, 3, 6, 1, 2, 1, 132, 3, 0, 11)).setObjects(*(("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvLevel"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvId"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvText"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmtsCmStatusMacAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "ifPhysAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmtsCmStatusDocsisRegMode"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfDocsisBaseCapability"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmtsCmStatusModulationType"),))
if mibBuilder.loadTexts: docsDevCmtsDCCRspFailNotif.setDescription('A notification to report the failure of a dynamic channel\n         change response during the dynamic channel\n         change process and is detected by the CMTS.\n\n         This notification sends additional information about\n         the event by including the following objects in its\n         varbinding list.\n         - docsDevEvLevel: the priority level associated with the\n           event.\n         - docsDevEvId: the unique identifier of the event that\n           occurred.\n         - docsDevEvText: a textual description of the event.\n\n         - docsIfCmtsCmStatusMacAddress: the MAC address of the CM\n           with which this notification is associated.\n         - ifPhysAddress: the MAC address of the CMTS\n           (if there is a cable card/interface in the CMTS,\n           then it is actually the MAC address of the cable\n           interface that connected to the CM) cable interface\n           connected to the CM.\n         - docsIfCmtsCmStatusDocsisRegMode: the QOS level (1.0, 1.1)\n           that the reporting CM is operating in.\n         - docsIfDocsisBaseCapability: the highest\n           version of the DOCSIS specification (1.0, 1.1, 2.0)\n           that the device is capable of supporting.\n         - docsIfCmtsCmStatusModulationType: the upstream\n           modulation methodology used by the CM.\n        ')
docsDevCmtsDCCAckFailNotif = NotificationType((1, 3, 6, 1, 2, 1, 132, 3, 0, 12)).setObjects(*(("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvLevel"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvId"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevEvText"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmtsCmStatusMacAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "ifPhysAddress"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmtsCmStatusDocsisRegMode"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfDocsisBaseCapability"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsIfCmtsCmStatusModulationType"),))
if mibBuilder.loadTexts: docsDevCmtsDCCAckFailNotif.setDescription('A notification to report the failure of a dynamic channel\n         change acknowledgement during the dynamic channel\n         change process and is detected by the CMTS.\n\n         This notification sends additional information about\n         the event by including the following objects in its\n         varbinding list.\n         - docsDevEvLevel: the priority level associated with the\n           event.\n         - docsDevEvId: the unique identifier of the event that\n           occurred.\n         - docsDevEvText: a textual description of the event.\n         - docsIfCmtsCmStatusMacAddress: the MAC address of the CM\n           with which this notification is associated.\n         - ifPhysAddress: the MAC address of the CMTS\n           (if there is a cable card/interface in the CMTS,\n           then it is actually the MAC address of the cable\n           interface that connected to the CM) cable interface\n           connected to the CM.\n         - docsIfCmtsCmStatusDocsisRegMode: the QOS level (1.0, 1.1)\n           that the reporting CM is operating in.\n         - docsIfDocsisBaseCapability: the highest\n           version of the DOCSIS specification (1.0, 1.1, 2.0)\n           that the device is capable of supporting.\n         - docsIfCmtsCmStatusModulationType: the upstream\n           modulation methodology used by the CM.\n        ')
docsDevNotifConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 132, 4))
docsDevNotifGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 132, 4, 1))
docsDevNotifCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 132, 4, 2))
docsDevCmNotifCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 132, 4, 2, 1)).setObjects(*(("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevCmNotifControlGroup"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevCmNotificationGroup"),))
if mibBuilder.loadTexts: docsDevCmNotifCompliance.setDescription('The compliance statement for CM Notifications and Control.')
docsDevCmNotifControlGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 132, 4, 1, 1)).setObjects(*(("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevCmNotifControl"),))
if mibBuilder.loadTexts: docsDevCmNotifControlGroup.setDescription('This group represents objects that allow control\n         over CM Notifications.')
docsDevCmNotificationGroup = NotificationGroup((1, 3, 6, 1, 2, 1, 132, 4, 1, 2)).setObjects(*(("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevCmInitTLVUnknownNotif"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevCmDynServReqFailNotif"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevCmDynServRspFailNotif"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevCmDynServAckFailNotif"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevCmBpiInitNotif"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevCmBPKMNotif"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevCmDynamicSANotif"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevCmDHCPFailNotif"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevCmSwUpgradeInitNotif"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevCmSwUpgradeFailNotif"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevCmSwUpgradeSuccessNotif"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevCmSwUpgradeCVCFailNotif"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevCmTODFailNotif"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevCmDCCReqFailNotif"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevCmDCCRspFailNotif"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevCmDCCAckFailNotif"),))
if mibBuilder.loadTexts: docsDevCmNotificationGroup.setDescription('A collection of CM notifications providing device status\n   and control.')
docsDevCmtsNotifCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 132, 4, 2, 2)).setObjects(*(("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevCmtsNotifControlGroup"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevCmtsNotificationGroup"),))
if mibBuilder.loadTexts: docsDevCmtsNotifCompliance.setDescription('The compliance statement for DOCSIS CMTS Notification\n         and Control.')
docsDevCmtsNotifControlGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 132, 4, 1, 3)).setObjects(*(("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevCmtsNotifControl"),))
if mibBuilder.loadTexts: docsDevCmtsNotifControlGroup.setDescription('This group represents objects that allow control\n         over CMTS Notifications.')
docsDevCmtsNotificationGroup = NotificationGroup((1, 3, 6, 1, 2, 1, 132, 4, 1, 4)).setObjects(*(("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevCmtsInitRegReqFailNotif"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevCmtsInitRegRspFailNotif"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevCmtsInitRegAckFailNotif"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevCmtsDynServReqFailNotif"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevCmtsDynServRspFailNotif"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevCmtsDynServAckFailNotif"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevCmtsBpiInitNotif"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevCmtsBPKMNotif"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevCmtsDynamicSANotif"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevCmtsDCCReqFailNotif"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevCmtsDCCRspFailNotif"), ("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", "docsDevCmtsDCCAckFailNotif"),))
if mibBuilder.loadTexts: docsDevCmtsNotificationGroup.setDescription('A collection of CMTS notifications providing device\n         status and control.')
mibBuilder.exportSymbols("DOCS-IETF-CABLE-DEVICE-NOTIFICATION-MIB", docsDevNotifMIB=docsDevNotifMIB, docsDevCmtsDynServReqFailNotif=docsDevCmtsDynServReqFailNotif, docsDevCmDynServReqFailNotif=docsDevCmDynServReqFailNotif, docsDevCmBPKMNotif=docsDevCmBPKMNotif, docsDevCmInitTLVUnknownNotif=docsDevCmInitTLVUnknownNotif, docsDevCmTODFailNotif=docsDevCmTODFailNotif, docsDevCmtsNotifControl=docsDevCmtsNotifControl, docsDevCmNotifControlGroup=docsDevCmNotifControlGroup, docsDevCmtsDCCAckFailNotif=docsDevCmtsDCCAckFailNotif, docsDevCmBpiInitNotif=docsDevCmBpiInitNotif, docsDevCmDHCPFailNotif=docsDevCmDHCPFailNotif, docsDevCmtsNotifs=docsDevCmtsNotifs, docsDevCmtsBpiInitNotif=docsDevCmtsBpiInitNotif, docsDevCmtsInitRegRspFailNotif=docsDevCmtsInitRegRspFailNotif, docsDevCmDCCRspFailNotif=docsDevCmDCCRspFailNotif, docsDevCmDCCAckFailNotif=docsDevCmDCCAckFailNotif, docsDevNotifConformance=docsDevNotifConformance, docsDevCmtsDCCRspFailNotif=docsDevCmtsDCCRspFailNotif, docsDevCmSwUpgradeCVCFailNotif=docsDevCmSwUpgradeCVCFailNotif, docsDevCmDynamicSANotif=docsDevCmDynamicSANotif, docsDevCmtsInitRegAckFailNotif=docsDevCmtsInitRegAckFailNotif, docsDevCmNotifCompliance=docsDevCmNotifCompliance, docsDevCmSwUpgradeInitNotif=docsDevCmSwUpgradeInitNotif, docsDevNotifGroups=docsDevNotifGroups, docsDevCmtsDynamicSANotif=docsDevCmtsDynamicSANotif, docsDevCmDynServAckFailNotif=docsDevCmDynServAckFailNotif, docsDevCmtsBPKMNotif=docsDevCmtsBPKMNotif, docsDevCmNotifs=docsDevCmNotifs, docsDevCmNotificationGroup=docsDevCmNotificationGroup, docsDevCmNotifControl=docsDevCmNotifControl, docsDevCmDynServRspFailNotif=docsDevCmDynServRspFailNotif, docsDevCmSwUpgradeSuccessNotif=docsDevCmSwUpgradeSuccessNotif, docsDevNotifControl=docsDevNotifControl, PYSNMP_MODULE_ID=docsDevNotifMIB, docsDevCmtsInitRegReqFailNotif=docsDevCmtsInitRegReqFailNotif, docsDevCmtsDCCReqFailNotif=docsDevCmtsDCCReqFailNotif, docsDevCmtsDynServRspFailNotif=docsDevCmtsDynServRspFailNotif, docsDevCmtsNotifCompliance=docsDevCmtsNotifCompliance, docsDevCmtsDynServAckFailNotif=docsDevCmtsDynServAckFailNotif, docsDevCmtsNotificationGroup=docsDevCmtsNotificationGroup, docsDevCmSwUpgradeFailNotif=docsDevCmSwUpgradeFailNotif, docsDevCmDCCReqFailNotif=docsDevCmDCCReqFailNotif, docsDevCmtsNotifControlGroup=docsDevCmtsNotifControlGroup, docsDevNotifCompliances=docsDevNotifCompliances)
