#
# PySNMP MIB module IANA-PRINTER-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/IANA-PRINTER-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:16:04 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( OctetString, Integer, ObjectIdentifier, ) = mibBuilder.importSymbols("ASN1", "OctetString", "Integer", "ObjectIdentifier")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueRangeConstraint, SingleValueConstraint, ConstraintsUnion, ConstraintsIntersection, ValueSizeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueRangeConstraint", "SingleValueConstraint", "ConstraintsUnion", "ConstraintsIntersection", "ValueSizeConstraint")
( ModuleCompliance, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "NotificationGroup")
( ModuleIdentity, Gauge32, Bits, Counter64, Integer32, mib_2, TimeTicks, IpAddress, MibScalar, MibTable, MibTableRow, MibTableColumn, Counter32, MibIdentifier, Unsigned32, ObjectIdentity, iso, NotificationType, ) = mibBuilder.importSymbols("SNMPv2-SMI", "ModuleIdentity", "Gauge32", "Bits", "Counter64", "Integer32", "mib-2", "TimeTicks", "IpAddress", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Counter32", "MibIdentifier", "Unsigned32", "ObjectIdentity", "iso", "NotificationType")
( TextualConvention, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "DisplayString")
ianaPrinterMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 109)).setRevisions(("2011-11-04 00:00", "2010-05-17 00:00", "2010-04-07 00:00", "2009-11-23 00:00", "2009-10-14 00:00", "2009-02-06 00:00", "2005-09-14 00:00", "2004-06-02 00:00",))
if mibBuilder.loadTexts: ianaPrinterMIB.setLastUpdated('201111040000Z')
if mibBuilder.loadTexts: ianaPrinterMIB.setOrganization('IANA')
if mibBuilder.loadTexts: ianaPrinterMIB.setContactInfo('Internet Assigned Numbers Authority\n                  Postal: ICANN\n                          4676 Admiralty Way, Suite 330\n                          Marina del Rey, CA 90292\n\n                  Tel:    +1 310 823 9358\n                  E-Mail: iana&iana.org')
if mibBuilder.loadTexts: ianaPrinterMIB.setDescription('This MIB module defines a set of printing-related\n                  TEXTUAL-CONVENTIONs for use in Printer MIB (RFC 3805),\n                  Finisher MIB (RFC 3806), and other MIBs which need to\n                  specify printing mechanism details.\n\n                  Any additions or changes to the contents of this MIB\n                  module require either publication of an RFC, or\n                  Designated Expert Review as defined in RFC 2434,\n                  Guidelines for Writing an IANA Considerations Section\n                  in RFCs.  The Designated Expert will be selected by\n                  the IESG Area Director(s) of the Applications Area.\n\n                  Copyright (C) The Internet Society (2004). The\n                  initial version of this MIB module was published\n                  in RFC 3805.  For full legal notices see the RFC\n                  itself or see:\n                  http://www.ietf.org/copyrights/ianamib.html')
class PrtCoverStatusTC(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6,))
    namedValues = NamedValues(("other", 1), ("unknown", 2), ("coverOpen", 3), ("coverClosed", 4), ("interlockOpen", 5), ("interlockClosed", 6),)

class PrtGeneralResetTC(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(3, 4, 5, 6,))
    namedValues = NamedValues(("notResetting", 3), ("powerCycleReset", 4), ("resetToNVRAM", 5), ("resetToFactoryDefaults", 6),)

class PrtChannelTypeTC(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46,))
    namedValues = NamedValues(("other", 1), ("unknown", 2), ("chSerialPort", 3), ("chParallelPort", 4), ("chIEEE1284Port", 5), ("chSCSIPort", 6), ("chAppleTalkPAP", 7), ("chLPDServer", 8), ("chNetwareRPrinter", 9), ("chNetwarePServer", 10), ("chPort9100", 11), ("chAppSocket", 12), ("chFTP", 13), ("chTFTP", 14), ("chDLCLLCPort", 15), ("chIBM3270", 16), ("chIBM5250", 17), ("chFax", 18), ("chIEEE1394", 19), ("chTransport1", 20), ("chCPAP", 21), ("chDCERemoteProcCall", 22), ("chONCRemoteProcCall", 23), ("chOLE", 24), ("chNamedPipe", 25), ("chPCPrint", 26), ("chServerMessageBlock", 27), ("chDPMF", 28), ("chDLLAPI", 29), ("chVxDAPI", 30), ("chSystemObjectManager", 31), ("chDECLAT", 32), ("chNPAP", 33), ("chUSB", 34), ("chIRDA", 35), ("chPrintXChange", 36), ("chPortTCP", 37), ("chBidirPortTCP", 38), ("chUNPP", 39), ("chAppleTalkADSP", 40), ("chPortSPX", 41), ("chPortHTTP", 42), ("chNDPS", 43), ("chIPP", 44), ("chSMTP", 45), ("chWSPrint", 46),)

class PrtInterpreterLangFamilyTC(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83,))
    namedValues = NamedValues(("other", 1), ("unknown", 2), ("langPCL", 3), ("langHPGL", 4), ("langPJL", 5), ("langPS", 6), ("langIPDS", 7), ("langPPDS", 8), ("langEscapeP", 9), ("langEpson", 10), ("langDDIF", 11), ("langInterpress", 12), ("langISO6429", 13), ("langLineData", 14), ("langMODCA", 15), ("langREGIS", 16), ("langSCS", 17), ("langSPDL", 18), ("langTEK4014", 19), ("langPDS", 20), ("langIGP", 21), ("langCodeV", 22), ("langDSCDSE", 23), ("langWPS", 24), ("langLN03", 25), ("langCCITT", 26), ("langQUIC", 27), ("langCPAP", 28), ("langDecPPL", 29), ("langSimpleText", 30), ("langNPAP", 31), ("langDOC", 32), ("langimPress", 33), ("langPinwriter", 34), ("langNPDL", 35), ("langNEC201PL", 36), ("langAutomatic", 37), ("langPages", 38), ("langLIPS", 39), ("langTIFF", 40), ("langDiagnostic", 41), ("langPSPrinter", 42), ("langCaPSL", 43), ("langEXCL", 44), ("langLCDS", 45), ("langXES", 46), ("langPCLXL", 47), ("langART", 48), ("langTIPSI", 49), ("langPrescribe", 50), ("langLinePrinter", 51), ("langIDP", 52), ("langXJCL", 53), ("langPDF", 54), ("langRPDL", 55), ("langIntermecIPL", 56), ("langUBIFingerprint", 57), ("langUBIDirectProtocol", 58), ("langFujitsu", 59), ("langCGM", 60), ("langJPEG", 61), ("langCALS1", 62), ("langCALS2", 63), ("langNIRS", 64), ("langC4", 65), ("langXPS", 66), ("langOpenXPS", 67), ("langJDF", 68), ("langJMF", 69), ("langPPML", 70), ("langXHTMLPrint", 71), ("langPDFis", 72), ("langPDF13", 73), ("langPDF14", 74), ("langPDF15", 75), ("langPDF16", 76), ("langPDF17", 77), ("langPS2", 78), ("langPS3", 79), ("langPCL3", 80), ("langPCL3GUI", 81), ("langPCL5e", 82), ("langPCL5c", 83),)

class PrtInputTypeTC(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7,))
    namedValues = NamedValues(("other", 1), ("unknown", 2), ("sheetFeedAutoRemovableTray", 3), ("sheetFeedAutoNonRemovableTray", 4), ("sheetFeedManual", 5), ("continuousRoll", 6), ("continuousFanFold", 7),)

class PrtOutputTypeTC(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7,))
    namedValues = NamedValues(("other", 1), ("unknown", 2), ("removableBin", 3), ("unRemovableBin", 4), ("continuousRollDevice", 5), ("mailBox", 6), ("continuousFanFold", 7),)

class PrtMarkerMarkTechTC(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27,))
    namedValues = NamedValues(("other", 1), ("unknown", 2), ("electrophotographicLED", 3), ("electrophotographicLaser", 4), ("electrophotographicOther", 5), ("impactMovingHeadDotMatrix9pin", 6), ("impactMovingHeadDotMatrix24pin", 7), ("impactMovingHeadDotMatrixOther", 8), ("impactMovingHeadFullyFormed", 9), ("impactBand", 10), ("impactOther", 11), ("inkjetAqueous", 12), ("inkjetSolid", 13), ("inkjetOther", 14), ("pen", 15), ("thermalTransfer", 16), ("thermalSensitive", 17), ("thermalDiffusion", 18), ("thermalOther", 19), ("electroerosion", 20), ("electrostatic", 21), ("photographicMicrofiche", 22), ("photographicImagesetter", 23), ("photographicOther", 24), ("ionDeposition", 25), ("eBeam", 26), ("typesetter", 27),)

class PrtMarkerSuppliesTypeTC(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36,))
    namedValues = NamedValues(("other", 1), ("unknown", 2), ("toner", 3), ("wasteToner", 4), ("ink", 5), ("inkCartridge", 6), ("inkRibbon", 7), ("wasteInk", 8), ("opc", 9), ("developer", 10), ("fuserOil", 11), ("solidWax", 12), ("ribbonWax", 13), ("wasteWax", 14), ("fuser", 15), ("coronaWire", 16), ("fuserOilWick", 17), ("cleanerUnit", 18), ("fuserCleaningPad", 19), ("transferUnit", 20), ("tonerCartridge", 21), ("fuserOiler", 22), ("water", 23), ("wasteWater", 24), ("glueWaterAdditive", 25), ("wastePaper", 26), ("bindingSupply", 27), ("bandingSupply", 28), ("stitchingWire", 29), ("shrinkWrap", 30), ("paperWrap", 31), ("staples", 32), ("inserts", 33), ("covers", 34), ("matteToner", 35), ("matteInk", 36),)

class PrtMediaPathTypeTC(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))
    namedValues = NamedValues(("other", 1), ("unknown", 2), ("longEdgeBindingDuplex", 3), ("shortEdgeBindingDuplex", 4), ("simplex", 5),)

class PrtConsoleColorTC(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8, 9, 10,))
    namedValues = NamedValues(("other", 1), ("unknown", 2), ("white", 3), ("red", 4), ("green", 5), ("blue", 6), ("cyan", 7), ("magenta", 8), ("yellow", 9), ("orange", 10),)

class PrtConsoleDisableTC(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(3, 4,))
    namedValues = NamedValues(("enabled", 3), ("disabled", 4),)

class PrtAlertTrainingLevelTC(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7,))
    namedValues = NamedValues(("other", 1), ("unknown", 2), ("untrained", 3), ("trained", 4), ("fieldService", 5), ("management", 6), ("noInterventionRequired", 7),)

class PrtAlertGroupTC(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 30, 31, 32, 33,))
    namedValues = NamedValues(("other", 1), ("unknown", 2), ("hostResourcesMIBStorageTable", 3), ("hostResourcesMIBDeviceTable", 4), ("generalPrinter", 5), ("cover", 6), ("localization", 7), ("input", 8), ("output", 9), ("marker", 10), ("markerSupplies", 11), ("markerColorant", 12), ("mediaPath", 13), ("channel", 14), ("interpreter", 15), ("consoleDisplayBuffer", 16), ("consoleLights", 17), ("alert", 18), ("finDevice", 30), ("finSupply", 31), ("finSupplyMediaInput", 32), ("finAttribute", 33),)

class PrtAlertCodeTC(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 501, 502, 503, 504, 505, 506, 507, 801, 802, 803, 804, 805, 806, 807, 808, 809, 810, 811, 812, 813, 901, 902, 903, 904, 1001, 1002, 1003, 1004, 1005, 1101, 1102, 1103, 1104, 1105, 1106, 1107, 1108, 1109, 1110, 1111, 1112, 1113, 1114, 1115, 1301, 1302, 1303, 1304, 1501, 1502, 1503, 1504, 1505, 1506, 1507, 1509, 1801, 30203, 30204, 30205, 30206, 30207, 30208, 30209, 30210, 30211, 30212, 30213, 30214, 30215, 30216, 30217, 30218, 30219, 30220, 30221, 30222, 30223, 30224, 30225, 30226, 30227, 30228, 30229, 30230, 30231, 30232, 30233, 30234, 30235, 30236, 30237, 30238, 30303, 30304, 30305, 30306, 30307, 30308, 30309, 30310, 30311, 30312, 30313, 30314, 30315, 30316, 30317, 30318, 30319, 30320, 30321, 30322, 30323, 30324, 30325, 30326, 30327, 30328, 30329, 30330, 30331, 30332, 30333, 30334, 30335, 30336, 30337, 30338, 30403, 30404, 30405, 30406, 30407, 30408, 30409, 30410, 30411, 30412, 30413, 30414, 30415, 30416, 30417, 30418, 30419, 30420, 30421, 30422, 30423, 30424, 30425, 30426, 30427, 30428, 30429, 30430, 30431, 30432, 30433, 30434, 30435, 30436, 30437, 30438, 30503, 30504, 30505, 30506, 30507, 30508, 30509, 30510, 30511, 30512, 30513, 30514, 30515, 30516, 30517, 30518, 30519, 30520, 30521, 30522, 30523, 30524, 30525, 30526, 30527, 30528, 30529, 30530, 30531, 30532, 30533, 30534, 30535, 30536, 30537, 30538, 30603, 30604, 30605, 30606, 30607, 30608, 30609, 30610, 30611, 30612, 30613, 30614, 30615, 30616, 30617, 30618,), SingleValueConstraint(30619, 30620, 30621, 30622, 30623, 30624, 30625, 30626, 30627, 30628, 30629, 30630, 30631, 30632, 30633, 30634, 30635, 30636, 30637, 30638, 30703, 30704, 30705, 30706, 30707, 30708, 30709, 30710, 30711, 30712, 30713, 30714, 30715, 30716, 30717, 30718, 30719, 30720, 30721, 30722, 30723, 30724, 30725, 30726, 30727, 30728, 30729, 30730, 30731, 30732, 30733, 30734, 30735, 30736, 30737, 30738, 30803, 30804, 30805, 30806, 30807, 30808, 30809, 30810, 30811, 30812, 30813, 30814, 30815, 30816, 30817, 30818, 30819, 30820, 30821, 30822, 30823, 30824, 30825, 30826, 30827, 30828, 30829, 30830, 30831, 30832, 30833, 30834, 30835, 30836, 30837, 30838, 30903, 30904, 30905, 30906, 30907, 30908, 30909, 30910, 30911, 30912, 30913, 30914, 30915, 30916, 30917, 30918, 30919, 30920, 30921, 30922, 30923, 30924, 30925, 30926, 30927, 30928, 30929, 30930, 30931, 30932, 30933, 30934, 30935, 30936, 30937, 30938, 31003, 31004, 31005, 31006, 31007, 31008, 31009, 31010, 31011, 31012, 31013, 31014, 31015, 31016, 31017, 31018, 31019, 31020, 31021, 31022, 31023, 31024, 31025, 31026, 31027, 31028, 31029, 31030, 31031, 31032, 31033, 31034, 31035, 31036, 31037, 31038, 31103, 31104, 31105, 31106, 31107, 31108, 31109, 31110, 31111, 31112, 31113, 31114, 31115, 31116, 31117, 31118, 31119, 31120, 31121, 31122, 31123, 31124, 31125, 31126, 31127, 31128, 31129, 31130, 31131, 31132, 31133, 31134, 31135, 31136, 31137, 31138, 31203, 31204, 31205, 31206, 31207, 31208, 31209, 31210, 31211, 31212, 31213, 31214, 31215, 31216, 31217, 31218, 31219, 31220, 31221, 31222, 31223, 31224, 31225, 31226, 31227, 31228, 31229, 31230, 31231, 31232, 31233, 31234, 31235, 31236, 31237, 31238, 31303, 31304, 31305, 31306, 31307, 31308, 31309, 31310, 31311, 31312, 31313, 31314, 31315, 31316, 31317, 31318, 31319, 31320, 31321,), SingleValueConstraint(31322, 31323, 31324, 31325, 31326, 31327, 31328, 31329, 31330, 31331, 31332, 31333, 31334, 31335, 31336, 31337, 31338, 31403, 31404, 31405, 31406, 31407, 31408, 31409, 31410, 31411, 31412, 31413, 31414, 31415, 31416, 31417, 31418, 31419, 31420, 31421, 31422, 31423, 31424, 31425, 31426, 31427, 31428, 31429, 31430, 31431, 31432, 31433, 31434, 31435, 31436, 31437, 31438, 31503, 31504, 31505, 31506, 31507, 31508, 31509, 31510, 31511, 31512, 31513, 31514, 31515, 31516, 31517, 31518, 31519, 31520, 31521, 31522, 31523, 31524, 31525, 31526, 31527, 31528, 31529, 31530, 31531, 31532, 31533, 31534, 31535, 31536, 31537, 31538, 31603, 31604, 31605, 31606, 31607, 31608, 31609, 31610, 31611, 31612, 31613, 31614, 31615, 31616, 31617, 31618, 31619, 31620, 31621, 31622, 31623, 31624, 31625, 31626, 31627, 31628, 31629, 31630, 31631, 31632, 31633, 31634, 31635, 31636, 31637, 31638, 31703, 31704, 31705, 31706, 31707, 31708, 31709, 31710, 31711, 31712, 31713, 31714, 31715, 31716, 31717, 31718, 31719, 31720, 31721, 31722, 31723, 31724, 31725, 31726, 31727, 31728, 31729, 31730, 31731, 31732, 31733, 31734, 31735, 31736, 31737, 31738, 31803, 31804, 31805, 31806, 31807, 31808, 31809, 31810, 31811, 31812, 31813, 31814, 31815, 31816, 31817, 31818, 31819, 31820, 31821, 31822, 31823, 31824, 31825, 31826, 31827, 31828, 31829, 31830, 31831, 31832, 31833, 31834, 31835, 31836, 31837, 31838,))
    namedValues = NamedValues(("other", 1), ("unknown", 2), ("coverOpen", 3), ("coverClosed", 4), ("interlockOpen", 5), ("interlockClosed", 6), ("configurationChange", 7), ("jam", 8), ("subunitMissing", 9), ("subunitLifeAlmostOver", 10), ("subunitLifeOver", 11), ("subunitAlmostEmpty", 12), ("subunitEmpty", 13), ("subunitAlmostFull", 14), ("subunitFull", 15), ("subunitNearLimit", 16), ("subunitAtLimit", 17), ("subunitOpened", 18), ("subunitClosed", 19), ("subunitTurnedOn", 20), ("subunitTurnedOff", 21), ("subunitOffline", 22), ("subunitPowerSaver", 23), ("subunitWarmingUp", 24), ("subunitAdded", 25), ("subunitRemoved", 26), ("subunitResourceAdded", 27), ("subunitResourceRemoved", 28), ("subunitRecoverableFailure", 29), ("subunitUnrecoverableFailure", 30), ("subunitRecoverableStorageError", 31), ("subunitUnrecoverableStorageError", 32), ("subunitMotorFailure", 33), ("subunitMemoryExhausted", 34), ("subunitUnderTemperature", 35), ("subunitOverTemperature", 36), ("subunitTimingFailure", 37), ("subunitThermistorFailure", 38), ("doorOpen", 501), ("doorClosed", 502), ("powerUp", 503), ("powerDown", 504), ("printerNMSReset", 505), ("printerManualReset", 506), ("printerReadyToPrint", 507), ("inputMediaTrayMissing", 801), ("inputMediaSizeChange", 802), ("inputMediaWeightChange", 803), ("inputMediaTypeChange", 804), ("inputMediaColorChange", 805), ("inputMediaFormPartsChange", 806), ("inputMediaSupplyLow", 807), ("inputMediaSupplyEmpty", 808), ("inputMediaChangeRequest", 809), ("inputManualInputRequest", 810), ("inputTrayPositionFailure", 811), ("inputTrayElevationFailure", 812), ("inputCannotFeedSizeSelected", 813), ("outputMediaTrayMissing", 901), ("outputMediaTrayAlmostFull", 902), ("outputMediaTrayFull", 903), ("outputMailboxSelectFailure", 904), ("markerFuserUnderTemperature", 1001), ("markerFuserOverTemperature", 1002), ("markerFuserTimingFailure", 1003), ("markerFuserThermistorFailure", 1004), ("markerAdjustingPrintQuality", 1005), ("markerTonerEmpty", 1101), ("markerInkEmpty", 1102), ("markerPrintRibbonEmpty", 1103), ("markerTonerAlmostEmpty", 1104), ("markerInkAlmostEmpty", 1105), ("markerPrintRibbonAlmostEmpty", 1106), ("markerWasteTonerReceptacleAlmostFull", 1107), ("markerWasteInkReceptacleAlmostFull", 1108), ("markerWasteTonerReceptacleFull", 1109), ("markerWasteInkReceptacleFull", 1110), ("markerOpcLifeAlmostOver", 1111), ("markerOpcLifeOver", 1112), ("markerDeveloperAlmostEmpty", 1113), ("markerDeveloperEmpty", 1114), ("markerTonerCartridgeMissing", 1115), ("mediaPathMediaTrayMissing", 1301), ("mediaPathMediaTrayAlmostFull", 1302), ("mediaPathMediaTrayFull", 1303), ("mediaPathCannotDuplexMediaSelected", 1304), ("interpreterMemoryIncrease", 1501), ("interpreterMemoryDecrease", 1502), ("interpreterCartridgeAdded", 1503), ("interpreterCartridgeDeleted", 1504), ("interpreterResourceAdded", 1505), ("interpreterResourceDeleted", 1506), ("interpreterResourceUnavailable", 1507), ("interpreterComplexPageEncountered", 1509), ("alertRemovalOfBinaryChangeEntry", 1801), ("staplerCoverOpen", 30203), ("staplerCoverClosed", 30204), ("staplerInterlockOpen", 30205), ("staplerInterlockClosed", 30206), ("staplerConfigurationChange", 30207), ("staplerJam", 30208), ("staplerMissing", 30209), ("staplerLifeAlmostOver", 30210), ("staplerLifeOver", 30211), ("staplerAlmostEmpty", 30212), ("staplerEmpty", 30213), ("staplerAlmostFull", 30214), ("staplerFull", 30215), ("staplerNearLimit", 30216), ("staplerAtLimit", 30217), ("staplerOpened", 30218), ("staplerClosed", 30219), ("staplerTurnedOn", 30220), ("staplerTurnedOff", 30221), ("staplerOffline", 30222), ("staplerPowerSaver", 30223), ("staplerWarmingUp", 30224), ("staplerAdded", 30225), ("staplerRemoved", 30226), ("staplerResourceAdded", 30227), ("staplerResourceRemoved", 30228), ("staplerRecoverableFailure", 30229), ("staplerUnrecoverableFailure", 30230), ("staplerRecoverableStorageError", 30231), ("staplerUnrecoverableStorageError", 30232), ("staplerMotorFailure", 30233), ("staplerMemoryExhausted", 30234), ("staplerUnderTemperature", 30235), ("staplerOverTemperature", 30236), ("staplerTimingFailure", 30237), ("staplerThermistorFailure", 30238), ("stitcherCoverOpen", 30303), ("stitcherCoverClosed", 30304), ("stitcherInterlockOpen", 30305), ("stitcherInterlockClosed", 30306), ("stitcherConfigurationChange", 30307), ("stitcherJam", 30308), ("stitcherMissing", 30309), ("stitcherLifeAlmostOver", 30310), ("stitcherLifeOver", 30311), ("stitcherAlmostEmpty", 30312), ("stitcherEmpty", 30313), ("stitcherAlmostFull", 30314), ("stitcherFull", 30315), ("stitcherNearLimit", 30316), ("stitcherAtLimit", 30317), ("stitcherOpened", 30318), ("stitcherClosed", 30319), ("stitcherTurnedOn", 30320), ("stitcherTurnedOff", 30321), ("stitcherOffline", 30322), ("stitcherPowerSaver", 30323), ("stitcherWarmingUp", 30324), ("stitcherAdded", 30325), ("stitcherRemoved", 30326), ("stitcherResourceAdded", 30327), ("stitcherResourceRemoved", 30328), ("stitcherRecoverableFailure", 30329), ("stitcherUnrecoverableFailure", 30330), ("stitcherRecoverableStorageError", 30331), ("stitcherUnrecoverableStorageError", 30332), ("stitcherMotorFailure", 30333), ("stitcherMemoryExhausted", 30334), ("stitcherUnderTemperature", 30335), ("stitcherOverTemperature", 30336), ("stitcherTimingFailure", 30337), ("stitcherThermistorFailure", 30338), ("folderCoverOpen", 30403), ("folderCoverClosed", 30404), ("folderInterlockOpen", 30405), ("folderInterlockClosed", 30406), ("folderConfigurationChange", 30407), ("folderJam", 30408), ("folderMissing", 30409), ("folderLifeAlmostOver", 30410), ("folderLifeOver", 30411), ("folderAlmostEmpty", 30412), ("folderEmpty", 30413), ("folderAlmostFull", 30414), ("folderFull", 30415), ("folderNearLimit", 30416), ("folderAtLimit", 30417), ("folderOpened", 30418), ("folderClosed", 30419), ("folderTurnedOn", 30420), ("folderTurnedOff", 30421), ("folderOffline", 30422), ("folderPowerSaver", 30423), ("folderWarmingUp", 30424), ("folderAdded", 30425), ("folderRemoved", 30426), ("folderResourceAdded", 30427), ("folderResourceRemoved", 30428), ("folderRecoverableFailure", 30429), ("folderUnrecoverableFailure", 30430), ("folderRecoverableStorageError", 30431), ("folderUnrecoverableStorageError", 30432), ("folderMotorFailure", 30433), ("folderMemoryExhausted", 30434), ("folderUnderTemperature", 30435), ("folderOverTemperature", 30436), ("folderTimingFailure", 30437), ("folderThermistorFailure", 30438), ("binderCoverOpen", 30503), ("binderCoverClosed", 30504), ("binderInterlockOpen", 30505), ("binderInterlockClosed", 30506), ("binderConfigurationChange", 30507), ("binderJam", 30508), ("binderMissing", 30509), ("binderLifeAlmostOver", 30510), ("binderLifeOver", 30511), ("binderAlmostEmpty", 30512), ("binderEmpty", 30513), ("binderAlmostFull", 30514), ("binderFull", 30515), ("binderNearLimit", 30516), ("binderAtLimit", 30517), ("binderOpened", 30518), ("binderClosed", 30519), ("binderTurnedOn", 30520), ("binderTurnedOff", 30521), ("binderOffline", 30522), ("binderPowerSaver", 30523), ("binderWarmingUp", 30524), ("binderAdded", 30525), ("binderRemoved", 30526), ("binderResourceAdded", 30527), ("binderResourceRemoved", 30528), ("binderRecoverableFailure", 30529), ("binderUnrecoverableFailure", 30530), ("binderRecoverableStorageError", 30531), ("binderUnrecoverableStorageError", 30532), ("binderMotorFailure", 30533), ("binderMemoryExhausted", 30534), ("binderUnderTemperature", 30535), ("binderOverTemperature", 30536), ("binderTimingFailure", 30537), ("binderThermistorFailure", 30538), ("trimmerCoverOpen", 30603), ("trimmerCoverClosed", 30604), ("trimmerInterlockOpen", 30605), ("trimmerInterlockClosed", 30606), ("trimmerConfigurationChange", 30607), ("trimmerJam", 30608), ("trimmerMissing", 30609), ("trimmerLifeAlmostOver", 30610), ("trimmerLifeOver", 30611), ("trimmerAlmostEmpty", 30612), ("trimmerEmpty", 30613), ("trimmerAlmostFull", 30614), ("trimmerFull", 30615), ("trimmerNearLimit", 30616), ("trimmerAtLimit", 30617), ("trimmerOpened", 30618),) + NamedValues(("trimmerClosed", 30619), ("trimmerTurnedOn", 30620), ("trimmerTurnedOff", 30621), ("trimmerOffline", 30622), ("trimmerPowerSaver", 30623), ("trimmerWarmingUp", 30624), ("trimmerAdded", 30625), ("trimmerRemoved", 30626), ("trimmerResourceAdded", 30627), ("trimmerResourceRemoved", 30628), ("trimmerRecoverableFailure", 30629), ("trimmerUnrecoverableFailure", 30630), ("trimmerRecoverableStorageError", 30631), ("trimmerUnrecoverableStorageError", 30632), ("trimmerMotorFailure", 30633), ("trimmerMemoryExhausted", 30634), ("trimmerUnderTemperature", 30635), ("trimmerOverTemperature", 30636), ("trimmerTimingFailure", 30637), ("trimmerThermistorFailure", 30638), ("dieCutterCoverOpen", 30703), ("dieCutterCoverClosed", 30704), ("dieCutterInterlockOpen", 30705), ("dieCutterInterlockClosed", 30706), ("dieCutterConfigurationChange", 30707), ("dieCutterJam", 30708), ("dieCutterMissing", 30709), ("dieCutterLifeAlmostOver", 30710), ("dieCutterLifeOver", 30711), ("dieCutterAlmostEmpty", 30712), ("dieCutterEmpty", 30713), ("dieCutterAlmostFull", 30714), ("dieCutterFull", 30715), ("dieCutterNearLimit", 30716), ("dieCutterAtLimit", 30717), ("dieCutterOpened", 30718), ("dieCutterClosed", 30719), ("dieCutterTurnedOn", 30720), ("dieCutterTurnedOff", 30721), ("dieCutterOffline", 30722), ("dieCutterPowerSaver", 30723), ("dieCutterWarmingUp", 30724), ("dieCutterAdded", 30725), ("dieCutterRemoved", 30726), ("dieCutterResourceAdded", 30727), ("dieCutterResourceRemoved", 30728), ("dieCutterRecoverableFailure", 30729), ("dieCutterUnrecoverableFailure", 30730), ("dieCutterRecoverableStorageError", 30731), ("dieCutterUnrecoverableStorageError", 30732), ("dieCutterMotorFailure", 30733), ("dieCutterMemoryExhausted", 30734), ("dieCutterUnderTemperature", 30735), ("dieCutterOverTemperature", 30736), ("dieCutterTimingFailure", 30737), ("dieCutterThermistorFailure", 30738), ("puncherCoverOpen", 30803), ("puncherCoverClosed", 30804), ("puncherInterlockOpen", 30805), ("puncherInterlockClosed", 30806), ("puncherConfigurationChange", 30807), ("puncherJam", 30808), ("puncherMissing", 30809), ("puncherLifeAlmostOver", 30810), ("puncherLifeOver", 30811), ("puncherAlmostEmpty", 30812), ("puncherEmpty", 30813), ("puncherAlmostFull", 30814), ("puncherFull", 30815), ("puncherNearLimit", 30816), ("puncherAtLimit", 30817), ("puncherOpened", 30818), ("puncherClosed", 30819), ("puncherTurnedOn", 30820), ("puncherTurnedOff", 30821), ("puncherOffline", 30822), ("puncherPowerSaver", 30823), ("puncherWarmingUp", 30824), ("puncherAdded", 30825), ("puncherRemoved", 30826), ("puncherResourceAdded", 30827), ("puncherResourceRemoved", 30828), ("puncherRecoverableFailure", 30829), ("puncherUnrecoverableFailure", 30830), ("puncherRecoverableStorageError", 30831), ("puncherUnrecoverableStorageError", 30832), ("puncherMotorFailure", 30833), ("puncherMemoryExhausted", 30834), ("puncherUnderTemperature", 30835), ("puncherOverTemperature", 30836), ("puncherTimingFailure", 30837), ("puncherThermistorFailure", 30838), ("perforaterCoverOpen", 30903), ("perforaterCoverClosed", 30904), ("perforaterInterlockOpen", 30905), ("perforaterInterlockClosed", 30906), ("perforaterConfigurationChange", 30907), ("perforaterJam", 30908), ("perforaterMissing", 30909), ("perforaterLifeAlmostOver", 30910), ("perforaterLifeOver", 30911), ("perforaterAlmostEmpty", 30912), ("perforaterEmpty", 30913), ("perforaterAlmostFull", 30914), ("perforaterFull", 30915), ("perforaterNearLimit", 30916), ("perforaterAtLimit", 30917), ("perforaterOpened", 30918), ("perforaterClosed", 30919), ("perforaterTurnedOn", 30920), ("perforaterTurnedOff", 30921), ("perforaterOffline", 30922), ("perforaterPowerSaver", 30923), ("perforaterWarmingUp", 30924), ("perforaterAdded", 30925), ("perforaterRemoved", 30926), ("perforaterResourceAdded", 30927), ("perforaterResourceRemoved", 30928), ("perforaterRecoverableFailure", 30929), ("perforaterUnrecoverableFailure", 30930), ("perforaterRecoverableStorageError", 30931), ("perforaterUnrecoverableStorageError", 30932), ("perforaterMotorFailure", 30933), ("perforaterMemoryExhausted", 30934), ("perforaterUnderTemperature", 30935), ("perforaterOverTemperature", 30936), ("perforaterTimingFailure", 30937), ("perforaterThermistorFailure", 30938), ("slitterCoverOpen", 31003), ("slitterCoverClosed", 31004), ("slitterInterlockOpen", 31005), ("slitterInterlockClosed", 31006), ("slitterConfigurationChange", 31007), ("slitterJam", 31008), ("slitterMissing", 31009), ("slitterLifeAlmostOver", 31010), ("slitterLifeOver", 31011), ("slitterAlmostEmpty", 31012), ("slitterEmpty", 31013), ("slitterAlmostFull", 31014), ("slitterFull", 31015), ("slitterNearLimit", 31016), ("slitterAtLimit", 31017), ("slitterOpened", 31018), ("slitterClosed", 31019), ("slitterTurnedOn", 31020), ("slitterTurnedOff", 31021), ("slitterOffline", 31022), ("slitterPowerSaver", 31023), ("slitterWarmingUp", 31024), ("slitterAdded", 31025), ("slitterRemoved", 31026), ("slitterResourceAdded", 31027), ("slitterResourceRemoved", 31028), ("slitterRecoverableFailure", 31029), ("slitterUnrecoverableFailure", 31030), ("slitterRecoverableStorageError", 31031), ("slitterUnrecoverableStorageError", 31032), ("slitterMotorFailure", 31033), ("slitterMemoryExhausted", 31034), ("slitterUnderTemperature", 31035), ("slitterOverTemperature", 31036), ("slitterTimingFailure", 31037), ("slitterThermistorFailure", 31038), ("separationCutterCoverOpen", 31103), ("separationCutterCoverClosed", 31104), ("separationCutterInterlockOpen", 31105), ("separationCutterInterlockClosed", 31106), ("separationCutterConfigurationChange", 31107), ("separationCutterJam", 31108), ("separationCutterMissing", 31109), ("separationCutterLifeAlmostOver", 31110), ("separationCutterLifeOver", 31111), ("separationCutterAlmostEmpty", 31112), ("separationCutterEmpty", 31113), ("separationCutterAlmostFull", 31114), ("separationCutterFull", 31115), ("separationCutterNearLimit", 31116), ("separationCutterAtLimit", 31117), ("separationCutterOpened", 31118), ("separationCutterClosed", 31119), ("separationCutterTurnedOn", 31120), ("separationCutterTurnedOff", 31121), ("separationCutterOffline", 31122), ("separationCutterPowerSaver", 31123), ("separationCutterWarmingUp", 31124), ("separationCutterAdded", 31125), ("separationCutterRemoved", 31126), ("separationCutterResourceAdded", 31127), ("separationCutterResourceRemoved", 31128), ("separationCutterRecoverableFailure", 31129), ("separationCutterUnrecoverableFailure", 31130), ("separationCutterRecoverableStorageError", 31131), ("separationCutterUnrecoverableStorageError", 31132), ("separationCutterMotorFailure", 31133), ("separationCutterMemoryExhausted", 31134), ("separationCutterUnderTemperature", 31135), ("separationCutterOverTemperature", 31136), ("separationCutterTimingFailure", 31137), ("separationCutterThermistorFailure", 31138), ("imprinterCoverOpen", 31203), ("imprinterCoverClosed", 31204), ("imprinterInterlockOpen", 31205), ("imprinterInterlockClosed", 31206), ("imprinterConfigurationChange", 31207), ("imprinterJam", 31208), ("imprinterMissing", 31209), ("imprinterLifeAlmostOver", 31210), ("imprinterLifeOver", 31211), ("imprinterAlmostEmpty", 31212), ("imprinterEmpty", 31213), ("imprinterAlmostFull", 31214), ("imprinterFull", 31215), ("imprinterNearLimit", 31216), ("imprinterAtLimit", 31217), ("imprinterOpened", 31218), ("imprinterClosed", 31219), ("imprinterTurnedOn", 31220), ("imprinterTurnedOff", 31221), ("imprinterOffline", 31222), ("imprinterPowerSaver", 31223), ("imprinterWarmingUp", 31224), ("imprinterAdded", 31225), ("imprinterRemoved", 31226), ("imprinterResourceAdded", 31227), ("imprinterResourceRemoved", 31228), ("imprinterRecoverableFailure", 31229), ("imprinterUnrecoverableFailure", 31230), ("imprinterRecoverableStorageError", 31231), ("imprinterUnrecoverableStorageError", 31232), ("imprinterMotorFailure", 31233), ("imprinterMemoryExhausted", 31234), ("imprinterUnderTemperature", 31235), ("imprinterOverTemperature", 31236), ("imprinterTimingFailure", 31237), ("imprinterThermistorFailure", 31238), ("wrapperCoverOpen", 31303), ("wrapperCoverClosed", 31304), ("wrapperInterlockOpen", 31305), ("wrapperInterlockClosed", 31306), ("wrapperConfigurationChange", 31307), ("wrapperJam", 31308), ("wrapperMissing", 31309), ("wrapperLifeAlmostOver", 31310), ("wrapperLifeOver", 31311), ("wrapperAlmostEmpty", 31312), ("wrapperEmpty", 31313), ("wrapperAlmostFull", 31314), ("wrapperFull", 31315), ("wrapperNearLimit", 31316), ("wrapperAtLimit", 31317), ("wrapperOpened", 31318), ("wrapperClosed", 31319), ("wrapperTurnedOn", 31320), ("wrapperTurnedOff", 31321),) + NamedValues(("wrapperOffline", 31322), ("wrapperPowerSaver", 31323), ("wrapperWarmingUp", 31324), ("wrapperAdded", 31325), ("wrapperRemoved", 31326), ("wrapperResourceAdded", 31327), ("wrapperResourceRemoved", 31328), ("wrapperRecoverableFailure", 31329), ("wrapperUnrecoverableFailure", 31330), ("wrapperRecoverableStorageError", 31331), ("wrapperUnrecoverableStorageError", 31332), ("wrapperMotorFailure", 31333), ("wrapperMemoryExhausted", 31334), ("wrapperUnderTemperature", 31335), ("wrapperOverTemperature", 31336), ("wrapperTimingFailure", 31337), ("wrapperThermistorFailure", 31338), ("banderCoverOpen", 31403), ("banderCoverClosed", 31404), ("banderInterlockOpen", 31405), ("banderInterlockClosed", 31406), ("banderConfigurationChange", 31407), ("banderJam", 31408), ("banderMissing", 31409), ("banderLifeAlmostOver", 31410), ("banderLifeOver", 31411), ("banderAlmostEmpty", 31412), ("banderEmpty", 31413), ("banderAlmostFull", 31414), ("banderFull", 31415), ("banderNearLimit", 31416), ("banderAtLimit", 31417), ("banderOpened", 31418), ("banderClosed", 31419), ("banderTurnedOn", 31420), ("banderTurnedOff", 31421), ("banderOffline", 31422), ("banderPowerSaver", 31423), ("banderWarmingUp", 31424), ("banderAdded", 31425), ("banderRemoved", 31426), ("banderResourceAdded", 31427), ("banderResourceRemoved", 31428), ("banderRecoverableFailure", 31429), ("banderUnrecoverableFailure", 31430), ("banderRecoverableStorageError", 31431), ("banderUnrecoverableStorageError", 31432), ("banderMotorFailure", 31433), ("banderMemoryExhausted", 31434), ("banderUnderTemperature", 31435), ("banderOverTemperature", 31436), ("banderTimingFailure", 31437), ("banderThermistorFailure", 31438), ("makeEnvelopeCoverOpen", 31503), ("makeEnvelopeCoverClosed", 31504), ("makeEnvelopeInterlockOpen", 31505), ("makeEnvelopeInterlockClosed", 31506), ("makeEnvelopeConfigurationChange", 31507), ("makeEnvelopeJam", 31508), ("makeEnvelopeMissing", 31509), ("makeEnvelopeLifeAlmostOver", 31510), ("makeEnvelopeLifeOver", 31511), ("makeEnvelopeAlmostEmpty", 31512), ("makeEnvelopeEmpty", 31513), ("makeEnvelopeAlmostFull", 31514), ("makeEnvelopeFull", 31515), ("makeEnvelopeNearLimit", 31516), ("makeEnvelopeAtLimit", 31517), ("makeEnvelopeOpened", 31518), ("makeEnvelopeClosed", 31519), ("makeEnvelopeTurnedOn", 31520), ("makeEnvelopeTurnedOff", 31521), ("makeEnvelopeOffline", 31522), ("makeEnvelopePowerSaver", 31523), ("makeEnvelopeWarmingUp", 31524), ("makeEnvelopeAdded", 31525), ("makeEnvelopeRemoved", 31526), ("makeEnvelopeResourceAdded", 31527), ("makeEnvelopeResourceRemoved", 31528), ("makeEnvelopeRecoverableFailure", 31529), ("makeEnvelopeUnrecoverableFailure", 31530), ("makeEnvelopeRecoverableStorageError", 31531), ("makeEnvelopeUnrecoverableStorageError", 31532), ("makeEnvelopeMotorFailure", 31533), ("makeEnvelopeMemoryExhausted", 31534), ("makeEnvelopeUnderTemperature", 31535), ("makeEnvelopeOverTemperature", 31536), ("makeEnvelopeTimingFailure", 31537), ("makeEnvelopeThermistorFailure", 31538), ("stackerCoverOpen", 31603), ("stackerCoverClosed", 31604), ("stackerInterlockOpen", 31605), ("stackerInterlockClosed", 31606), ("stackerConfigurationChange", 31607), ("stackerJam", 31608), ("stackerMissing", 31609), ("stackerLifeAlmostOver", 31610), ("stackerLifeOver", 31611), ("stackerAlmostEmpty", 31612), ("stackerEmpty", 31613), ("stackerAlmostFull", 31614), ("stackerFull", 31615), ("stackerNearLimit", 31616), ("stackerAtLimit", 31617), ("stackerOpened", 31618), ("stackerClosed", 31619), ("stackerTurnedOn", 31620), ("stackerTurnedOff", 31621), ("stackerOffline", 31622), ("stackerPowerSaver", 31623), ("stackerWarmingUp", 31624), ("stackerAdded", 31625), ("stackerRemoved", 31626), ("stackerResourceAdded", 31627), ("stackerResourceRemoved", 31628), ("stackerRecoverableFailure", 31629), ("stackerUnrecoverableFailure", 31630), ("stackerRecoverableStorageError", 31631), ("stackerUnrecoverableStorageError", 31632), ("stackerMotorFailure", 31633), ("stackerMemoryExhausted", 31634), ("stackerUnderTemperature", 31635), ("stackerOverTemperature", 31636), ("stackerTimingFailure", 31637), ("stackerThermistorFailure", 31638), ("sheetRotatorCoverOpen", 31703), ("sheetRotatorCoverClosed", 31704), ("sheetRotatorInterlockOpen", 31705), ("sheetRotatorInterlockClosed", 31706), ("sheetRotatorConfigurationChange", 31707), ("sheetRotatorJam", 31708), ("sheetRotatorMissing", 31709), ("sheetRotatorLifeAlmostOver", 31710), ("sheetRotatorLifeOver", 31711), ("sheetRotatorAlmostEmpty", 31712), ("sheetRotatorEmpty", 31713), ("sheetRotatorAlmostFull", 31714), ("sheetRotatorFull", 31715), ("sheetRotatorNearLimit", 31716), ("sheetRotatorAtLimit", 31717), ("sheetRotatorOpened", 31718), ("sheetRotatorClosed", 31719), ("sheetRotatorTurnedOn", 31720), ("sheetRotatorTurnedOff", 31721), ("sheetRotatorOffline", 31722), ("sheetRotatorPowerSaver", 31723), ("sheetRotatorWarmingUp", 31724), ("sheetRotatorAdded", 31725), ("sheetRotatorRemoved", 31726), ("sheetRotatorResourceAdded", 31727), ("sheetRotatorResourceRemoved", 31728), ("sheetRotatorRecoverableFailure", 31729), ("sheetRotatorUnrecoverableFailure", 31730), ("sheetRotatorRecoverableStorageError", 31731), ("sheetRotatorUnrecoverableStorageError", 31732), ("sheetRotatorMotorFailure", 31733), ("sheetRotatorMemoryExhausted", 31734), ("sheetRotatorUnderTemperature", 31735), ("sheetRotatorOverTemperature", 31736), ("sheetRotatorTimingFailure", 31737), ("sheetRotatorThermistorFailure", 31738), ("inserterCoverOpen", 31803), ("inserterCoverClosed", 31804), ("inserterInterlockOpen", 31805), ("inserterInterlockClosed", 31806), ("inserterConfigurationChange", 31807), ("inserterJam", 31808), ("inserterMissing", 31809), ("inserterLifeAlmostOver", 31810), ("inserterLifeOver", 31811), ("inserterAlmostEmpty", 31812), ("inserterEmpty", 31813), ("inserterAlmostFull", 31814), ("inserterFull", 31815), ("inserterNearLimit", 31816), ("inserterAtLimit", 31817), ("inserterOpened", 31818), ("inserterClosed", 31819), ("inserterTurnedOn", 31820), ("inserterTurnedOff", 31821), ("inserterOffline", 31822), ("inserterPowerSaver", 31823), ("inserterWarmingUp", 31824), ("inserterAdded", 31825), ("inserterRemoved", 31826), ("inserterResourceAdded", 31827), ("inserterResourceRemoved", 31828), ("inserterRecoverableFailure", 31829), ("inserterUnrecoverableFailure", 31830), ("inserterRecoverableStorageError", 31831), ("inserterUnrecoverableStorageError", 31832), ("inserterMotorFailure", 31833), ("inserterMemoryExhausted", 31834), ("inserterUnderTemperature", 31835), ("inserterOverTemperature", 31836), ("inserterTimingFailure", 31837), ("inserterThermistorFailure", 31838),)

mibBuilder.exportSymbols("IANA-PRINTER-MIB", PrtAlertCodeTC=PrtAlertCodeTC, PrtMediaPathTypeTC=PrtMediaPathTypeTC, PrtConsoleDisableTC=PrtConsoleDisableTC, PrtInputTypeTC=PrtInputTypeTC, ianaPrinterMIB=ianaPrinterMIB, PrtChannelTypeTC=PrtChannelTypeTC, PrtConsoleColorTC=PrtConsoleColorTC, PrtCoverStatusTC=PrtCoverStatusTC, PrtAlertGroupTC=PrtAlertGroupTC, PrtInterpreterLangFamilyTC=PrtInterpreterLangFamilyTC, PrtMarkerMarkTechTC=PrtMarkerMarkTechTC, PrtAlertTrainingLevelTC=PrtAlertTrainingLevelTC, PrtOutputTypeTC=PrtOutputTypeTC, PrtMarkerSuppliesTypeTC=PrtMarkerSuppliesTypeTC, PrtGeneralResetTC=PrtGeneralResetTC, PYSNMP_MODULE_ID=ianaPrinterMIB)
