#
# PySNMP MIB module VDSL-LINE-EXT-MCM-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/VDSL-LINE-EXT-MCM-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:32:42 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( ObjectIdentifier, OctetString, Integer, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "OctetString", "Integer")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueSizeConstraint, SingleValueConstraint, ConstraintsUnion, ValueRangeConstraint, ConstraintsIntersection, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueSizeConstraint", "SingleValueConstraint", "ConstraintsUnion", "ValueRangeConstraint", "ConstraintsIntersection")
( ObjectGroup, NotificationGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ObjectGroup", "NotificationGroup", "ModuleCompliance")
( Integer32, ObjectIdentity, iso, Unsigned32, MibIdentifier, MibScalar, MibTable, MibTableRow, MibTableColumn, TimeTicks, IpAddress, Bits, NotificationType, Counter64, transmission, Gauge32, ModuleIdentity, Counter32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Integer32", "ObjectIdentity", "iso", "Unsigned32", "MibIdentifier", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "TimeTicks", "IpAddress", "Bits", "NotificationType", "Counter64", "transmission", "Gauge32", "ModuleIdentity", "Counter32")
( RowStatus, TextualConvention, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "RowStatus", "TextualConvention", "DisplayString")
( vdslLineConfProfileName, ) = mibBuilder.importSymbols("VDSL-LINE-MIB", "vdslLineConfProfileName")
vdslExtMCMMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 10, 229)).setRevisions(("2005-04-28 00:00",))
if mibBuilder.loadTexts: vdslExtMCMMIB.setLastUpdated('200504280000Z')
if mibBuilder.loadTexts: vdslExtMCMMIB.setOrganization('ADSLMIB Working Group')
if mibBuilder.loadTexts: vdslExtMCMMIB.setContactInfo('WG-email:  adslmib@ietf.org\n         Info:      https://www1.ietf.org/mailman/listinfo/adslmib\n\n         Chair:     Mike Sneed\n                    Sand Channel Systems\n         Postal:    P.O. Box 37324\n                    Raleigh NC 27627-732\n         Email:     sneedmike@hotmail.com\n         Phone:     +1 206 600 7022\n\n         Co-Chair/Co-editor:\n                    Bob Ray\n                    PESA Switching Systems, Inc.\n         Postal:    330-A Wynn Drive\n                    Huntsville, AL 35805\n                    USA\n         Email:     rray@pesa.com\n         Phone:     +1 256 726 9200 ext.  142\n\n\n\n\n         Co-editor: Menachem Dodge\n                    ECI Telecom Ltd.\n         Postal:    30 hasivim St.\n                    Petach Tikva 49517,\n                    Israel.\n         Email:     mbdodge@ieee.org\n         Phone:     +972 3 926 8421\n        ')
if mibBuilder.loadTexts: vdslExtMCMMIB.setDescription('The VDSL-LINE-MIB found in RFC 3728 defines objects for\n    the management of a pair of VDSL transceivers at each end of\n    the VDSL line.  The VDSL-LINE-MIB configures and monitors the\n    line code independent parameters (TC layer) of the VDSL line.\n    This MIB module is an optional extension of the VDSL-LINE-MIB\n    and defines objects for configuration and monitoring of the\n    line code specific (LCS) elements (PMD layer) for VDSL lines\n    using MCM coding.  The objects in this extension MIB MUST NOT\n    be used for VDSL lines using Single Carrier Modulation (SCM)\n    line coding.  If an object in this extension MIB is referenced\n    by a line which does not use MCM, it has no effect on the\n    operation of that line.\n\n    Naming Conventions:\n        Vtuc -- (VTUC) transceiver at near (Central) end of line\n        Vtur -- (VTUR) transceiver at Remote end of line\n        Vtu  -- One of either Vtuc or Vtur\n        Curr -- Current\n        LCS  -- Line Code Specific\n        Max  -- Maximum\n        PSD  -- Power Spectral Density\n        Rx   -- Receive\n        Tx   -- Transmit\n\n    Copyright (C) The Internet Society (2005).  This version\n    of this MIB module is part of RFC 4070: see the RFC\n    itself for full legal notices.')
vdslLineExtMCMMib = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 229, 1))
vdslLineExtMCMMibObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 229, 1, 1))
vdslLineMCMConfProfileTable = MibTable((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 1), )
if mibBuilder.loadTexts: vdslLineMCMConfProfileTable.setDescription('This table contains additional information on multiple\n        carrier VDSL lines.  One entry in this table reflects a\n        profile defined by a manager which can be used to\n        configure the VDSL line.\n\n        If an entry in this table is referenced by a line which\n        does not use MCM, it has no effect on the operation of that\n        line.\n\n        All read-create-objects defined in this table SHOULD be\n        stored persistently.')
vdslLineMCMConfProfileEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 1, 1), ).setIndexNames((0, "VDSL-LINE-MIB", "vdslLineConfProfileName"))
if mibBuilder.loadTexts: vdslLineMCMConfProfileEntry.setDescription('Each entry consists of a list of parameters that\n        represents the configuration of a multiple carrier\n        modulation VDSL modem.')
vdslLineMCMConfProfileTxWindowLength = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 1, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,255))).setUnits('samples').setMaxAccess("readcreate")
if mibBuilder.loadTexts: vdslLineMCMConfProfileTxWindowLength.setDescription('Specifies the length of the transmit window, counted\n        in samples at the sampling rate corresponding to the\n        negotiated value of N.')
vdslLineMCMConfProfileRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 1, 1, 2), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: vdslLineMCMConfProfileRowStatus.setDescription("This object is used to create a new row or modify or\n        delete an existing row in this table.\n\n        A profile is activated by setting this object to `active'.\n        When `active' is set, the system will validate the profile.\n\n        None of the columns in this row may be modified while the\n        row is in the 'active' state.\n\n        Before a profile can be deleted or taken out of\n        service, (by setting this object to `destroy' or\n        `notInService') it must first be unreferenced\n        from all associated lines.")
vdslLineMCMConfProfileTxBandTable = MibTable((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 2), )
if mibBuilder.loadTexts: vdslLineMCMConfProfileTxBandTable.setDescription('This table contains transmit band descriptor configuration\n        information for a VDSL line.  Each entry in this table\n        reflects the configuration for one of possibly many bands\n        with a multiple carrier modulation (MCM) VDSL line.\n        These entries are defined by a manager and can be used to\n        configure the VDSL line.\n\n        If an entry in this table is referenced by a line which\n        does not use MCM, it has no effect on the operation of that\n        line.\n\n        All read-create-objects defined in this table SHOULD be\n        stored persistently.')
vdslLineMCMConfProfileTxBandEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 2, 1), ).setIndexNames((0, "VDSL-LINE-MIB", "vdslLineConfProfileName"), (0, "VDSL-LINE-EXT-MCM-MIB", "vdslLineMCMConfProfileTxBandNumber"))
if mibBuilder.loadTexts: vdslLineMCMConfProfileTxBandEntry.setDescription('Each entry consists of a transmit band descriptor, which\n        is defined by a start and a stop tone index.')
vdslLineMCMConfProfileTxBandNumber = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 2, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4096)))
if mibBuilder.loadTexts: vdslLineMCMConfProfileTxBandNumber.setDescription('The index for this band descriptor entry.')
vdslLineMCMConfProfileTxBandStart = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 2, 1, 2), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4096))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: vdslLineMCMConfProfileTxBandStart.setDescription('Start tone index for this band.')
vdslLineMCMConfProfileTxBandStop = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 2, 1, 3), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4096))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: vdslLineMCMConfProfileTxBandStop.setDescription('Stop tone index for this band.')
vdslLineMCMConfProfileTxBandRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 2, 1, 4), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: vdslLineMCMConfProfileTxBandRowStatus.setDescription("This object is used to create a new row or modify or\n        delete an existing row in this table.\n        A profile is activated by setting this object to `active'.\n        When `active' is set, the system will validate the profile.\n\n\n\n\n        Each entry must be internally consistent, the Stop Tone must\n        be greater than the Start Tone.  Each entry must also be\n        externally consistent, all entries indexed by a specific\n        profile must not overlap.  Validation of the profile will\n        check both internal and external consistency.\n\n        None of the columns in this row may be modified while the\n        row is in the 'active' state.\n\n        Before a profile can be deleted or taken out of\n        service, (by setting this object to `destroy' or\n        `notInService') it must be first unreferenced\n        from all associated lines.")
vdslLineMCMConfProfileRxBandTable = MibTable((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 3), )
if mibBuilder.loadTexts: vdslLineMCMConfProfileRxBandTable.setDescription('This table contains receive band descriptor configuration\n        information for a VDSL line.  Each entry in this table\n        reflects the configuration for one of possibly many bands\n        with a multiple carrier modulation (MCM) VDSL line.\n        These entries are defined by a manager and can be used to\n        configure the VDSL line.\n\n        If an entry in this table is referenced by a line which\n        does not use MCM, it has no effect on the operation of that\n        line.\n\n        All read-create-objects defined in this table SHOULD be\n        stored persistently.')
vdslLineMCMConfProfileRxBandEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 3, 1), ).setIndexNames((0, "VDSL-LINE-MIB", "vdslLineConfProfileName"), (0, "VDSL-LINE-EXT-MCM-MIB", "vdslLineMCMConfProfileRxBandNumber"))
if mibBuilder.loadTexts: vdslLineMCMConfProfileRxBandEntry.setDescription('Each entry consists of a transmit band descriptor, which\n        is defined by a start and a stop tone index.')
vdslLineMCMConfProfileRxBandNumber = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 3, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4096)))
if mibBuilder.loadTexts: vdslLineMCMConfProfileRxBandNumber.setDescription('The index for this band descriptor entry.')
vdslLineMCMConfProfileRxBandStart = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 3, 1, 2), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4096))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: vdslLineMCMConfProfileRxBandStart.setDescription('Start tone index for this band.')
vdslLineMCMConfProfileRxBandStop = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 3, 1, 3), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4096))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: vdslLineMCMConfProfileRxBandStop.setDescription('Stop tone index for this band.')
vdslLineMCMConfProfileRxBandRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 3, 1, 4), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: vdslLineMCMConfProfileRxBandRowStatus.setDescription("This object is used to create a new row or modify or\n        delete an existing row in this table.\n\n        A profile is activated by setting this object to `active'.\n        When `active' is set, the system will validate the profile.\n        Each entry must be internally consistent, the Stop Tone must\n        be greater than the Start Tone.  Each entry must also be\n        externally consistent, all entries indexed by a specific\n\n\n\n        profile must not overlap.  Validation of the profile will\n        check both internal and external consistency.\n\n        None of the columns in this row may be modified while the\n        row is in the 'active' state.\n\n        Before a profile can be deleted or taken out of\n        service, (by setting this object to `destroy' or\n        `notInService') it must be first unreferenced\n        from all associated lines.")
vdslLineMCMConfProfileTxPSDTable = MibTable((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 4), )
if mibBuilder.loadTexts: vdslLineMCMConfProfileTxPSDTable.setDescription('This table contains transmit PSD mask descriptor\n        configuration information for a VDSL line.  Each entry in\n        this table reflects the configuration for one tone within\n        a multiple carrier modulation (MCM) VDSL line.  These\n        entries are defined by a manager and can be used to\n        configure the VDSL line.\n\n        If an entry in this table is referenced by a line which\n        does not use MCM, it has no effect on the operation of that\n        line.\n\n        All read-create-objects defined in this table SHOULD be\n        stored persistently.')
vdslLineMCMConfProfileTxPSDEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 4, 1), ).setIndexNames((0, "VDSL-LINE-MIB", "vdslLineConfProfileName"), (0, "VDSL-LINE-EXT-MCM-MIB", "vdslLineMCMConfProfileTxPSDNumber"))
if mibBuilder.loadTexts: vdslLineMCMConfProfileTxPSDEntry.setDescription('Each entry consists of a transmit PSD mask descriptor,\n        which defines the power spectral density (PSD) for a tone.')
vdslLineMCMConfProfileTxPSDNumber = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 4, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4096)))
if mibBuilder.loadTexts: vdslLineMCMConfProfileTxPSDNumber.setDescription('The index for this mask descriptor entry.')
vdslLineMCMConfProfileTxPSDTone = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 4, 1, 2), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4096))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: vdslLineMCMConfProfileTxPSDTone.setDescription('The tone index for which the PSD is being specified.')
vdslLineMCMConfProfileTxPSDPSD = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 4, 1, 3), Unsigned32()).setUnits('0.5dBm/Hz').setMaxAccess("readcreate")
if mibBuilder.loadTexts: vdslLineMCMConfProfileTxPSDPSD.setDescription('Power Spectral Density level in steps of 0.5dBm/Hz with\n        an offset of -140dBm/Hz.')
vdslLineMCMConfProfileTxPSDRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 4, 1, 4), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: vdslLineMCMConfProfileTxPSDRowStatus.setDescription("This object is used to create a new row or modify or\n        delete an existing row in this table.\n\n        A profile is activated by setting this object to `active'.\n        When `active' is set, the system will validate the profile.\n\n        None of the columns in this row may be modified while the\n        row is in the 'active' state.\n\n        Before a profile can be deleted or taken out of\n\n\n\n        service, (by setting this object to `destroy' or\n        `notInService') it must be first unreferenced\n        from all associated lines.")
vdslLineMCMConfProfileMaxTxPSDTable = MibTable((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 5), )
if mibBuilder.loadTexts: vdslLineMCMConfProfileMaxTxPSDTable.setDescription('This table contains transmit maximum PSD mask descriptor\n        configuration information for a VDSL line.  Each entry in\n        this table reflects the configuration for one tone within\n        a multiple carrier modulation (MCM) VDSL modem.  These\n        entries are defined by a manager and can be used to\n        configure the VDSL line.\n\n        If an entry in this table is referenced by a line which\n        does not use MCM, it has no effect on the operation of that\n        line.\n\n        All read-create-objects defined in this table SHOULD be\n        stored persistently.')
vdslLineMCMConfProfileMaxTxPSDEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 5, 1), ).setIndexNames((0, "VDSL-LINE-MIB", "vdslLineConfProfileName"), (0, "VDSL-LINE-EXT-MCM-MIB", "vdslLineMCMConfProfileMaxTxPSDNumber"))
if mibBuilder.loadTexts: vdslLineMCMConfProfileMaxTxPSDEntry.setDescription('Each entry consists of a transmit PSD mask descriptor,\n        which defines the maximum power spectral density (PSD)\n        for a tone.')
vdslLineMCMConfProfileMaxTxPSDNumber = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 5, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4096)))
if mibBuilder.loadTexts: vdslLineMCMConfProfileMaxTxPSDNumber.setDescription('The index for this band descriptor entry.')
vdslLineMCMConfProfileMaxTxPSDTone = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 5, 1, 2), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4096))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: vdslLineMCMConfProfileMaxTxPSDTone.setDescription('The tone index for which the PSD is being specified.\n         There must not be multiple rows defined, for a particular\n         profile, with the same value for this field.')
vdslLineMCMConfProfileMaxTxPSDPSD = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 5, 1, 3), Unsigned32()).setUnits('0.5dBm/Hz').setMaxAccess("readcreate")
if mibBuilder.loadTexts: vdslLineMCMConfProfileMaxTxPSDPSD.setDescription('Power Spectral Density level in steps of 0.5dBm/Hz with\n        an offset of -140dBm/Hz.')
vdslLineMCMConfProfileMaxTxPSDRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 5, 1, 4), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: vdslLineMCMConfProfileMaxTxPSDRowStatus.setDescription("This object is used to create a new row or modify or\n        delete an existing row in this table.\n        A profile is activated by setting this object to `active'.\n        When `active' is set, the system will validate the profile.\n        There must be only one entry in this table for each tone\n        associated with a specific profile.  This will be checked\n        during the validation process.\n\n        None of the columns in this row may be modified while the\n        row is in the 'active' state.\n\n        Before a profile can be deleted or taken out of\n        service, (by setting this object to `destroy' or\n        `notInService') it must be first unreferenced\n        from all associated lines.")
vdslLineMCMConfProfileMaxRxPSDTable = MibTable((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 6), )
if mibBuilder.loadTexts: vdslLineMCMConfProfileMaxRxPSDTable.setDescription('This table contains maximum receive PSD mask descriptor\n        configuration information for a VDSL line.  Each entry in\n        this table reflects the configuration for one tone within\n        a multiple carrier modulation (MCM) VDSL modem.  These\n        entries are defined by a manager and can be used to\n        configure the VDSL line.\n\n        If an entry in this table is referenced by a line which\n        does not use MCM, it has no effect on the operation of that\n        line.\n\n        All read-create-objects defined in this table SHOULD be\n        stored persistently.')
vdslLineMCMConfProfileMaxRxPSDEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 6, 1), ).setIndexNames((0, "VDSL-LINE-MIB", "vdslLineConfProfileName"), (0, "VDSL-LINE-EXT-MCM-MIB", "vdslLineMCMConfProfileMaxRxPSDNumber"))
if mibBuilder.loadTexts: vdslLineMCMConfProfileMaxRxPSDEntry.setDescription('Each entry consists of a transmit PSD mask descriptor,\n        which defines the power spectral density (PSD) for a\n        tone.')
vdslLineMCMConfProfileMaxRxPSDNumber = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 6, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4096)))
if mibBuilder.loadTexts: vdslLineMCMConfProfileMaxRxPSDNumber.setDescription('The index for this band descriptor entry.')
vdslLineMCMConfProfileMaxRxPSDTone = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 6, 1, 2), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4096))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: vdslLineMCMConfProfileMaxRxPSDTone.setDescription('The tone index for which the PSD is being specified.\n         There must not be multiple rows defined, for a particular\n         profile, with the same value for this field.')
vdslLineMCMConfProfileMaxRxPSDPSD = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 6, 1, 3), Unsigned32()).setUnits('0.5dBm/Hz').setMaxAccess("readcreate")
if mibBuilder.loadTexts: vdslLineMCMConfProfileMaxRxPSDPSD.setDescription('Power Spectral Density level in steps of 0.5dBm/Hz with\n        an offset of -140dBm/Hz.')
vdslLineMCMConfProfileMaxRxPSDRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 6, 1, 4), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: vdslLineMCMConfProfileMaxRxPSDRowStatus.setDescription("This object is used to create a new row or modify or\n        delete an existing row in this table.\n\n        A profile is activated by setting this object to `active'.\n        When `active' is set, the system will validate the profile.\n        There must be only one entry in this table for each tone\n        associated with a specific profile.  This will be checked\n        during the validation process.\n\n        None of the columns in this row may be modified while the\n        row is in the 'active' state.\n\n        Before a profile can be deleted or taken out of\n        service, (by setting this object to `destroy' or\n        `notInService') it must be first unreferenced\n        from all associated lines.")
vdslLineExtMCMConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 229, 1, 2))
vdslLineExtMCMGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 229, 1, 2, 1))
vdslLineExtMCMCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 229, 1, 2, 2))
vdslLineExtMCMMibCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 10, 229, 1, 2, 2, 1)).setObjects(*(("VDSL-LINE-EXT-MCM-MIB", "vdslLineExtMCMGroup"),))
if mibBuilder.loadTexts: vdslLineExtMCMMibCompliance.setDescription('The compliance statement for SNMP entities which\n        manage VDSL interfaces.')
vdslLineExtMCMGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 229, 1, 2, 1, 1)).setObjects(*(("VDSL-LINE-EXT-MCM-MIB", "vdslLineMCMConfProfileTxWindowLength"), ("VDSL-LINE-EXT-MCM-MIB", "vdslLineMCMConfProfileRowStatus"), ("VDSL-LINE-EXT-MCM-MIB", "vdslLineMCMConfProfileTxBandStart"), ("VDSL-LINE-EXT-MCM-MIB", "vdslLineMCMConfProfileTxBandStop"), ("VDSL-LINE-EXT-MCM-MIB", "vdslLineMCMConfProfileTxBandRowStatus"), ("VDSL-LINE-EXT-MCM-MIB", "vdslLineMCMConfProfileRxBandStart"), ("VDSL-LINE-EXT-MCM-MIB", "vdslLineMCMConfProfileRxBandStop"), ("VDSL-LINE-EXT-MCM-MIB", "vdslLineMCMConfProfileRxBandRowStatus"), ("VDSL-LINE-EXT-MCM-MIB", "vdslLineMCMConfProfileTxPSDTone"), ("VDSL-LINE-EXT-MCM-MIB", "vdslLineMCMConfProfileTxPSDPSD"), ("VDSL-LINE-EXT-MCM-MIB", "vdslLineMCMConfProfileTxPSDRowStatus"), ("VDSL-LINE-EXT-MCM-MIB", "vdslLineMCMConfProfileMaxTxPSDTone"), ("VDSL-LINE-EXT-MCM-MIB", "vdslLineMCMConfProfileMaxTxPSDPSD"), ("VDSL-LINE-EXT-MCM-MIB", "vdslLineMCMConfProfileMaxTxPSDRowStatus"), ("VDSL-LINE-EXT-MCM-MIB", "vdslLineMCMConfProfileMaxRxPSDTone"), ("VDSL-LINE-EXT-MCM-MIB", "vdslLineMCMConfProfileMaxRxPSDPSD"), ("VDSL-LINE-EXT-MCM-MIB", "vdslLineMCMConfProfileMaxRxPSDRowStatus"),))
if mibBuilder.loadTexts: vdslLineExtMCMGroup.setDescription('A collection of objects providing configuration\n\n\n\n             information for a VDSL line based upon multiple\n             carrier modulation modem.')
mibBuilder.exportSymbols("VDSL-LINE-EXT-MCM-MIB", vdslLineExtMCMGroup=vdslLineExtMCMGroup, vdslLineMCMConfProfileTxPSDNumber=vdslLineMCMConfProfileTxPSDNumber, vdslLineMCMConfProfileMaxRxPSDTable=vdslLineMCMConfProfileMaxRxPSDTable, vdslLineMCMConfProfileRxBandStart=vdslLineMCMConfProfileRxBandStart, vdslLineMCMConfProfileMaxTxPSDPSD=vdslLineMCMConfProfileMaxTxPSDPSD, vdslLineMCMConfProfileTxBandRowStatus=vdslLineMCMConfProfileTxBandRowStatus, vdslLineExtMCMCompliances=vdslLineExtMCMCompliances, vdslLineMCMConfProfileMaxTxPSDTable=vdslLineMCMConfProfileMaxTxPSDTable, vdslLineMCMConfProfileRxBandTable=vdslLineMCMConfProfileRxBandTable, vdslLineMCMConfProfileTxBandEntry=vdslLineMCMConfProfileTxBandEntry, vdslLineExtMCMMibObjects=vdslLineExtMCMMibObjects, vdslLineMCMConfProfileTxBandStart=vdslLineMCMConfProfileTxBandStart, vdslLineMCMConfProfileMaxRxPSDPSD=vdslLineMCMConfProfileMaxRxPSDPSD, vdslLineMCMConfProfileMaxTxPSDNumber=vdslLineMCMConfProfileMaxTxPSDNumber, vdslLineMCMConfProfileMaxTxPSDTone=vdslLineMCMConfProfileMaxTxPSDTone, vdslLineMCMConfProfileMaxRxPSDRowStatus=vdslLineMCMConfProfileMaxRxPSDRowStatus, vdslLineMCMConfProfileRxBandStop=vdslLineMCMConfProfileRxBandStop, vdslLineMCMConfProfileTxWindowLength=vdslLineMCMConfProfileTxWindowLength, vdslLineMCMConfProfileTxPSDPSD=vdslLineMCMConfProfileTxPSDPSD, vdslLineMCMConfProfileMaxRxPSDEntry=vdslLineMCMConfProfileMaxRxPSDEntry, vdslLineExtMCMMibCompliance=vdslLineExtMCMMibCompliance, vdslLineMCMConfProfileMaxRxPSDNumber=vdslLineMCMConfProfileMaxRxPSDNumber, vdslLineMCMConfProfileTxBandStop=vdslLineMCMConfProfileTxBandStop, vdslLineMCMConfProfileTxPSDTone=vdslLineMCMConfProfileTxPSDTone, vdslLineMCMConfProfileMaxRxPSDTone=vdslLineMCMConfProfileMaxRxPSDTone, vdslLineMCMConfProfileTxBandTable=vdslLineMCMConfProfileTxBandTable, vdslLineMCMConfProfileRxBandNumber=vdslLineMCMConfProfileRxBandNumber, vdslLineMCMConfProfileMaxTxPSDEntry=vdslLineMCMConfProfileMaxTxPSDEntry, vdslLineMCMConfProfileEntry=vdslLineMCMConfProfileEntry, vdslLineMCMConfProfileTxPSDEntry=vdslLineMCMConfProfileTxPSDEntry, vdslLineMCMConfProfileTxBandNumber=vdslLineMCMConfProfileTxBandNumber, PYSNMP_MODULE_ID=vdslExtMCMMIB, vdslLineMCMConfProfileRxBandEntry=vdslLineMCMConfProfileRxBandEntry, vdslLineMCMConfProfileTxPSDRowStatus=vdslLineMCMConfProfileTxPSDRowStatus, vdslLineMCMConfProfileRowStatus=vdslLineMCMConfProfileRowStatus, vdslLineMCMConfProfileRxBandRowStatus=vdslLineMCMConfProfileRxBandRowStatus, vdslLineMCMConfProfileTable=vdslLineMCMConfProfileTable, vdslLineExtMCMGroups=vdslLineExtMCMGroups, vdslLineMCMConfProfileMaxTxPSDRowStatus=vdslLineMCMConfProfileMaxTxPSDRowStatus, vdslLineExtMCMConformance=vdslLineExtMCMConformance, vdslLineExtMCMMib=vdslLineExtMCMMib, vdslExtMCMMIB=vdslExtMCMMIB, vdslLineMCMConfProfileTxPSDTable=vdslLineMCMConfProfileTxPSDTable)
