#
# PySNMP MIB module MIP-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/MIP-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:20:14 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( Integer, OctetString, ObjectIdentifier, ) = mibBuilder.importSymbols("ASN1", "Integer", "OctetString", "ObjectIdentifier")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueRangeConstraint, ConstraintsUnion, ValueSizeConstraint, SingleValueConstraint, ConstraintsIntersection, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueRangeConstraint", "ConstraintsUnion", "ValueSizeConstraint", "SingleValueConstraint", "ConstraintsIntersection")
( ModuleCompliance, ObjectGroup, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "ObjectGroup", "NotificationGroup")
( Counter64, MibIdentifier, Gauge32, ObjectIdentity, TimeTicks, Counter32, Bits, iso, IpAddress, Unsigned32, MibScalar, MibTable, MibTableRow, MibTableColumn, Integer32, experimental, NotificationType, ModuleIdentity, mib_2, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Counter64", "MibIdentifier", "Gauge32", "ObjectIdentity", "TimeTicks", "Counter32", "Bits", "iso", "IpAddress", "Unsigned32", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Integer32", "experimental", "NotificationType", "ModuleIdentity", "mib-2")
( TruthValue, TextualConvention, DisplayString, TimeStamp, RowStatus, ) = mibBuilder.importSymbols("SNMPv2-TC", "TruthValue", "TextualConvention", "DisplayString", "TimeStamp", "RowStatus")
mipMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 44))
if mibBuilder.loadTexts: mipMIB.setLastUpdated('9606040000Z')
if mibBuilder.loadTexts: mipMIB.setOrganization('IETF Mobile IP Working Group')
if mibBuilder.loadTexts: mipMIB.setContactInfo('       David Cong\n                Postal: Motorola\n                        1301 E. Algonquin Rd.\n                        Schaumburg, IL 60196\n                Phone:  +1-847-576-1357\n                Email:  cong@comm.mot.com')
if mibBuilder.loadTexts: mipMIB.setDescription('The MIB Module for the Mobile IP.')
mipMIBObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 44, 1))
mipSystem = MibIdentifier((1, 3, 6, 1, 2, 1, 44, 1, 1))
mipSecurity = MibIdentifier((1, 3, 6, 1, 2, 1, 44, 1, 2))
mipMN = MibIdentifier((1, 3, 6, 1, 2, 1, 44, 1, 3))
mipMA = MibIdentifier((1, 3, 6, 1, 2, 1, 44, 1, 4))
mipFA = MibIdentifier((1, 3, 6, 1, 2, 1, 44, 1, 5))
mipHA = MibIdentifier((1, 3, 6, 1, 2, 1, 44, 1, 6))
mnSystem = MibIdentifier((1, 3, 6, 1, 2, 1, 44, 1, 3, 1))
mnDiscovery = MibIdentifier((1, 3, 6, 1, 2, 1, 44, 1, 3, 2))
mnRegistration = MibIdentifier((1, 3, 6, 1, 2, 1, 44, 1, 3, 3))
maAdvertisement = MibIdentifier((1, 3, 6, 1, 2, 1, 44, 1, 4, 2))
faSystem = MibIdentifier((1, 3, 6, 1, 2, 1, 44, 1, 5, 1))
faAdvertisement = MibIdentifier((1, 3, 6, 1, 2, 1, 44, 1, 5, 2))
faRegistration = MibIdentifier((1, 3, 6, 1, 2, 1, 44, 1, 5, 3))
haRegistration = MibIdentifier((1, 3, 6, 1, 2, 1, 44, 1, 6, 3))
class RegistrationFlags(Bits, TextualConvention):
    namedValues = NamedValues(("vjCompression", 0), ("gre", 1), ("minEnc", 2), ("decapsulationbyMN", 3), ("broadcastDatagram", 4), ("simultaneousBindings", 5),)

mipEntities = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 1, 1), Bits().clone(namedValues=NamedValues(("mobileNode", 0), ("foreignAgent", 1), ("homeAgent", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: mipEntities.setDescription('This object describes which Mobile IP entities are\n                supported by this managed entity. The entity may\n                support more than one Mobile IP entities. For example,\n                the entity supports both Foreign Agent (FA) and Home\n                Agent (HA). Therefore, bit 1 and bit 2 are set to 1\n                for this object.')
mipEnable = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 1, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("enabled", 1), ("disabled", 2),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mipEnable.setDescription('Indicates whether the Mobile IP protocol should be\n                enabled for the managed entity. If it is disabled, the\n                entity should disable both agent discovery and\n                registration functions.')
mipEncapsulationSupported = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 1, 3), Bits().clone(namedValues=NamedValues(("ipInIp", 0), ("gre", 1), ("minEnc", 2), ("other", 3),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: mipEncapsulationSupported.setDescription('Encapsulation methods supported by the Mobile IP\n                entity. The entity may support multiple encapsulation\n                methods or none of them:\n                    ipInIp(0), -- IP Encapsulation within IP\n                    gre(1),    -- Generic Routing Encapsulation,\n                               -- refers to RFC1701\n                    minEnc(2), -- Minimal Encapsulation within IP.')
mipSecAssocTable = MibTable((1, 3, 6, 1, 2, 1, 44, 1, 2, 1), )
if mibBuilder.loadTexts: mipSecAssocTable.setDescription('A table containing Mobility Security Associations.')
mipSecAssocEntry = MibTableRow((1, 3, 6, 1, 2, 1, 44, 1, 2, 1, 1), ).setIndexNames((0, "MIP-MIB", "mipSecPeerAddress"), (0, "MIP-MIB", "mipSecSPI"))
if mibBuilder.loadTexts: mipSecAssocEntry.setDescription('One particular Mobility Security Association.')
mipSecPeerAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 2, 1, 1, 1), IpAddress())
if mibBuilder.loadTexts: mipSecPeerAddress.setDescription('The IP address of the peer entity with which this\n                node shares the mobility security association.')
mipSecSPI = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 2, 1, 1, 2), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,4294967295)))
if mibBuilder.loadTexts: mipSecSPI.setDescription('The SPI is the 4-byte opaque index within the\n                Mobility Security Association which selects the\n                specific security parameters to be used to\n                authenticate the peer, i.e. the rest of the variables\n                in this MipSecAssocEntry.')
mipSecAlgorithmType = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 2, 1, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("other", 1), ("md5", 2),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mipSecAlgorithmType.setDescription('Type of security algorithm.')
mipSecAlgorithmMode = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 2, 1, 1, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("other", 1), ("prefixSuffix", 2),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mipSecAlgorithmMode.setDescription('Security mode used by this algorithm.')
mipSecKey = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 2, 1, 1, 5), OctetString().subtype(subtypeSpec=ValueSizeConstraint(16,16)).setFixedLength(16)).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mipSecKey.setDescription('The shared secret key for the security\n                associations. Reading this object will always return\n                zero length value.')
mipSecReplayMethod = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 2, 1, 1, 6), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("other", 1), ("timestamps", 2), ("nonces", 3),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mipSecReplayMethod.setDescription('The replay-protection method supported for this SPI\n                within this Mobility Security Association.')
mipSecTotalViolations = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 2, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mipSecTotalViolations.setDescription('Total number of security violations in the entity')
mipSecViolationTable = MibTable((1, 3, 6, 1, 2, 1, 44, 1, 2, 3), )
if mibBuilder.loadTexts: mipSecViolationTable.setDescription('A table containing information about security\n                violations.')
mipSecViolationEntry = MibTableRow((1, 3, 6, 1, 2, 1, 44, 1, 2, 3, 1), ).setIndexNames((0, "MIP-MIB", "mipSecViolatorAddress"))
if mibBuilder.loadTexts: mipSecViolationEntry.setDescription('Information about one particular security violation.')
mipSecViolatorAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 2, 3, 1, 1), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mipSecViolatorAddress.setDescription("Violator's IP address. The violator is not necessary\n                in the mipSecAssocTable.")
mipSecViolationCounter = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 2, 3, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mipSecViolationCounter.setDescription('Total number of security violations for this peer.')
mipSecRecentViolationSPI = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 2, 3, 1, 3), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mipSecRecentViolationSPI.setDescription('SPI of the most recent security violation for this\n                peer. If the security violation is due to an\n                identification mismatch, then this is the SPI from the\n                Mobile-Home Authentication Extension.  If the security\n                violation is due to an invalid authenticator, then\n                this is the SPI from the offending authentication\n                extension.  In all other cases, it should be set to\n                zero.')
mipSecRecentViolationTime = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 2, 3, 1, 4), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mipSecRecentViolationTime.setDescription('Time of the most recent security violation for this\n                peer.')
mipSecRecentViolationIDLow = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 2, 3, 1, 5), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mipSecRecentViolationIDLow.setDescription('Low-order 32 bits of identification used in request or\n                reply of the most recent security violation for this\n                peer.')
mipSecRecentViolationIDHigh = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 2, 3, 1, 6), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mipSecRecentViolationIDHigh.setDescription('High-order 32 bits of identification used in request\n                or reply of the most recent security violation for\n                this peer.')
mipSecRecentViolationReason = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 2, 3, 1, 7), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6,))).clone(namedValues=NamedValues(("noMobilitySecurityAssociation", 1), ("badAuthenticator", 2), ("badIdentifier", 3), ("badSPI", 4), ("missingSecurityExtension", 5), ("other", 6),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: mipSecRecentViolationReason.setDescription('Reason for the most recent security violation for\n                this peer.')
mnState = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 3, 1, 1), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))).clone(namedValues=NamedValues(("home", 1), ("registered", 2), ("pending", 3), ("isolated", 4), ("unknown", 5),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: mnState.setDescription("Indicates mobile node's state of Mobile IP:\n                     home,\n                         -- MN is connected to home network.\n                     registered,\n                         -- MN has registered on foreign network\n                     pending,\n                         -- MN has sent registration request and is\n                            waiting for the reply\n                     isolated,\n                         -- MN is isolated from network\n                     unknown\n                         -- MN can not determine its state.")
mnHomeAddress = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 3, 1, 2), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mnHomeAddress.setDescription("An IP address that is assigned for an extended period\n                of time to the mobile node. It remains unchanged\n                regardless of the mobile node's current point of\n                attachment.")
mnHATable = MibTable((1, 3, 6, 1, 2, 1, 44, 1, 3, 1, 3), )
if mibBuilder.loadTexts: mnHATable.setDescription("A table containing all of the mobile node's potential\n                home agents.")
mnHAEntry = MibTableRow((1, 3, 6, 1, 2, 1, 44, 1, 3, 1, 3, 1), ).setIndexNames((0, "MIP-MIB", "mnHAAddress"))
if mibBuilder.loadTexts: mnHAEntry.setDescription('Information for a particular Home Agent.')
mnHAAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 3, 1, 3, 1, 1), IpAddress())
if mibBuilder.loadTexts: mnHAAddress.setDescription("IP address of mobile node's Home Agent.")
mnCurrentHA = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 3, 1, 3, 1, 2), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mnCurrentHA.setDescription('Whether this home agent is the current home agent for\n                the mobile node. If it is true, the mobile node is\n                registered with that home agent.')
mnHAStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 3, 1, 3, 1, 3), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mnHAStatus.setDescription("The row status for this home agent entry. If the\n                status is set to 'createAndGo' or 'active', then the\n                mobile node can use mnHAAddress as a valid candidate\n                for a home agent. If the status is set to 'destroy',\n                then the mobile node should delete this row, and\n                deregister from that home agent.")
mnFATable = MibTable((1, 3, 6, 1, 2, 1, 44, 1, 3, 2, 1), )
if mibBuilder.loadTexts: mnFATable.setDescription('A table containing all foreign agents that the mobile\n                node knows about and their corresponding COA (care-of\n                address). This COA is an address of a foreign agent\n                with which the mobile node is registered. The table is\n                updated when advertisements are received by the mobile\n                node. If an advertisement expires, its entry(s) should\n                be deleted from the table. One foreign agent can\n                provide more than one COA in its advertisements.')
mnFAEntry = MibTableRow((1, 3, 6, 1, 2, 1, 44, 1, 3, 2, 1, 1), ).setIndexNames((0, "MIP-MIB", "mnFAAddress"), (0, "MIP-MIB", "mnCOA"))
if mibBuilder.loadTexts: mnFAEntry.setDescription('One pair of foreign agent IP address and COA for that\n                foreign agent.')
mnFAAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 3, 2, 1, 1, 1), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mnFAAddress.setDescription("Foreign agent's IP address.")
mnCOA = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 3, 2, 1, 1, 2), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mnCOA.setDescription('A care-of address being offered by this foreign agent\n                or a co-located care-of address which the mobile node\n                has associated with one of its own network\n                interfaces.')
mnRecentAdvReceived = MibIdentifier((1, 3, 6, 1, 2, 1, 44, 1, 3, 2, 2))
mnAdvSourceAddress = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 3, 2, 2, 1), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mnAdvSourceAddress.setDescription('The source IP address of the most recently received\n                Agent Advertisement. This address could be the address\n                of a home agent or a foreign agent.')
mnAdvSequence = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 3, 2, 2, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: mnAdvSequence.setDescription('The sequence number of the most recently received\n                advertisement. The sequence number ranges from 0 to\n                0xffff. After the sequence number attains the value\n                0xffff, it will roll over to 256.')
mnAdvFlags = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 3, 2, 2, 3), Bits().clone(namedValues=NamedValues(("vjCompression", 0), ("gre", 1), ("minEnc", 2), ("foreignAgent", 3), ("homeAgent", 4), ("busy", 5), ("regRequired", 6),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: mnAdvFlags.setDescription('The flags are contained in the 7th byte in the\n                extension of the most recently received mobility agent\n                advertisement:\n                    vjCompression\n                        -- Agent supports Van Jacobson compression\n                    gre\n                        -- Agent offers Generice Routing Encapsulation\n                    minEnc,\n                        -- Agent offers Minimal Encapsulation\n                    foreignAgent,\n                        -- Agent is a Foreign Agent\n                    homeAgent,\n                        -- Agent is a Home Agent\n                    busy,\n                        -- Foreign Agent is busy\n                    regRequired,\n                        -- FA registration is required.')
mnAdvMaxRegLifetime = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 3, 2, 2, 4), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: mnAdvMaxRegLifetime.setDescription('The longest lifetime in seconds that the agent is\n                willing to accept in any registration request.')
mnAdvMaxAdvLifetime = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 3, 2, 2, 5), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: mnAdvMaxAdvLifetime.setDescription('The maximum length of time that the Advertisement is\n                considered valid in the absence of further\n                Advertisements.')
mnAdvTimeReceived = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 3, 2, 2, 6), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mnAdvTimeReceived.setDescription('The time at which the most recently received\n                advertisement was received.')
mnSolicitationsSent = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 3, 2, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mnSolicitationsSent.setDescription('Total number of Solicitation sent by the mobile\n                node.')
mnAdvertisementsReceived = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 3, 2, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mnAdvertisementsReceived.setDescription('Total number of advertisements received by the mobile\n                node.')
mnAdvsDroppedInvalidExtension = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 3, 2, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mnAdvsDroppedInvalidExtension.setDescription('Total number of advertisements dropped by the mobile\n                node due to both poorly formed extensions and\n                unrecognized extensions with extension number in the\n                range 0-127.')
mnAdvsIgnoredUnknownExtension = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 3, 2, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mnAdvsIgnoredUnknownExtension.setDescription('Total number of unrecognized extensions in the range\n                128-255 that were ignored by the mobile node.')
mnMoveFromHAToFA = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 3, 2, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mnMoveFromHAToFA.setDescription('Number of times that the mobile node has decided to\n                move from its home network to a foreign network.')
mnMoveFromFAToFA = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 3, 2, 8), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mnMoveFromFAToFA.setDescription('Number of times that the mobile node has decided to\n                move from one foreign network to another foreign\n                network.')
mnMoveFromFAToHA = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 3, 2, 9), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mnMoveFromFAToHA.setDescription('Number of times that the mobile node has decided to\n                move from a foreign network to its home network.')
mnGratuitousARPsSend = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 3, 2, 10), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mnGratuitousARPsSend.setDescription('Total number of Gratuitous ARPs sent by mobile node\n                in order to clear out any stale ARP entries in the ARP\n                caches of nodes on the home network.')
mnAgentRebootsDectected = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 3, 2, 11), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mnAgentRebootsDectected.setDescription('Total number of agent reboots detected by the mobile\n                node through sequence number of the advertisement.')
mnRegistrationTable = MibTable((1, 3, 6, 1, 2, 1, 44, 1, 3, 3, 1), )
if mibBuilder.loadTexts: mnRegistrationTable.setDescription("A table containing information about the mobile\n                node's attempted registration(s).  The mobile node\n                updates this table based upon Registration Requests\n                sent and Registration Replies received in response to\n                these requests.  Certain variables within this table\n                are also updated if when Registration Requests are\n                retransmitted.")
mnRegistrationEntry = MibTableRow((1, 3, 6, 1, 2, 1, 44, 1, 3, 3, 1, 1), ).setIndexNames((0, "MIP-MIB", "mnRegAgentAddress"), (0, "MIP-MIB", "mnRegCOA"))
if mibBuilder.loadTexts: mnRegistrationEntry.setDescription('Information about one registration attempt.')
mnRegAgentAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 3, 3, 1, 1, 1), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mnRegAgentAddress.setDescription('IP address of the agent as used in the destination\n                 IP address of the Registration Request.  The agent\n                 may be a home agent or a foreign agent.')
mnRegCOA = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 3, 3, 1, 1, 2), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mnRegCOA.setDescription('Care-of address for the registration.')
mnRegFlags = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 3, 3, 1, 1, 3), RegistrationFlags()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mnRegFlags.setDescription('Registration flags sent by the mobile node. It is the\n                second byte in the Mobile IP Registratation Request\n                message.')
mnRegIDLow = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 3, 3, 1, 1, 4), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mnRegIDLow.setDescription('Low-order 32 bits of the Identification used in that\n                registration by the mobile node.')
mnRegIDHigh = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 3, 3, 1, 1, 5), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mnRegIDHigh.setDescription('High-order 32 bits of the Identification used in that\n                registration by the mobile node.')
mnRegTimeRequested = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 3, 3, 1, 1, 6), Integer32()).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: mnRegTimeRequested.setDescription('If the registration is pending, then this is the\n                lifetime requested by the mobile node (in seconds).\n                If the registration has been accepted, then this is\n                the lifetime actually granted by the home agent in the\n                reply.')
mnRegTimeRemaining = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 3, 3, 1, 1, 7), Gauge32()).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: mnRegTimeRemaining.setDescription('The number of seconds remaining until this\n                registration expires.  It has the same initial value\n                as mnRegTimeRequested and is only valid if\n                mnRegIsAccepted is TRUE.')
mnRegTimeSent = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 3, 3, 1, 1, 8), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mnRegTimeSent.setDescription('The time when the last (re-)transmission occured.')
mnRegIsAccepted = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 3, 3, 1, 1, 9), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mnRegIsAccepted.setDescription('true(1) if the mobile node has received a\n                Registration Reply indicating that service has been\n                accepted; false(2) otherwise.  false(2) implies that\n                the registration is still pending.')
mnCOAIsLocal = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 3, 3, 1, 1, 10), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mnCOAIsLocal.setDescription('Whether the COA is local to (dynamically acquired by)\n                the mobile node or not.  If it is false(2), the COA is\n                an address of the foreign agent.')
mnRegRequestsSent = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 3, 3, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mnRegRequestsSent.setDescription('Total number of registration requests sent by the\n                mobile node. This does not include deregistrations\n                (those with Lifetime equal to zero).')
mnDeRegRequestsSent = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 3, 3, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mnDeRegRequestsSent.setDescription('Total number of deregistration requests sent by the\n                mobile node (those with Lifetime equal to zero).')
mnRegRepliesRecieved = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 3, 3, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mnRegRepliesRecieved.setDescription('Total number of registration replies received by the\n                mobile node in which the Lifetime is greater than\n                zero.')
mnDeRegRepliesRecieved = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 3, 3, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mnDeRegRepliesRecieved.setDescription('Total number of (de)registration replies received by\n                the mobile node in which the Lifetime is equal to\n                zero.')
mnRepliesInvalidHomeAddress = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 3, 3, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mnRepliesInvalidHomeAddress.setDescription('Total number of replies with invalid home address for\n                the mobile node.')
mnRepliesUnknownHA = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 3, 3, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mnRepliesUnknownHA.setDescription('Total number of replies with unknown home agents\n                (not in home agent table).')
mnRepliesUnknownFA = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 3, 3, 8), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mnRepliesUnknownFA.setDescription('Total number of replies with unknown foreign agents if\n                replies relayed through foreign agent.')
mnRepliesInvalidID = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 3, 3, 9), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mnRepliesInvalidID.setDescription('Total number of replies with invalid Identification\n                fields.')
mnRepliesDroppedInvalidExtension = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 3, 3, 10), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mnRepliesDroppedInvalidExtension.setDescription('Total number of Registration Replies dropped by the\n                mobile node due to both poorly formed extensions and\n                unrecognized extensions with extension number in the\n                range 0-127.')
mnRepliesIgnoredUnknownExtension = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 3, 3, 11), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mnRepliesIgnoredUnknownExtension.setDescription('Total number of Registration Replies that contained\n                one or more unrecognized extensions in the range\n                128-255 that were ignored by the mobile node.')
mnRepliesHAAuthenticationFailure = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 3, 3, 12), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mnRepliesHAAuthenticationFailure.setDescription('Total number of replies without a valid Home Agent to\n                Mobile Node authenticator.')
mnRepliesFAAuthenticationFailure = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 3, 3, 13), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mnRepliesFAAuthenticationFailure.setDescription('Total number of replies without a valid Foreign Agent\n                to Mobile Node authenticator.')
mnRegRequestsAccepted = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 3, 3, 14), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mnRegRequestsAccepted.setDescription("Total number of registration requests accepted by the\n                mobile node's home agent (Code 0 and Code 1).")
mnRegRequestsDeniedByHA = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 3, 3, 15), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mnRegRequestsDeniedByHA.setDescription("Total number of registration requests denied by\n                mobile node's home agent (Sum of Code 128 through\n                Code 191).")
mnRegRequestsDeniedByFA = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 3, 3, 16), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mnRegRequestsDeniedByFA.setDescription('Total number of registration requests denied by the\n                foreign agent (Sum of Codes 64 through Code 127).')
mnRegRequestsDeniedByHADueToID = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 3, 3, 17), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mnRegRequestsDeniedByHADueToID.setDescription('Total number of Registration Request denied by home\n                agent due to identification mismatch.')
mnRegRequestsWithDirectedBroadcast = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 3, 3, 18), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mnRegRequestsWithDirectedBroadcast.setDescription('Total number of Registration Requests sent by mobile\n                node with a directed broadcast address in the home\n                agent field.')
maAdvConfigTable = MibTable((1, 3, 6, 1, 2, 1, 44, 1, 4, 2, 1), )
if mibBuilder.loadTexts: maAdvConfigTable.setDescription('A table containing configurable advertisement\n                parameters for all advertisement interfaces in\n                the mobility agent.')
maAdvConfigEntry = MibTableRow((1, 3, 6, 1, 2, 1, 44, 1, 4, 2, 1, 1), ).setIndexNames((0, "MIP-MIB", "maInterfaceAddress"))
if mibBuilder.loadTexts: maAdvConfigEntry.setDescription('Advertisement parameters for one advertisement\n                interface.')
maInterfaceAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 4, 2, 1, 1, 1), IpAddress())
if mibBuilder.loadTexts: maInterfaceAddress.setDescription('IP address for advertisement interface.')
maAdvMaxRegLifetime = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 4, 2, 1, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setUnits('seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: maAdvMaxRegLifetime.setDescription('The longest lifetime in seconds that mobility agent\n                is willing to accept in any Registration Request.')
maAdvPrefixLengthInclusion = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 4, 2, 1, 1, 3), TruthValue()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: maAdvPrefixLengthInclusion.setDescription('Whether the advertisement should include the Prefix-\n                Lengths Extension. If it is true, all advertisements\n                sent over this interface should include the\n                Prefix-Lengths Extension.')
maAdvAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 4, 2, 1, 1, 4), IpAddress()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: maAdvAddress.setDescription('The IP destination address to be used for\n                advertisements sent from the interface. The only\n                permissible values are the all-systems multicast\n                address (224.0.0.1) or the limited-broadcast address\n                (255.255.255.255).')
maAdvMaxInterval = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 4, 2, 1, 1, 5), Integer32().subtype(subtypeSpec=ValueRangeConstraint(4,1800))).setUnits('seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: maAdvMaxInterval.setDescription('The maximum time in seconds between successive\n                transmissions of Agent Advertisements from this\n                interface.')
maAdvMinInterval = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 4, 2, 1, 1, 6), Integer32().subtype(subtypeSpec=ValueRangeConstraint(3,1800))).setUnits('seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: maAdvMinInterval.setDescription('The minimum time in seconds between successive\n                transmissions of Agent Advertisements from this\n                interface.')
maAdvMaxAdvLifetime = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 4, 2, 1, 1, 7), Integer32().subtype(subtypeSpec=ValueRangeConstraint(4,9000))).setUnits('seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: maAdvMaxAdvLifetime.setDescription('The time (in seconds) to be placed in the Lifetime\n                field of the RFC 1256-portion of the Agent\n                Advertisements sent over this interface.')
maAdvResponseSolicitationOnly = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 4, 2, 1, 1, 8), TruthValue().clone('false')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: maAdvResponseSolicitationOnly.setDescription('The flag indicates whether the advertisement from\n                that interface should be sent only in response to an\n                Agent Solicitation message.')
maAdvStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 4, 2, 1, 1, 9), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: maAdvStatus.setDescription("The row status for the agent advertisement table. If\n                this column status is 'active', the manager should not\n                change any column in the row.")
maAdvertisementsSent = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 4, 2, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: maAdvertisementsSent.setDescription('Total number of advertisements sent by the mobility\n                agent.')
maAdvsSentForSolicitation = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 4, 2, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: maAdvsSentForSolicitation.setDescription('Total number of advertisements sent by mobility agent\n                in response to mobile node solicitations.')
maSolicitationsReceived = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 4, 2, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: maSolicitationsReceived.setDescription('Total number of solicitations received by the\n                mobility agent.')
faCOATable = MibTable((1, 3, 6, 1, 2, 1, 44, 1, 5, 1, 1), )
if mibBuilder.loadTexts: faCOATable.setDescription('A table containing all of the care-of addresses\n                (COAs) supported by the foreign agent. New entries can\n                be added to the table. The order of entries in the\n                faCOATAble is also the order in which the COAs are\n                listed in the Agent Advertisement.')
faCOAEntry = MibTableRow((1, 3, 6, 1, 2, 1, 44, 1, 5, 1, 1, 1), ).setIndexNames((0, "MIP-MIB", "faSupportedCOA"))
if mibBuilder.loadTexts: faCOAEntry.setDescription('Entry of COA')
faSupportedCOA = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 5, 1, 1, 1, 1), IpAddress())
if mibBuilder.loadTexts: faSupportedCOA.setDescription('Care-of-address supported by this foreign agent.')
faCOAStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 5, 1, 1, 1, 2), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: faCOAStatus.setDescription('The row status for COA entry.')
faIsBusy = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 5, 2, 1), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: faIsBusy.setDescription("Whether or not the foreign agent is too busy to\n                accept additional registrations. If true(1), the agent\n                is busy and any Agent advertisements sent from this\n                agent should have the 'B' bit set to 1.")
faRegistrationRequired = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 5, 2, 2), TruthValue()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: faRegistrationRequired.setDescription("Whether or not this foreign agent requires\n                registration even from those mobile nodes that have\n                acquired their own, colocated care-of address.  If\n                true(1), registration is required and any Agent\n                Advertisements sent from this agent should have the\n                'R' bit set to 1.")
faVisitorTable = MibTable((1, 3, 6, 1, 2, 1, 44, 1, 5, 3, 1), )
if mibBuilder.loadTexts: faVisitorTable.setDescription("A table containing the foreign agent's visitor list.\n                The foreign agent updates this table in response to\n                registration events from mobile nodes.")
faVisitorEntry = MibTableRow((1, 3, 6, 1, 2, 1, 44, 1, 5, 3, 1, 1), ).setIndexNames((0, "MIP-MIB", "faVisitorIPAddress"))
if mibBuilder.loadTexts: faVisitorEntry.setDescription('Information for one visitor.')
faVisitorIPAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 5, 3, 1, 1, 1), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: faVisitorIPAddress.setDescription("Source IP address of visitor's Registration Request.")
faVisitorHomeAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 5, 3, 1, 1, 2), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: faVisitorHomeAddress.setDescription('Home (IP) address of visiting mobile node.')
faVisitorHomeAgentAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 5, 3, 1, 1, 3), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: faVisitorHomeAgentAddress.setDescription('Home agent IP address for that visiting mobile node.')
faVisitorTimeGranted = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 5, 3, 1, 1, 4), Integer32()).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: faVisitorTimeGranted.setDescription('The lifetime in seconds granted to the mobile node\n                for this registration.  Only valid if\n                faVisitorRegIsAccepted is true(1).')
faVisitorTimeRemaining = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 5, 3, 1, 1, 5), Gauge32()).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: faVisitorTimeRemaining.setDescription('The number of seconds remaining until the\n                registration is expired. It has the same initial value\n                as faVisitorTimeGranted, and is counted down by the\n                foreign agent.')
faVisitorRegFlags = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 5, 3, 1, 1, 6), RegistrationFlags()).setMaxAccess("readonly")
if mibBuilder.loadTexts: faVisitorRegFlags.setDescription('Registration flags sent by mobile node.')
faVisitorRegIDLow = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 5, 3, 1, 1, 7), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: faVisitorRegIDLow.setDescription('Low 32 bits of Identification used in that\n                registration by the mobile node.')
faVisitorRegIDHigh = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 5, 3, 1, 1, 8), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: faVisitorRegIDHigh.setDescription('High 32 bits of Identification used in that\n                registration by the mobile node.')
faVisitorRegIsAccepted = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 5, 3, 1, 1, 9), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: faVisitorRegIsAccepted.setDescription('Whether the registration has been accepted or not. If\n                it is false(2), this registration is still pending for\n                reply.')
faRegRequestsReceived = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 5, 3, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: faRegRequestsReceived.setDescription('Total number of valid Registration Requests\n                received.')
faRegRequestsRelayed = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 5, 3, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: faRegRequestsRelayed.setDescription('Total number of Registration Requests relayed to home\n                agent by foreign agent.')
faReasonUnspecified = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 5, 3, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: faReasonUnspecified.setDescription('Total number of Registration Requests denied by\n                foreign agent -- reason unspecified (Code 64).')
faAdmProhibited = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 5, 3, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: faAdmProhibited.setDescription('Total number of Registration Requests denied by\n                foreign agent -- administratively prohibited (Code\n                65).')
faInsufficientResource = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 5, 3, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: faInsufficientResource.setDescription('Total number of Registration Requests denied by\n                foreign agent -- insufficient resources (Code 66).')
faMNAuthenticationFailure = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 5, 3, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: faMNAuthenticationFailure.setDescription('Total number of Registration Requests denied by\n                foreign agent -- mobile node failed authentication\n                (Code 67).')
faRegLifetimeTooLong = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 5, 3, 8), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: faRegLifetimeTooLong.setDescription('Total number of Registration Requests denied by\n                foreign agent -- requested lifetime too long (Code\n                69).')
faPoorlyFormedRequests = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 5, 3, 9), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: faPoorlyFormedRequests.setDescription('Total number of Registration Requests denied by\n                foreign agent -- poorly formed request (Code 70).')
faEncapsulationUnavailable = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 5, 3, 10), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: faEncapsulationUnavailable.setDescription('Total number of Registration Requests denied by\n                foreign agent -- requested encapsulation unavailable\n                (Code 72).')
faVJCompressionUnavailable = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 5, 3, 11), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: faVJCompressionUnavailable.setDescription('Total number of Registration Requests denied by\n                foreign agent -- requested Van Jacobson header\n                compression unavailable (Code 73).')
faHAUnreachable = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 5, 3, 12), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: faHAUnreachable.setDescription('Total number of Registration Requests denied by\n                foreign agent -- home agent unreachable (Codes\n                80-95).')
faRegRepliesRecieved = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 5, 3, 13), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: faRegRepliesRecieved.setDescription('Total number of well-formed Registration Replies\n                received by foreign agent.')
faRegRepliesRelayed = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 5, 3, 14), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: faRegRepliesRelayed.setDescription('Total number of valid Registration Replies relayed to\n                the mobile node by foreign agent.')
faHAAuthenticationFailure = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 5, 3, 15), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: faHAAuthenticationFailure.setDescription('Total number of Registration Replies denied by\n                foreign agent -- home agent failed authentication\n                (Code 68).')
faPoorlyFormedReplies = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 5, 3, 16), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: faPoorlyFormedReplies.setDescription('Total number of Registration Replies denied by\n                foreign agent -- poorly formed reply (Code 71).')
haMobilityBindingTable = MibTable((1, 3, 6, 1, 2, 1, 44, 1, 6, 3, 1), )
if mibBuilder.loadTexts: haMobilityBindingTable.setDescription("A table containing the home agent's mobility binding\n                list.  The home agent updates this table in response\n                to registration events from mobile nodes.")
haMobilityBindingEntry = MibTableRow((1, 3, 6, 1, 2, 1, 44, 1, 6, 3, 1, 1), ).setIndexNames((0, "MIP-MIB", "haMobilityBindingMN"), (0, "MIP-MIB", "haMobilityBindingCOA"))
if mibBuilder.loadTexts: haMobilityBindingEntry.setDescription('An entry on the mobility binding list.')
haMobilityBindingMN = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 6, 3, 1, 1, 1), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: haMobilityBindingMN.setDescription("Mobile node's home (IP) address.")
haMobilityBindingCOA = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 6, 3, 1, 1, 2), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: haMobilityBindingCOA.setDescription("Mobile node's care-of-address. One mobile node can\n                have multiple bindings with different\n                care-of-addresses.")
haMobilityBindingSourceAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 6, 3, 1, 1, 3), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: haMobilityBindingSourceAddress.setDescription("IP source address of the Registration Request as\n                received by the home agent.  Will be either a mobile\n                node's co-located care-of address or an address of the\n                foreign agent.")
haMobilityBindingRegFlags = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 6, 3, 1, 1, 4), RegistrationFlags()).setMaxAccess("readonly")
if mibBuilder.loadTexts: haMobilityBindingRegFlags.setDescription('Registration flags sent by mobile node.')
haMobilityBindingRegIDLow = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 6, 3, 1, 1, 5), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: haMobilityBindingRegIDLow.setDescription('Low 32 bits of Identification used in that binding by\n                the mobile node.')
haMobilityBindingRegIDHigh = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 6, 3, 1, 1, 6), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: haMobilityBindingRegIDHigh.setDescription('High 32 bits of Identification used in that binding by\n                the mobile node.')
haMobilityBindingTimeGranted = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 6, 3, 1, 1, 7), Integer32()).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: haMobilityBindingTimeGranted.setDescription('The lifetime in seconds granted to the mobile node\n                for this registration.')
haMobilityBindingTimeRemaining = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 6, 3, 1, 1, 8), Gauge32()).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: haMobilityBindingTimeRemaining.setDescription('The number of seconds remaining until the\n                registration is expired. It has the same initial value\n                as haMobilityBindingTimeGranted, and is counted down\n                by the home agent.')
haCounterTable = MibTable((1, 3, 6, 1, 2, 1, 44, 1, 6, 3, 2), )
if mibBuilder.loadTexts: haCounterTable.setDescription('A table containing registration statistics for all\n                mobile nodes authorized to use this home agent.')
haCounterEntry = MibTableRow((1, 3, 6, 1, 2, 1, 44, 1, 6, 3, 2, 1), ).setIndexNames((0, "MIP-MIB", "haMobilityBindingMN"))
if mibBuilder.loadTexts: haCounterEntry.setDescription('Registration statistics for one mobile node.')
haServiceRequestsAccepted = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 6, 3, 2, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: haServiceRequestsAccepted.setDescription('Total number of service requests for the mobile node\n                accepted by the home agent (Code 0 + Code 1).')
haServiceRequestsDenied = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 6, 3, 2, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: haServiceRequestsDenied.setDescription('Total number of service requests for the mobile node\n                denied by the home agent (sum of all registrations\n                denied with Code 128 through Code 159).')
haOverallServiceTime = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 6, 3, 2, 1, 4), Gauge32()).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: haOverallServiceTime.setDescription('Overall service time (in seconds) that has\n                accumulated for the mobile node since the home agent\n                last rebooted.')
haRecentServiceAcceptedTime = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 6, 3, 2, 1, 5), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: haRecentServiceAcceptedTime.setDescription('The time at which the most recent Registration\n                Request was accepted by the home agent for this mobile\n                node.')
haRecentServiceDeniedTime = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 6, 3, 2, 1, 6), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: haRecentServiceDeniedTime.setDescription('The time at which the most recent Registration\n                Request was denied by the home agent for this mobile\n                node.')
haRecentServiceDeniedCode = MibTableColumn((1, 3, 6, 1, 2, 1, 44, 1, 6, 3, 2, 1, 7), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(128, 129, 130, 131, 132, 133, 134, 135, 136,))).clone(namedValues=NamedValues(("reasonUnspecified", 128), ("admProhibited", 129), ("insufficientResource", 130), ("mnAuthenticationFailure", 131), ("faAuthenticationFailure", 132), ("idMismatch", 133), ("poorlyFormedRequest", 134), ("tooManyBindings", 135), ("unknownHA", 136),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: haRecentServiceDeniedCode.setDescription('The Code indicating the reason why the most recent\n                Registration Request for this mobile node was rejected\n                by the home agent.')
haRegistrationAccepted = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 6, 3, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: haRegistrationAccepted.setDescription('Total number of Registration Requests accepted by\n                home agent (Code 0).')
haMultiBindingUnsupported = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 6, 3, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: haMultiBindingUnsupported.setDescription('Total number of Registration Requests accepted by\n                home agent -- simultaneous mobility bindings\n                unsupported (Code 1).')
haReasonUnspecified = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 6, 3, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: haReasonUnspecified.setDescription('Total number of Registration Requests denied by home\n                agent -- reason unspecified (Code 128).')
haAdmProhibited = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 6, 3, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: haAdmProhibited.setDescription('Total number of Registration Requests denied by home\n                agent -- administratively prohibited (Code 129).')
haInsufficientResource = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 6, 3, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: haInsufficientResource.setDescription('Total number of Registration Requests denied by home\n                agent -- insufficient resources (Code 130).')
haMNAuthenticationFailure = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 6, 3, 8), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: haMNAuthenticationFailure.setDescription('Total number of Registration Requests denied by home\n                agent -- mobile node failed authentication (Code\n                131).')
haFAAuthenticationFailure = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 6, 3, 9), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: haFAAuthenticationFailure.setDescription('Total number of Registration Requests denied by home\n                agent -- foreign agent failed authentication (Code\n                132).')
haIDMismatch = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 6, 3, 10), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: haIDMismatch.setDescription('Total number of Registration Requests denied by home\n                agent -- Identification mismatch (Code 133).')
haPoorlyFormedRequest = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 6, 3, 11), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: haPoorlyFormedRequest.setDescription('Total number of Registration Requests denied by home\n                agent -- poorly formed request (Code 134).')
haTooManyBindings = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 6, 3, 12), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: haTooManyBindings.setDescription('Total number of Registration Requests denied by home\n                agent -- too many simultaneous mobility bindings (Code\n                135).')
haUnknownHA = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 6, 3, 13), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: haUnknownHA.setDescription('Total number of Registration Requests denied by home\n                agent -- unknown home agent address (Code 136).')
haGratuitiousARPsSent = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 6, 3, 14), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: haGratuitiousARPsSent.setDescription('Total number of gratuition ARPs sent by the home\n                agent on behalf of mobile nodes.')
haProxyARPsSent = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 6, 3, 15), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: haProxyARPsSent.setDescription('Total number of proxy ARPs sent by the home agent on\n                behalf of mobile nodes.')
haRegRequestsReceived = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 6, 3, 16), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: haRegRequestsReceived.setDescription('Total number of Registration Requests received by\n                home agent.')
haDeRegRequestsReceived = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 6, 3, 17), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: haDeRegRequestsReceived.setDescription('Total number of Registration Requests received by the\n                home agent with a Lifetime of zero (requests to\n                deregister).')
haRegRepliesSent = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 6, 3, 18), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: haRegRepliesSent.setDescription('Total number of Registration Replies sent by the home\n                agent.')
haDeRegRepliesSent = MibScalar((1, 3, 6, 1, 2, 1, 44, 1, 6, 3, 19), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: haDeRegRepliesSent.setDescription('Total number of Registration Replies sent by the home\n                agent in response to requests to deregister.')
mipMIBNotificationPrefix = MibIdentifier((1, 3, 6, 1, 2, 1, 44, 2))
mipMIBNotifications = MibIdentifier((1, 3, 6, 1, 2, 1, 44, 2, 0))
mipAuthFailure = NotificationType((1, 3, 6, 1, 2, 1, 44, 2, 0, 1)).setObjects(*(("MIP-MIB", "mipSecViolatorAddress"), ("MIP-MIB", "mipSecRecentViolationSPI"), ("MIP-MIB", "mipSecRecentViolationIDLow"), ("MIP-MIB", "mipSecRecentViolationIDHigh"), ("MIP-MIB", "mipSecRecentViolationReason"),))
if mibBuilder.loadTexts: mipAuthFailure.setDescription('The mipAuthFailure indicates that the Mobile IP\n                entity has an authentication failure when it validates\n                the mobile Registration Request or Reply.\n                Implementation of this trap is optional.')
mipMIBConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 44, 3))
mipGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 44, 3, 1))
mipCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 44, 3, 2))
mipCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 44, 3, 2, 1)).setObjects(*(("MIP-MIB", "mipSystemGroup"), ("MIP-MIB", "mipSecAssociationGroup"), ("MIP-MIB", "mipSecViolationGroup"), ("MIP-MIB", "mnSystemGroup"), ("MIP-MIB", "mnDiscoveryGroup"), ("MIP-MIB", "mnRegistrationGroup"), ("MIP-MIB", "maAdvertisementGroup"), ("MIP-MIB", "faSystemGroup"), ("MIP-MIB", "faAdvertisementGroup"), ("MIP-MIB", "faRegistrationGroup"), ("MIP-MIB", "haRegistrationGroup"), ("MIP-MIB", "haRegNodeCountersGroup"), ("MIP-MIB", "mipSecNotificationsGroup"),))
if mibBuilder.loadTexts: mipCompliance.setDescription('The compliance statement for SNMPv2 entities which\n                implement the Mobile IP MIB.')
mipSystemGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 44, 3, 1, 1)).setObjects(*(("MIP-MIB", "mipEntities"), ("MIP-MIB", "mipEnable"), ("MIP-MIB", "mipEncapsulationSupported"),))
if mibBuilder.loadTexts: mipSystemGroup.setDescription("A collection of objects providing the basic Mobile IP\n                entity's management information.")
mipSecAssociationGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 44, 3, 1, 2)).setObjects(*(("MIP-MIB", "mipSecAlgorithmType"), ("MIP-MIB", "mipSecAlgorithmMode"), ("MIP-MIB", "mipSecKey"), ("MIP-MIB", "mipSecReplayMethod"),))
if mibBuilder.loadTexts: mipSecAssociationGroup.setDescription('A collection of objects providing the management\n                information for security associations of Mobile IP\n                entities.')
mipSecViolationGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 44, 3, 1, 3)).setObjects(*(("MIP-MIB", "mipSecTotalViolations"), ("MIP-MIB", "mipSecViolationCounter"), ("MIP-MIB", "mipSecRecentViolationSPI"), ("MIP-MIB", "mipSecRecentViolationTime"), ("MIP-MIB", "mipSecRecentViolationIDLow"), ("MIP-MIB", "mipSecRecentViolationIDHigh"), ("MIP-MIB", "mipSecRecentViolationReason"),))
if mibBuilder.loadTexts: mipSecViolationGroup.setDescription('A collection of objects providing the management\n                information for security violation logging of Mobile\n                IP entities.')
mnSystemGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 44, 3, 1, 4)).setObjects(*(("MIP-MIB", "mnState"), ("MIP-MIB", "mnCurrentHA"), ("MIP-MIB", "mnHomeAddress"), ("MIP-MIB", "mnHAStatus"),))
if mibBuilder.loadTexts: mnSystemGroup.setDescription('A collection of objects providing the basic\n                management information for mobile nodes.')
mnDiscoveryGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 44, 3, 1, 5)).setObjects(*(("MIP-MIB", "mnFAAddress"), ("MIP-MIB", "mnCOA"), ("MIP-MIB", "mnAdvSourceAddress"), ("MIP-MIB", "mnAdvSequence"), ("MIP-MIB", "mnAdvFlags"), ("MIP-MIB", "mnAdvMaxRegLifetime"), ("MIP-MIB", "mnAdvMaxAdvLifetime"), ("MIP-MIB", "mnAdvTimeReceived"), ("MIP-MIB", "mnSolicitationsSent"), ("MIP-MIB", "mnAdvertisementsReceived"), ("MIP-MIB", "mnAdvsDroppedInvalidExtension"), ("MIP-MIB", "mnAdvsIgnoredUnknownExtension"), ("MIP-MIB", "mnMoveFromHAToFA"), ("MIP-MIB", "mnMoveFromFAToFA"), ("MIP-MIB", "mnMoveFromFAToHA"), ("MIP-MIB", "mnGratuitousARPsSend"), ("MIP-MIB", "mnAgentRebootsDectected"),))
if mibBuilder.loadTexts: mnDiscoveryGroup.setDescription('A collection of objects providing management\n                information for the Agent Discovery function within a\n                mobile node.')
mnRegistrationGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 44, 3, 1, 6)).setObjects(*(("MIP-MIB", "mnRegAgentAddress"), ("MIP-MIB", "mnRegCOA"), ("MIP-MIB", "mnRegFlags"), ("MIP-MIB", "mnRegIDLow"), ("MIP-MIB", "mnRegIDHigh"), ("MIP-MIB", "mnRegTimeRequested"), ("MIP-MIB", "mnRegTimeRemaining"), ("MIP-MIB", "mnRegTimeSent"), ("MIP-MIB", "mnRegIsAccepted"), ("MIP-MIB", "mnCOAIsLocal"), ("MIP-MIB", "mnRegRequestsSent"), ("MIP-MIB", "mnRegRepliesRecieved"), ("MIP-MIB", "mnDeRegRequestsSent"), ("MIP-MIB", "mnDeRegRepliesRecieved"), ("MIP-MIB", "mnRepliesInvalidHomeAddress"), ("MIP-MIB", "mnRepliesUnknownHA"), ("MIP-MIB", "mnRepliesUnknownFA"), ("MIP-MIB", "mnRepliesInvalidID"), ("MIP-MIB", "mnRepliesDroppedInvalidExtension"), ("MIP-MIB", "mnRepliesIgnoredUnknownExtension"), ("MIP-MIB", "mnRepliesHAAuthenticationFailure"), ("MIP-MIB", "mnRepliesFAAuthenticationFailure"), ("MIP-MIB", "mnRegRequestsAccepted"), ("MIP-MIB", "mnRegRequestsDeniedByHA"), ("MIP-MIB", "mnRegRequestsDeniedByFA"), ("MIP-MIB", "mnRegRequestsDeniedByHADueToID"), ("MIP-MIB", "mnRegRequestsWithDirectedBroadcast"),))
if mibBuilder.loadTexts: mnRegistrationGroup.setDescription('A collection of objects providing management\n                information for the registration function within a\n                mobile node.')
maAdvertisementGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 44, 3, 1, 7)).setObjects(*(("MIP-MIB", "maAdvMaxRegLifetime"), ("MIP-MIB", "maAdvPrefixLengthInclusion"), ("MIP-MIB", "maAdvAddress"), ("MIP-MIB", "maAdvMaxInterval"), ("MIP-MIB", "maAdvMinInterval"), ("MIP-MIB", "maAdvMaxAdvLifetime"), ("MIP-MIB", "maAdvResponseSolicitationOnly"), ("MIP-MIB", "maAdvStatus"), ("MIP-MIB", "maAdvertisementsSent"), ("MIP-MIB", "maAdvsSentForSolicitation"), ("MIP-MIB", "maSolicitationsReceived"),))
if mibBuilder.loadTexts: maAdvertisementGroup.setDescription('A collection of objects providing management\n                information for the Agent Advertisement function\n                within mobility agents.')
faSystemGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 44, 3, 1, 8)).setObjects(*(("MIP-MIB", "faCOAStatus"),))
if mibBuilder.loadTexts: faSystemGroup.setDescription('A collection of objects providing the basic\n                management information for foreign agents.')
faAdvertisementGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 44, 3, 1, 9)).setObjects(*(("MIP-MIB", "faIsBusy"), ("MIP-MIB", "faRegistrationRequired"),))
if mibBuilder.loadTexts: faAdvertisementGroup.setDescription('A collection of objects providing supplemental\n                management information for the Agent Advertisement\n                function within a foreign agent.')
faRegistrationGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 44, 3, 1, 10)).setObjects(*(("MIP-MIB", "faVisitorIPAddress"), ("MIP-MIB", "faVisitorHomeAddress"), ("MIP-MIB", "faVisitorHomeAgentAddress"), ("MIP-MIB", "faVisitorTimeGranted"), ("MIP-MIB", "faVisitorTimeRemaining"), ("MIP-MIB", "faVisitorRegFlags"), ("MIP-MIB", "faVisitorRegIDLow"), ("MIP-MIB", "faVisitorRegIDHigh"), ("MIP-MIB", "faVisitorRegIsAccepted"), ("MIP-MIB", "faRegRequestsReceived"), ("MIP-MIB", "faRegRequestsRelayed"), ("MIP-MIB", "faReasonUnspecified"), ("MIP-MIB", "faAdmProhibited"), ("MIP-MIB", "faInsufficientResource"), ("MIP-MIB", "faMNAuthenticationFailure"), ("MIP-MIB", "faRegLifetimeTooLong"), ("MIP-MIB", "faPoorlyFormedRequests"), ("MIP-MIB", "faEncapsulationUnavailable"), ("MIP-MIB", "faVJCompressionUnavailable"), ("MIP-MIB", "faHAUnreachable"), ("MIP-MIB", "faRegRepliesRecieved"), ("MIP-MIB", "faRegRepliesRelayed"), ("MIP-MIB", "faHAAuthenticationFailure"), ("MIP-MIB", "faPoorlyFormedReplies"),))
if mibBuilder.loadTexts: faRegistrationGroup.setDescription('A collection of objects providing management\n                information for the registration function within a\n                foreign agent.')
haRegistrationGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 44, 3, 1, 11)).setObjects(*(("MIP-MIB", "haMobilityBindingMN"), ("MIP-MIB", "haMobilityBindingCOA"), ("MIP-MIB", "haMobilityBindingSourceAddress"), ("MIP-MIB", "haMobilityBindingRegFlags"), ("MIP-MIB", "haMobilityBindingRegIDLow"), ("MIP-MIB", "haMobilityBindingRegIDHigh"), ("MIP-MIB", "haMobilityBindingTimeGranted"), ("MIP-MIB", "haMobilityBindingTimeRemaining"), ("MIP-MIB", "haRegistrationAccepted"), ("MIP-MIB", "haMultiBindingUnsupported"), ("MIP-MIB", "haReasonUnspecified"), ("MIP-MIB", "haAdmProhibited"), ("MIP-MIB", "haInsufficientResource"), ("MIP-MIB", "haMNAuthenticationFailure"), ("MIP-MIB", "haFAAuthenticationFailure"), ("MIP-MIB", "haIDMismatch"), ("MIP-MIB", "haPoorlyFormedRequest"), ("MIP-MIB", "haTooManyBindings"), ("MIP-MIB", "haUnknownHA"), ("MIP-MIB", "haGratuitiousARPsSent"), ("MIP-MIB", "haProxyARPsSent"), ("MIP-MIB", "haRegRequestsReceived"), ("MIP-MIB", "haDeRegRequestsReceived"), ("MIP-MIB", "haRegRepliesSent"), ("MIP-MIB", "haDeRegRepliesSent"),))
if mibBuilder.loadTexts: haRegistrationGroup.setDescription('A collection of objects providing management\n                information for the registration function within a\n                home agent.')
haRegNodeCountersGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 44, 3, 1, 12)).setObjects(*(("MIP-MIB", "haServiceRequestsAccepted"), ("MIP-MIB", "haServiceRequestsDenied"), ("MIP-MIB", "haOverallServiceTime"), ("MIP-MIB", "haRecentServiceAcceptedTime"), ("MIP-MIB", "haRecentServiceDeniedTime"), ("MIP-MIB", "haRecentServiceDeniedCode"),))
if mibBuilder.loadTexts: haRegNodeCountersGroup.setDescription('A collection of objects providing management\n                information for counters related to the registration\n                function within a home agent.')
mipSecNotificationsGroup = NotificationGroup((1, 3, 6, 1, 2, 1, 44, 3, 1, 13)).setObjects(*(("MIP-MIB", "mipAuthFailure"),))
if mibBuilder.loadTexts: mipSecNotificationsGroup.setDescription('The notification related to security violations.')
mibBuilder.exportSymbols("MIP-MIB", haAdmProhibited=haAdmProhibited, mipSecViolationGroup=mipSecViolationGroup, faCOATable=faCOATable, mipSystem=mipSystem, haFAAuthenticationFailure=haFAAuthenticationFailure, mipSecRecentViolationIDHigh=mipSecRecentViolationIDHigh, maInterfaceAddress=maInterfaceAddress, faCOAEntry=faCOAEntry, faAdvertisementGroup=faAdvertisementGroup, mipSecViolationEntry=mipSecViolationEntry, haServiceRequestsDenied=haServiceRequestsDenied, haMobilityBindingRegIDHigh=haMobilityBindingRegIDHigh, mipSecAssocTable=mipSecAssocTable, mnFAAddress=mnFAAddress, mnMoveFromFAToFA=mnMoveFromFAToFA, mipMIBObjects=mipMIBObjects, mipCompliances=mipCompliances, maAdvertisementGroup=maAdvertisementGroup, mnFATable=mnFATable, haProxyARPsSent=haProxyARPsSent, mipSecurity=mipSecurity, mnRegRequestsSent=mnRegRequestsSent, mnRegIDHigh=mnRegIDHigh, haMobilityBindingTimeGranted=haMobilityBindingTimeGranted, haTooManyBindings=haTooManyBindings, haMobilityBindingTimeRemaining=haMobilityBindingTimeRemaining, haRegRequestsReceived=haRegRequestsReceived, mnHomeAddress=mnHomeAddress, mnSolicitationsSent=mnSolicitationsSent, mnDeRegRequestsSent=mnDeRegRequestsSent, mnCOAIsLocal=mnCOAIsLocal, maAdvPrefixLengthInclusion=maAdvPrefixLengthInclusion, haCounterTable=haCounterTable, maAdvStatus=maAdvStatus, faVisitorHomeAgentAddress=faVisitorHomeAgentAddress, mipFA=mipFA, maAdvResponseSolicitationOnly=maAdvResponseSolicitationOnly, faVisitorRegIsAccepted=faVisitorRegIsAccepted, maAdvAddress=maAdvAddress, maAdvertisement=maAdvertisement, RegistrationFlags=RegistrationFlags, mnRegistrationTable=mnRegistrationTable, maAdvMaxRegLifetime=maAdvMaxRegLifetime, mipCompliance=mipCompliance, mipEncapsulationSupported=mipEncapsulationSupported, mnSystem=mnSystem, mnDiscovery=mnDiscovery, mipMIB=mipMIB, haDeRegRequestsReceived=haDeRegRequestsReceived, faRegistrationRequired=faRegistrationRequired, faCOAStatus=faCOAStatus, mnRepliesDroppedInvalidExtension=mnRepliesDroppedInvalidExtension, haMobilityBindingEntry=haMobilityBindingEntry, faPoorlyFormedRequests=faPoorlyFormedRequests, mnRegFlags=mnRegFlags, haMobilityBindingRegIDLow=haMobilityBindingRegIDLow, faAdvertisement=faAdvertisement, mnAdvertisementsReceived=mnAdvertisementsReceived, mnAdvTimeReceived=mnAdvTimeReceived, mipGroups=mipGroups, mipEntities=mipEntities, mnHAEntry=mnHAEntry, mnAgentRebootsDectected=mnAgentRebootsDectected, mnDeRegRepliesRecieved=mnDeRegRepliesRecieved, haIDMismatch=haIDMismatch, haRegistrationAccepted=haRegistrationAccepted, faVisitorTimeRemaining=faVisitorTimeRemaining, maSolicitationsReceived=maSolicitationsReceived, faReasonUnspecified=faReasonUnspecified, maAdvertisementsSent=maAdvertisementsSent, faEncapsulationUnavailable=faEncapsulationUnavailable, haReasonUnspecified=haReasonUnspecified, maAdvsSentForSolicitation=maAdvsSentForSolicitation, mnRegRepliesRecieved=mnRegRepliesRecieved, mnHAStatus=mnHAStatus, faVisitorIPAddress=faVisitorIPAddress, mnRegRequestsDeniedByHADueToID=mnRegRequestsDeniedByHADueToID, mipSecNotificationsGroup=mipSecNotificationsGroup, haPoorlyFormedRequest=haPoorlyFormedRequest, mipSecRecentViolationIDLow=mipSecRecentViolationIDLow, faVisitorRegFlags=faVisitorRegFlags, haInsufficientResource=haInsufficientResource, mipEnable=mipEnable, maAdvConfigEntry=maAdvConfigEntry, faIsBusy=faIsBusy, haMobilityBindingSourceAddress=haMobilityBindingSourceAddress, mnAdvMaxRegLifetime=mnAdvMaxRegLifetime, haMobilityBindingMN=haMobilityBindingMN, faVJCompressionUnavailable=faVJCompressionUnavailable, haRegRepliesSent=haRegRepliesSent, mnMoveFromHAToFA=mnMoveFromHAToFA, faSystem=faSystem, mnRepliesIgnoredUnknownExtension=mnRepliesIgnoredUnknownExtension, faRegRepliesRecieved=faRegRepliesRecieved, haMobilityBindingRegFlags=haMobilityBindingRegFlags, mipSecRecentViolationTime=mipSecRecentViolationTime, mipSystemGroup=mipSystemGroup, mnState=mnState, mnRepliesInvalidID=mnRepliesInvalidID, mipSecSPI=mipSecSPI, mnRepliesHAAuthenticationFailure=mnRepliesHAAuthenticationFailure, mnRegistrationEntry=mnRegistrationEntry, faVisitorTable=faVisitorTable, mipAuthFailure=mipAuthFailure, faSystemGroup=faSystemGroup, faRegRequestsReceived=faRegRequestsReceived, faRegRequestsRelayed=faRegRequestsRelayed, haServiceRequestsAccepted=haServiceRequestsAccepted, maAdvMaxAdvLifetime=maAdvMaxAdvLifetime, mipMIBNotificationPrefix=mipMIBNotificationPrefix, mnRepliesUnknownFA=mnRepliesUnknownFA, maAdvMaxInterval=maAdvMaxInterval, mnRegRequestsAccepted=mnRegRequestsAccepted, haRecentServiceDeniedTime=haRecentServiceDeniedTime, faRegLifetimeTooLong=faRegLifetimeTooLong, mipSecViolationCounter=mipSecViolationCounter, mipSecReplayMethod=mipSecReplayMethod, faRegRepliesRelayed=faRegRepliesRelayed, faAdmProhibited=faAdmProhibited, mnGratuitousARPsSend=mnGratuitousARPsSend, mipSecAssociationGroup=mipSecAssociationGroup, haOverallServiceTime=haOverallServiceTime, mnAdvsIgnoredUnknownExtension=mnAdvsIgnoredUnknownExtension, faHAUnreachable=faHAUnreachable, mipSecViolatorAddress=mipSecViolatorAddress, haRegNodeCountersGroup=haRegNodeCountersGroup, maAdvConfigTable=maAdvConfigTable, faVisitorHomeAddress=faVisitorHomeAddress, mnRegIsAccepted=mnRegIsAccepted, mipSecRecentViolationReason=mipSecRecentViolationReason, mnMoveFromFAToHA=mnMoveFromFAToHA, haMNAuthenticationFailure=haMNAuthenticationFailure, faRegistrationGroup=faRegistrationGroup, mnCOA=mnCOA, mipSecAlgorithmType=mipSecAlgorithmType, mipMIBConformance=mipMIBConformance, mipSecRecentViolationSPI=mipSecRecentViolationSPI, haRegistration=haRegistration, mnRecentAdvReceived=mnRecentAdvReceived, mnAdvSequence=mnAdvSequence, mnRegRequestsDeniedByFA=mnRegRequestsDeniedByFA, haGratuitiousARPsSent=haGratuitiousARPsSent, mnAdvMaxAdvLifetime=mnAdvMaxAdvLifetime, faSupportedCOA=faSupportedCOA, mnHAAddress=mnHAAddress, haCounterEntry=haCounterEntry, mnRegTimeRequested=mnRegTimeRequested, faPoorlyFormedReplies=faPoorlyFormedReplies, mnRepliesUnknownHA=mnRepliesUnknownHA, mipSecAssocEntry=mipSecAssocEntry, faInsufficientResource=faInsufficientResource, mipSecViolationTable=mipSecViolationTable, mnHATable=mnHATable, mnRepliesInvalidHomeAddress=mnRepliesInvalidHomeAddress, mnAdvSourceAddress=mnAdvSourceAddress, mnRegAgentAddress=mnRegAgentAddress, mnDiscoveryGroup=mnDiscoveryGroup, faVisitorRegIDHigh=faVisitorRegIDHigh, haRegistrationGroup=haRegistrationGroup, mnRepliesFAAuthenticationFailure=mnRepliesFAAuthenticationFailure, mnRegistrationGroup=mnRegistrationGroup, mnRegistration=mnRegistration, maAdvMinInterval=maAdvMinInterval, mipSecAlgorithmMode=mipSecAlgorithmMode, mnFAEntry=mnFAEntry, haRecentServiceAcceptedTime=haRecentServiceAcceptedTime, PYSNMP_MODULE_ID=mipMIB, mipMIBNotifications=mipMIBNotifications, haUnknownHA=haUnknownHA, haMobilityBindingCOA=haMobilityBindingCOA, haDeRegRepliesSent=haDeRegRepliesSent, faRegistration=faRegistration, mipSecKey=mipSecKey, mipSecPeerAddress=mipSecPeerAddress, faVisitorTimeGranted=faVisitorTimeGranted, mnRegIDLow=mnRegIDLow, mipMN=mipMN, faVisitorRegIDLow=faVisitorRegIDLow, mnRegCOA=mnRegCOA, faHAAuthenticationFailure=faHAAuthenticationFailure, mnRegRequestsWithDirectedBroadcast=mnRegRequestsWithDirectedBroadcast, mnAdvFlags=mnAdvFlags, mipHA=mipHA, haMobilityBindingTable=haMobilityBindingTable, mnRegTimeSent=mnRegTimeSent, mnCurrentHA=mnCurrentHA, haRecentServiceDeniedCode=haRecentServiceDeniedCode, mnSystemGroup=mnSystemGroup, mnAdvsDroppedInvalidExtension=mnAdvsDroppedInvalidExtension, mnRegTimeRemaining=mnRegTimeRemaining, haMultiBindingUnsupported=haMultiBindingUnsupported, faMNAuthenticationFailure=faMNAuthenticationFailure, faVisitorEntry=faVisitorEntry, mnRegRequestsDeniedByHA=mnRegRequestsDeniedByHA, mipMA=mipMA, mipSecTotalViolations=mipSecTotalViolations)
