#
# PySNMP MIB module NET-SNMP-AGENT-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/NET-SNMP-AGENT-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:22:30 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( OctetString, ObjectIdentifier, Integer, ) = mibBuilder.importSymbols("ASN1", "OctetString", "ObjectIdentifier", "Integer")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsUnion, ValueRangeConstraint, ConstraintsIntersection, ValueSizeConstraint, SingleValueConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsUnion", "ValueRangeConstraint", "ConstraintsIntersection", "ValueSizeConstraint", "SingleValueConstraint")
( netSnmpModuleIDs, netSnmpNotifications, netSnmpGroups, netSnmpObjects, ) = mibBuilder.importSymbols("NET-SNMP-MIB", "netSnmpModuleIDs", "netSnmpNotifications", "netSnmpGroups", "netSnmpObjects")
( SnmpAdminString, ) = mibBuilder.importSymbols("SNMP-FRAMEWORK-MIB", "SnmpAdminString")
( ModuleCompliance, ObjectGroup, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "ObjectGroup", "NotificationGroup")
( ObjectIdentity, Counter64, NotificationType, IpAddress, Integer32, MibScalar, MibTable, MibTableRow, MibTableColumn, MibIdentifier, ModuleIdentity, TimeTicks, Gauge32, Counter32, iso, Unsigned32, Bits, ) = mibBuilder.importSymbols("SNMPv2-SMI", "ObjectIdentity", "Counter64", "NotificationType", "IpAddress", "Integer32", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "MibIdentifier", "ModuleIdentity", "TimeTicks", "Gauge32", "Counter32", "iso", "Unsigned32", "Bits")
( TextualConvention, DisplayString, RowStatus, TruthValue, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "DisplayString", "RowStatus", "TruthValue")
netSnmpAgentMIB = ModuleIdentity((1, 3, 6, 1, 4, 1, 8072, 3, 1, 2)).setRevisions(("2010-03-17 00:00", "2005-02-07 00:00", "2002-02-09 00:00",))
if mibBuilder.loadTexts: netSnmpAgentMIB.setLastUpdated('201003170000Z')
if mibBuilder.loadTexts: netSnmpAgentMIB.setOrganization('www.net-snmp.org')
if mibBuilder.loadTexts: netSnmpAgentMIB.setContactInfo('postal:   Wes Hardaker\n                    P.O. Box 382\n                    Davis CA  95617\n\n          email:    net-snmp-coders@lists.sourceforge.net')
if mibBuilder.loadTexts: netSnmpAgentMIB.setDescription('Defines control and monitoring structures for the Net-SNMP agent.')
nsVersion = MibIdentifier((1, 3, 6, 1, 4, 1, 8072, 1, 1))
nsMibRegistry = MibIdentifier((1, 3, 6, 1, 4, 1, 8072, 1, 2))
nsExtensions = MibIdentifier((1, 3, 6, 1, 4, 1, 8072, 1, 3))
nsDLMod = MibIdentifier((1, 3, 6, 1, 4, 1, 8072, 1, 4))
nsCache = MibIdentifier((1, 3, 6, 1, 4, 1, 8072, 1, 5))
nsErrorHistory = MibIdentifier((1, 3, 6, 1, 4, 1, 8072, 1, 6))
nsConfiguration = MibIdentifier((1, 3, 6, 1, 4, 1, 8072, 1, 7))
nsTransactions = MibIdentifier((1, 3, 6, 1, 4, 1, 8072, 1, 8))
class NetsnmpCacheStatus(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))
    namedValues = NamedValues(("enabled", 1), ("disabled", 2), ("empty", 3), ("cached", 4), ("expired", 5),)

nsCacheDefaultTimeout = MibScalar((1, 3, 6, 1, 4, 1, 8072, 1, 5, 1), Integer32().clone(5)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: nsCacheDefaultTimeout.setDescription('Default cache timeout value (unless overridden\n       for a particular cache entry).')
nsCacheEnabled = MibScalar((1, 3, 6, 1, 4, 1, 8072, 1, 5, 2), TruthValue().clone('true')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: nsCacheEnabled.setDescription('Whether data caching is active overall.')
nsCacheTable = MibTable((1, 3, 6, 1, 4, 1, 8072, 1, 5, 3), )
if mibBuilder.loadTexts: nsCacheTable.setDescription('A table of individual MIB module data caches.')
nsCacheEntry = MibTableRow((1, 3, 6, 1, 4, 1, 8072, 1, 5, 3, 1), ).setIndexNames((1, "NET-SNMP-AGENT-MIB", "nsCachedOID"))
if mibBuilder.loadTexts: nsCacheEntry.setDescription('A conceptual row within the cache table.')
nsCachedOID = MibTableColumn((1, 3, 6, 1, 4, 1, 8072, 1, 5, 3, 1, 1), ObjectIdentifier())
if mibBuilder.loadTexts: nsCachedOID.setDescription('The root OID of the data being cached.')
nsCacheTimeout = MibTableColumn((1, 3, 6, 1, 4, 1, 8072, 1, 5, 3, 1, 2), Integer32()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: nsCacheTimeout.setDescription('The length of time (?in seconds) for which the data in\n       this particular cache entry will remain valid.')
nsCacheStatus = MibTableColumn((1, 3, 6, 1, 4, 1, 8072, 1, 5, 3, 1, 3), NetsnmpCacheStatus()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: nsCacheStatus.setDescription("The current status of this particular cache entry.\n       Acceptable values for Set requests are 'enabled(1)',\n       'disabled(2)' or 'empty(3)' (to clear all cached data).\n       Requests to read the value of such an object will\n       return 'disabled(2)' through to 'expired(5)'.")
nsConfigDebug = MibIdentifier((1, 3, 6, 1, 4, 1, 8072, 1, 7, 1))
nsConfigLogging = MibIdentifier((1, 3, 6, 1, 4, 1, 8072, 1, 7, 2))
nsDebugEnabled = MibScalar((1, 3, 6, 1, 4, 1, 8072, 1, 7, 1, 1), TruthValue().clone('false')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: nsDebugEnabled.setDescription('Whether the agent is configured to generate debugging output')
nsDebugOutputAll = MibScalar((1, 3, 6, 1, 4, 1, 8072, 1, 7, 1, 2), TruthValue().clone('false')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: nsDebugOutputAll.setDescription('Whether the agent is configured to display all debugging output\n       rather than filtering on individual debug tokens.  Nothing will\n       be generated unless nsDebugEnabled is also true(1)')
nsDebugDumpPdu = MibScalar((1, 3, 6, 1, 4, 1, 8072, 1, 7, 1, 3), TruthValue().clone('false')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: nsDebugDumpPdu.setDescription('Whether the agent is configured to display raw packet dumps.\n       This is unrelated to the nsDebugEnabled setting.')
nsDebugTokenTable = MibTable((1, 3, 6, 1, 4, 1, 8072, 1, 7, 1, 4), )
if mibBuilder.loadTexts: nsDebugTokenTable.setDescription('A table of individual debug tokens, used to control the selection\n       of what debugging output should be produced.  This table is only\n       effective if nsDebugOutputAll is false(2), and nothing will\n       be generated unless nsDebugEnabled is also true(1)')
nsDebugTokenEntry = MibTableRow((1, 3, 6, 1, 4, 1, 8072, 1, 7, 1, 4, 1), ).setIndexNames((1, "NET-SNMP-AGENT-MIB", "nsDebugTokenPrefix"))
if mibBuilder.loadTexts: nsDebugTokenEntry.setDescription('A conceptual row within the debug token table.')
nsDebugTokenPrefix = MibTableColumn((1, 3, 6, 1, 4, 1, 8072, 1, 7, 1, 4, 1, 2), DisplayString())
if mibBuilder.loadTexts: nsDebugTokenPrefix.setDescription('A token prefix for which to generate the corresponding\n       debugging output.  Note that debug output will be generated\n       for all registered debug statements sharing this prefix\n       (rather than an exact match).  Nothing will be generated\n       unless both nsDebuggingEnabled is set true(1) and the\n       corresponding nsDebugTokenStatus value is active(1).')
nsDebugTokenStatus = MibTableColumn((1, 3, 6, 1, 4, 1, 8072, 1, 7, 1, 4, 1, 4), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: nsDebugTokenStatus.setDescription("Whether to generate debug output for the corresponding debug\n       token prefix.  Nothing will be generated unless both\n       nsDebuggingEnabled is true(1) and this instance is active(1).\n       Note that is valid for an instance to be left with the value\n       notInService(2) indefinitely - i.e. the meaning of 'abnormally\n       long' (see RFC 2579, RowStatus) for this table is infinite.")
nsLoggingTable = MibTable((1, 3, 6, 1, 4, 1, 8072, 1, 7, 2, 1), )
if mibBuilder.loadTexts: nsLoggingTable.setDescription('A table of individual logging output destinations, used to control\n       where various levels of output from the agent should be directed.')
nsLoggingEntry = MibTableRow((1, 3, 6, 1, 4, 1, 8072, 1, 7, 2, 1, 1), ).setIndexNames((0, "NET-SNMP-AGENT-MIB", "nsLogLevel"), (1, "NET-SNMP-AGENT-MIB", "nsLogToken"))
if mibBuilder.loadTexts: nsLoggingEntry.setDescription('A conceptual row within the logging table.')
nsLogLevel = MibTableColumn((1, 3, 6, 1, 4, 1, 8072, 1, 7, 2, 1, 1, 1), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(0, 1, 2, 3, 4, 5, 6, 7,))).clone(namedValues=NamedValues(("emergency", 0), ("alert", 1), ("critical", 2), ("error", 3), ("warning", 4), ("notice", 5), ("info", 6), ("debug", 7),)))
if mibBuilder.loadTexts: nsLogLevel.setDescription('The (minimum) priority level for which this logging entry\n       should be applied.')
nsLogToken = MibTableColumn((1, 3, 6, 1, 4, 1, 8072, 1, 7, 2, 1, 1, 2), DisplayString())
if mibBuilder.loadTexts: nsLogToken.setDescription('A token for which to generate logging entries.\n       Depending on the style of logging, this may either\n       be simply an arbitrary token, or may have some\n       particular meaning (such as the filename to log to).')
nsLogType = MibTableColumn((1, 3, 6, 1, 4, 1, 8072, 1, 7, 2, 1, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))).clone(namedValues=NamedValues(("stdout", 1), ("stderr", 2), ("file", 3), ("syslog", 4), ("callback", 5),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: nsLogType.setDescription('The type of logging for this entry.')
nsLogMaxLevel = MibTableColumn((1, 3, 6, 1, 4, 1, 8072, 1, 7, 2, 1, 1, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(0, 1, 2, 3, 4, 5, 6, 7,))).clone(namedValues=NamedValues(("emergency", 0), ("alert", 1), ("critical", 2), ("error", 3), ("warning", 4), ("notice", 5), ("info", 6), ("debug", 7),)).clone('emergency')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: nsLogMaxLevel.setDescription('The maximum priority level for which this logging entry\n       should be applied.')
nsLogStatus = MibTableColumn((1, 3, 6, 1, 4, 1, 8072, 1, 7, 2, 1, 1, 5), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: nsLogStatus.setDescription("Whether to generate logging output for this entry.\n       Note that is valid for an instance to be left with the value\n       notInService(2) indefinitely - i.e. the meaning of 'abnormally\n       long' (see RFC 2579, RowStatus) for this table is infinite.")
nsTransactionTable = MibTable((1, 3, 6, 1, 4, 1, 8072, 1, 8, 1), )
if mibBuilder.loadTexts: nsTransactionTable.setDescription('Lists currently outstanding transactions in the net-snmp agent.\n\t This includes requests to AgentX subagents, or proxied SNMP agents.')
nsTransactionEntry = MibTableRow((1, 3, 6, 1, 4, 1, 8072, 1, 8, 1, 1), ).setIndexNames((0, "NET-SNMP-AGENT-MIB", "nsTransactionID"))
if mibBuilder.loadTexts: nsTransactionEntry.setDescription('A row describing a given transaction.')
nsTransactionID = MibTableColumn((1, 3, 6, 1, 4, 1, 8072, 1, 8, 1, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,4294967295)))
if mibBuilder.loadTexts: nsTransactionID.setDescription('The internal identifier for a given transaction.')
nsTransactionMode = MibTableColumn((1, 3, 6, 1, 4, 1, 8072, 1, 8, 1, 1, 2), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: nsTransactionMode.setDescription('The mode number for the current operation being performed.')
nsModuleTable = MibTable((1, 3, 6, 1, 4, 1, 8072, 1, 2, 1), )
if mibBuilder.loadTexts: nsModuleTable.setDescription("A table displaying all the oid's registered by mib modules in\n\t the agent.  Since the agent is modular in nature, this lists\n\t each module's OID it is responsible for and the name of the module")
nsModuleEntry = MibTableRow((1, 3, 6, 1, 4, 1, 8072, 1, 2, 1, 1), ).setIndexNames((0, "NET-SNMP-AGENT-MIB", "nsmContextName"), (0, "NET-SNMP-AGENT-MIB", "nsmRegistrationPoint"), (0, "NET-SNMP-AGENT-MIB", "nsmRegistrationPriority"))
if mibBuilder.loadTexts: nsModuleEntry.setDescription('An entry containing a registered mib oid.')
nsmContextName = MibTableColumn((1, 3, 6, 1, 4, 1, 8072, 1, 2, 1, 1, 1), SnmpAdminString())
if mibBuilder.loadTexts: nsmContextName.setDescription('The context name the module is registered under.')
nsmRegistrationPoint = MibTableColumn((1, 3, 6, 1, 4, 1, 8072, 1, 2, 1, 1, 2), ObjectIdentifier())
if mibBuilder.loadTexts: nsmRegistrationPoint.setDescription('The registry OID of a mib module.')
nsmRegistrationPriority = MibTableColumn((1, 3, 6, 1, 4, 1, 8072, 1, 2, 1, 1, 3), Integer32().subtype(subtypeSpec=ValueRangeConstraint(-2147483648,2147483647)))
if mibBuilder.loadTexts: nsmRegistrationPriority.setDescription('The priority of the registered mib module.')
nsModuleName = MibTableColumn((1, 3, 6, 1, 4, 1, 8072, 1, 2, 1, 1, 4), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: nsModuleName.setDescription('The module name that registered this OID.')
nsModuleModes = MibTableColumn((1, 3, 6, 1, 4, 1, 8072, 1, 2, 1, 1, 5), Bits().clone(namedValues=NamedValues(("getAndGetNext", 0), ("set", 1), ("getBulk", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: nsModuleModes.setDescription('The modes that the particular lower level handler can cope\n  \t with directly.')
nsModuleTimeout = MibTableColumn((1, 3, 6, 1, 4, 1, 8072, 1, 2, 1, 1, 6), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: nsModuleTimeout.setDescription('The registered timeout.  This is only meaningful for handlers\n\t that expect to return results at a later date (subagents,\n\t etc)')
nsNotifyStart = NotificationType((1, 3, 6, 1, 4, 1, 8072, 4, 0, 1)).setObjects(*())
if mibBuilder.loadTexts: nsNotifyStart.setDescription('An indication that the agent has started running.')
nsNotifyShutdown = NotificationType((1, 3, 6, 1, 4, 1, 8072, 4, 0, 2)).setObjects(*())
if mibBuilder.loadTexts: nsNotifyShutdown.setDescription('An indication that the agent is in the process of being shut down.')
nsNotifyRestart = NotificationType((1, 3, 6, 1, 4, 1, 8072, 4, 0, 3)).setObjects(*())
if mibBuilder.loadTexts: nsNotifyRestart.setDescription('An indication that the agent has been restarted.\n\t This does not imply anything about whether the configuration has\n\t changed or not (unlike the standard coldStart or warmStart traps)')
nsModuleGroup = ObjectGroup((1, 3, 6, 1, 4, 1, 8072, 5, 2, 2)).setObjects(*(("NET-SNMP-AGENT-MIB", "nsModuleName"), ("NET-SNMP-AGENT-MIB", "nsModuleModes"), ("NET-SNMP-AGENT-MIB", "nsModuleTimeout"),))
if mibBuilder.loadTexts: nsModuleGroup.setDescription('The objects relating to the list of MIB modules registered\n\t with the Net-SNMP agent.')
nsCacheGroup = ObjectGroup((1, 3, 6, 1, 4, 1, 8072, 5, 2, 4)).setObjects(*(("NET-SNMP-AGENT-MIB", "nsCacheDefaultTimeout"), ("NET-SNMP-AGENT-MIB", "nsCacheEnabled"), ("NET-SNMP-AGENT-MIB", "nsCacheTimeout"), ("NET-SNMP-AGENT-MIB", "nsCacheStatus"),))
if mibBuilder.loadTexts: nsCacheGroup.setDescription('The objects relating to data caching in the Net-SNMP agent.')
nsConfigGroups = MibIdentifier((1, 3, 6, 1, 4, 1, 8072, 5, 2, 7))
nsDebugGroup = ObjectGroup((1, 3, 6, 1, 4, 1, 8072, 5, 2, 7, 1)).setObjects(*(("NET-SNMP-AGENT-MIB", "nsDebugEnabled"), ("NET-SNMP-AGENT-MIB", "nsDebugOutputAll"), ("NET-SNMP-AGENT-MIB", "nsDebugDumpPdu"), ("NET-SNMP-AGENT-MIB", "nsDebugTokenStatus"),))
if mibBuilder.loadTexts: nsDebugGroup.setDescription('The objects relating to debug configuration in the Net-SNMP agent.')
nsLoggingGroup = ObjectGroup((1, 3, 6, 1, 4, 1, 8072, 5, 2, 7, 2)).setObjects(*(("NET-SNMP-AGENT-MIB", "nsLogType"), ("NET-SNMP-AGENT-MIB", "nsLogMaxLevel"), ("NET-SNMP-AGENT-MIB", "nsLogStatus"),))
if mibBuilder.loadTexts: nsLoggingGroup.setDescription('The objects relating to logging configuration in the Net-SNMP agent.')
nsTransactionGroup = ObjectGroup((1, 3, 6, 1, 4, 1, 8072, 5, 2, 8)).setObjects(*(("NET-SNMP-AGENT-MIB", "nsTransactionMode"),))
if mibBuilder.loadTexts: nsTransactionGroup.setDescription('The objects relating to transaction monitoring in the Net-SNMP agent.')
nsAgentNotifyGroup = NotificationGroup((1, 3, 6, 1, 4, 1, 8072, 5, 2, 9)).setObjects(*(("NET-SNMP-AGENT-MIB", "nsNotifyStart"), ("NET-SNMP-AGENT-MIB", "nsNotifyShutdown"), ("NET-SNMP-AGENT-MIB", "nsNotifyRestart"),))
if mibBuilder.loadTexts: nsAgentNotifyGroup.setDescription('The notifications relating to the basic operation of the Net-SNMP agent.')
mibBuilder.exportSymbols("NET-SNMP-AGENT-MIB", nsMibRegistry=nsMibRegistry, nsCachedOID=nsCachedOID, nsModuleModes=nsModuleModes, nsCacheEntry=nsCacheEntry, nsLoggingTable=nsLoggingTable, nsDLMod=nsDLMod, nsTransactionTable=nsTransactionTable, nsCacheStatus=nsCacheStatus, nsCacheDefaultTimeout=nsCacheDefaultTimeout, nsConfigLogging=nsConfigLogging, nsAgentNotifyGroup=nsAgentNotifyGroup, nsTransactions=nsTransactions, nsCacheEnabled=nsCacheEnabled, nsTransactionGroup=nsTransactionGroup, nsErrorHistory=nsErrorHistory, nsLogLevel=nsLogLevel, nsTransactionEntry=nsTransactionEntry, nsNotifyShutdown=nsNotifyShutdown, nsDebugEnabled=nsDebugEnabled, nsDebugTokenPrefix=nsDebugTokenPrefix, nsModuleGroup=nsModuleGroup, nsCacheTimeout=nsCacheTimeout, nsLogStatus=nsLogStatus, nsmRegistrationPriority=nsmRegistrationPriority, nsVersion=nsVersion, nsLogMaxLevel=nsLogMaxLevel, nsmRegistrationPoint=nsmRegistrationPoint, nsNotifyStart=nsNotifyStart, nsConfigGroups=nsConfigGroups, nsDebugDumpPdu=nsDebugDumpPdu, PYSNMP_MODULE_ID=netSnmpAgentMIB, nsDebugTokenStatus=nsDebugTokenStatus, netSnmpAgentMIB=netSnmpAgentMIB, nsLogType=nsLogType, nsTransactionMode=nsTransactionMode, nsLogToken=nsLogToken, nsExtensions=nsExtensions, nsConfigDebug=nsConfigDebug, nsModuleTimeout=nsModuleTimeout, nsDebugTokenEntry=nsDebugTokenEntry, nsDebugTokenTable=nsDebugTokenTable, nsCache=nsCache, nsModuleTable=nsModuleTable, nsTransactionID=nsTransactionID, nsModuleEntry=nsModuleEntry, nsCacheTable=nsCacheTable, nsLoggingEntry=nsLoggingEntry, NetsnmpCacheStatus=NetsnmpCacheStatus, nsModuleName=nsModuleName, nsDebugGroup=nsDebugGroup, nsmContextName=nsmContextName, nsCacheGroup=nsCacheGroup, nsDebugOutputAll=nsDebugOutputAll, nsNotifyRestart=nsNotifyRestart, nsLoggingGroup=nsLoggingGroup, nsConfiguration=nsConfiguration)
