#
# PySNMP MIB module DIRECTORY-SERVER-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/DIRECTORY-SERVER-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:07:50 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( ObjectIdentifier, Integer, OctetString, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "Integer", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsUnion, ConstraintsIntersection, SingleValueConstraint, ValueRangeConstraint, ValueSizeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsUnion", "ConstraintsIntersection", "SingleValueConstraint", "ValueRangeConstraint", "ValueSizeConstraint")
( applIndex, URLString, DistinguishedName, ) = mibBuilder.importSymbols("NETWORK-SERVICES-MIB", "applIndex", "URLString", "DistinguishedName")
( ZeroBasedCounter32, ) = mibBuilder.importSymbols("RMON2-MIB", "ZeroBasedCounter32")
( NotificationGroup, ObjectGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ObjectGroup", "ModuleCompliance")
( TimeTicks, Gauge32, MibScalar, MibTable, MibTableRow, MibTableColumn, Bits, Integer32, NotificationType, ModuleIdentity, Counter32, mib_2, IpAddress, ObjectIdentity, Counter64, MibIdentifier, iso, Unsigned32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "TimeTicks", "Gauge32", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Bits", "Integer32", "NotificationType", "ModuleIdentity", "Counter32", "mib-2", "IpAddress", "ObjectIdentity", "Counter64", "MibIdentifier", "iso", "Unsigned32")
( TextualConvention, DisplayString, TimeStamp, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "DisplayString", "TimeStamp")
dsMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 66)).setRevisions(("1999-06-07 00:00", "1993-11-25 00:00",))
if mibBuilder.loadTexts: dsMIB.setLastUpdated('9906070000Z')
if mibBuilder.loadTexts: dsMIB.setOrganization('IETF Mail and Directory Management Working\n                     Group')
if mibBuilder.loadTexts: dsMIB.setContactInfo('                      Glenn Mansfield\n                     Postal: Cyber Solutions Inc.\n                             6-6-3, Minami Yoshinari\n                             Aoba-ku, Sendai, Japan 989-3204.\n\n                        Tel: +81-22-303-4012\n                        Fax: +81-22-303-4015\n                   E-mail: glenn@cysols.com\n       Working Group E-mail: ietf-madman@innosoft.com\n               To subscribe: ietf-madman-request@innosoft.com')
if mibBuilder.loadTexts: dsMIB.setDescription(' The MIB module for monitoring Directory Services.')
dsTable = MibTable((1, 3, 6, 1, 2, 1, 66, 1), )
if mibBuilder.loadTexts: dsTable.setDescription(' The table holding information related to the Directory\n            Servers.')
dsTableEntry = MibTableRow((1, 3, 6, 1, 2, 1, 66, 1, 1), ).setIndexNames((0, "NETWORK-SERVICES-MIB", "applIndex"))
if mibBuilder.loadTexts: dsTableEntry.setDescription(' Entry containing summary description for a Directory\n            Server.')
dsServerType = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 1, 1, 1), Bits().clone(namedValues=NamedValues(("frontEndDirectoryServer", 0), ("backEndDirectoryServer", 1),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsServerType.setDescription('This object indicates whether the server is\n           a frontend or, a backend or, both. If the server\n           is a frontend, then the frontEndDirectoryServer\n           bit will be set. Similarly for the backend.')
dsServerDescription = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 1, 1, 2), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsServerDescription.setDescription('A text description of the application.  This information\n          is intended to identify and briefly describe the\n          application in a status display.')
dsMasterEntries = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 1, 1, 3), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsMasterEntries.setDescription(' Number of entries mastered in the Directory Server.')
dsCopyEntries = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 1, 1, 4), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsCopyEntries.setDescription(' Number of entries for which systematic (slave)\n            copies are maintained in the Directory Server.')
dsCacheEntries = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 1, 1, 5), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsCacheEntries.setDescription(' Number of entries cached (non-systematic copies) in\n            the Directory Server. This will include the entries that\n            are cached partially. The negative cache is not counted.')
dsCacheHits = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 1, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsCacheHits.setDescription(' Number of operations that were serviced from\n            the locally held cache.')
dsSlaveHits = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 1, 1, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsSlaveHits.setDescription(' Number of operations that were serviced from\n            the locally held object replications ( copy-\n            entries).')
dsApplIfOpsTable = MibTable((1, 3, 6, 1, 2, 1, 66, 2), )
if mibBuilder.loadTexts: dsApplIfOpsTable.setDescription(' The table holding information related to the\n            Directory Server operations.')
dsApplIfOpsEntry = MibTableRow((1, 3, 6, 1, 2, 1, 66, 2, 1), ).setIndexNames((0, "NETWORK-SERVICES-MIB", "applIndex"), (0, "DIRECTORY-SERVER-MIB", "dsApplIfProtocolIndex"))
if mibBuilder.loadTexts: dsApplIfOpsEntry.setDescription(' Entry containing operations related statistics\n            for a Directory Server.')
dsApplIfProtocolIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfProtocolIndex.setDescription('An index to uniquely identify an entry corresponding to a\n          application-layer protocol interface. This index is used\n          for lexicographic ordering of the table.')
dsApplIfProtocol = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 2), ObjectIdentifier()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfProtocol.setDescription("An identification of the protocol being used by the application\n          on this interface.  For an OSI Application, this will be the\n          Application Context.  For Internet applications, the IANA\n          maintains a registry[22] of the OIDs which correspond to\n          well-known applications.  If the application protocol is\n          not listed in the registry, an OID value of the form\n          {applTCPProtoID port} or {applUDProtoID port} are used for\n          TCP-based and UDP-based protocols, respectively. In either\n          case 'port' corresponds to the primary port number being\n          used by the protocol. The OIDs applTCPProtoID and\n          applUDPProtoID are defined in NETWORK-SERVICES-MIB")
dsApplIfUnauthBinds = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfUnauthBinds.setDescription(' Number of unauthenticated/anonymous bind requests\n            received.')
dsApplIfSimpleAuthBinds = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfSimpleAuthBinds.setDescription(' Number of bind requests that were authenticated\n            using simple authentication procedures like password\n            checks. This includes the\n            password authentication using SASL mechanisms like\n            CRAM-MD5.')
dsApplIfStrongAuthBinds = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfStrongAuthBinds.setDescription(' Number of bind requests that were authenticated\n            using TLS and X.500 strong authentication procedures.\n            This includes the binds that were\n            authenticated using external authentication procedures.')
dsApplIfBindSecurityErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfBindSecurityErrors.setDescription(' Number of bind requests that have been rejected\n            due to inappropriate authentication or\n            invalid credentials.')
dsApplIfInOps = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfInOps.setDescription(' Number of requests received from DUAs or other\n            Directory Servers.')
dsApplIfReadOps = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 8), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfReadOps.setDescription(' Number of read requests  received.')
dsApplIfCompareOps = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 9), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfCompareOps.setDescription(' Number of compare requests received.')
dsApplIfAddEntryOps = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 10), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfAddEntryOps.setDescription(' Number of addEntry requests received.')
dsApplIfRemoveEntryOps = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 11), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfRemoveEntryOps.setDescription(' Number of removeEntry requests received.')
dsApplIfModifyEntryOps = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 12), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfModifyEntryOps.setDescription(' Number of modifyEntry requests received.')
dsApplIfModifyRDNOps = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 13), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfModifyRDNOps.setDescription(' Number of modifyRDN requests received.')
dsApplIfListOps = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 14), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfListOps.setDescription(' Number of list requests received.')
dsApplIfSearchOps = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 15), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfSearchOps.setDescription(' Number of search requests- baseObject searches,\n            oneLevel searches and  whole subtree searches,\n            received.')
dsApplIfOneLevelSearchOps = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 16), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfOneLevelSearchOps.setDescription(' Number of oneLevel search requests received.')
dsApplIfWholeSubtreeSearchOps = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 17), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfWholeSubtreeSearchOps.setDescription(' Number of whole subtree search requests received.')
dsApplIfReferrals = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 18), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfReferrals.setDescription(' Number of referrals returned in response\n            to requests for operations.')
dsApplIfChainings = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 19), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfChainings.setDescription(' Number of operations forwarded by this Directory Server\n            to other Directory Servers.')
dsApplIfSecurityErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 20), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfSecurityErrors.setDescription(' Number of requests received\n            which did not meet the security requirements. ')
dsApplIfErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 21), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfErrors.setDescription(' Number of requests that could not be serviced\n            due to errors other than security errors, and\n            referrals.\n            A partially serviced operation will not be counted\n            as an error.\n            The errors include naming-related, update-related,\n            attribute-related and service-related errors.')
dsApplIfReplicationUpdatesIn = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 22), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfReplicationUpdatesIn.setDescription(' Number of replication updates fetched or received from\n            supplier Directory Servers.')
dsApplIfReplicationUpdatesOut = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 23), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfReplicationUpdatesOut.setDescription(' Number of replication updates sent to or taken by\n            consumer Directory Servers.')
dsApplIfInBytes = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 24), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfInBytes.setDescription(' Incoming traffic, in bytes, on the interface.\n            This will include requests from DUAs as well\n            as responses from other Directory Servers.')
dsApplIfOutBytes = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 25), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfOutBytes.setDescription(' Outgoing traffic in bytes on the interface.\n            This will include responses to DUAs and Directory\n            Servers as well as requests to other Directory Servers.')
dsIntTable = MibTable((1, 3, 6, 1, 2, 1, 66, 3), )
if mibBuilder.loadTexts: dsIntTable.setDescription(' Each row of this table contains some details\n            related to the history of the interaction\n            of the monitored Directory Server with its\n            peer Directory Servers.')
dsIntEntry = MibTableRow((1, 3, 6, 1, 2, 1, 66, 3, 1), ).setIndexNames((0, "NETWORK-SERVICES-MIB", "applIndex"), (0, "DIRECTORY-SERVER-MIB", "dsIntEntIndex"), (0, "DIRECTORY-SERVER-MIB", "dsApplIfProtocolIndex"))
if mibBuilder.loadTexts: dsIntEntry.setDescription(' Entry containing interaction details of a Directory\n            Server with a peer Directory Server.')
dsIntEntIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 3, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647)))
if mibBuilder.loadTexts: dsIntEntIndex.setDescription(' Together with applIndex and dsApplIfProtocolIndex, this\n            object forms the unique key to\n            identify the conceptual row which contains useful info\n            on the (attempted) interaction between the Directory\n            Server (referred to by applIndex) and a peer Directory\n            Server using a particular protocol.')
dsIntEntDirectoryName = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 3, 1, 2), DistinguishedName()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsIntEntDirectoryName.setDescription(' Distinguished Name of the peer Directory Server to\n            which this entry pertains.')
dsIntEntTimeOfCreation = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 3, 1, 3), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsIntEntTimeOfCreation.setDescription(' The value of sysUpTime when this row was created.\n            If the entry was created before the network management\n            subsystem was initialized, this object will contain\n            a value of zero.')
dsIntEntTimeOfLastAttempt = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 3, 1, 4), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsIntEntTimeOfLastAttempt.setDescription(' The value of sysUpTime when the last attempt was made\n            to contact the peer Directory Server. If the last attempt\n            was made before the network management subsystem was\n            initialized, this object will contain a value of zero.')
dsIntEntTimeOfLastSuccess = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 3, 1, 5), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsIntEntTimeOfLastSuccess.setDescription(' The value of sysUpTime when the last attempt made to\n            contact the peer Directory Server was successful. If there\n            have been no successful attempts this entry will have a value\n            of zero. If the last successful attempt was made before\n            the network management subsystem was initialized, this\n            object will contain a value of zero.')
dsIntEntFailuresSinceLastSuccess = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 3, 1, 6), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsIntEntFailuresSinceLastSuccess.setDescription(' The number of failures since the last time an\n            attempt to contact the peer Directory Server was successful.\n            If there have been no successful attempts, this counter\n            will contain the number of failures since this entry\n            was created.')
dsIntEntFailures = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 3, 1, 7), ZeroBasedCounter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsIntEntFailures.setDescription(' Cumulative failures in contacting the peer Directory Server\n            since the creation of this entry.')
dsIntEntSuccesses = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 3, 1, 8), ZeroBasedCounter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsIntEntSuccesses.setDescription(' Cumulative successes in contacting the peer Directory Server\n            since the creation of this entry.')
dsIntEntURL = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 3, 1, 9), URLString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsIntEntURL.setDescription(' URL of the peer Directory Server.')
dsConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 66, 4))
dsGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 66, 4, 1))
dsCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 66, 4, 2))
dsEntryCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 66, 4, 2, 1)).setObjects(*(("DIRECTORY-SERVER-MIB", "dsEntryGroup"),))
if mibBuilder.loadTexts: dsEntryCompliance.setDescription('The compliance statement for SNMP entities\n                which implement the DIRECTORY-SERVER-MIB for\n                a summary overview of the Directory Servers .')
dsOpsCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 66, 4, 2, 2)).setObjects(*(("DIRECTORY-SERVER-MIB", "dsEntryGroup"), ("DIRECTORY-SERVER-MIB", "dsOpsGroup"),))
if mibBuilder.loadTexts: dsOpsCompliance.setDescription('The compliance statement for SNMP entities\n                which implement the DIRECTORY-SERVER-MIB for monitoring\n                Directory Server operations,  entry statistics and cache\n                performance.')
dsIntCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 66, 4, 2, 3)).setObjects(*(("DIRECTORY-SERVER-MIB", "dsEntryGroup"), ("DIRECTORY-SERVER-MIB", "dsIntGroup"),))
if mibBuilder.loadTexts: dsIntCompliance.setDescription(' The compliance statement  for SNMP  entities\n                     which implement the DIRECTORY-SERVER-MIB for\n                     monitoring Directory Server operations and the\n                     interaction of the Directory Server with peer\n                     Directory Servers.')
dsOpsIntCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 66, 4, 2, 4)).setObjects(*(("DIRECTORY-SERVER-MIB", "dsEntryGroup"), ("DIRECTORY-SERVER-MIB", "dsOpsGroup"), ("DIRECTORY-SERVER-MIB", "dsIntGroup"),))
if mibBuilder.loadTexts: dsOpsIntCompliance.setDescription(' The compliance statement  for SNMP  entities\n                  which implement the DIRECTORY-SERVER-MIB for monitoring\n                  Directory Server operations and the interaction of the\n                  Directory Server with peer Directory Servers.')
dsEntryGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 66, 4, 1, 1)).setObjects(*(("DIRECTORY-SERVER-MIB", "dsServerType"), ("DIRECTORY-SERVER-MIB", "dsServerDescription"), ("DIRECTORY-SERVER-MIB", "dsMasterEntries"), ("DIRECTORY-SERVER-MIB", "dsCopyEntries"), ("DIRECTORY-SERVER-MIB", "dsCacheEntries"), ("DIRECTORY-SERVER-MIB", "dsCacheHits"), ("DIRECTORY-SERVER-MIB", "dsSlaveHits"),))
if mibBuilder.loadTexts: dsEntryGroup.setDescription(' A collection of objects for a summary overview of the\n                  Directory Servers.')
dsOpsGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 66, 4, 1, 2)).setObjects(*(("DIRECTORY-SERVER-MIB", "dsApplIfProtocolIndex"), ("DIRECTORY-SERVER-MIB", "dsApplIfProtocol"), ("DIRECTORY-SERVER-MIB", "dsApplIfUnauthBinds"), ("DIRECTORY-SERVER-MIB", "dsApplIfSimpleAuthBinds"), ("DIRECTORY-SERVER-MIB", "dsApplIfStrongAuthBinds"), ("DIRECTORY-SERVER-MIB", "dsApplIfBindSecurityErrors"), ("DIRECTORY-SERVER-MIB", "dsApplIfInOps"), ("DIRECTORY-SERVER-MIB", "dsApplIfReadOps"), ("DIRECTORY-SERVER-MIB", "dsApplIfCompareOps"), ("DIRECTORY-SERVER-MIB", "dsApplIfAddEntryOps"), ("DIRECTORY-SERVER-MIB", "dsApplIfRemoveEntryOps"), ("DIRECTORY-SERVER-MIB", "dsApplIfModifyEntryOps"), ("DIRECTORY-SERVER-MIB", "dsApplIfModifyRDNOps"), ("DIRECTORY-SERVER-MIB", "dsApplIfListOps"), ("DIRECTORY-SERVER-MIB", "dsApplIfSearchOps"), ("DIRECTORY-SERVER-MIB", "dsApplIfOneLevelSearchOps"), ("DIRECTORY-SERVER-MIB", "dsApplIfWholeSubtreeSearchOps"), ("DIRECTORY-SERVER-MIB", "dsApplIfReferrals"), ("DIRECTORY-SERVER-MIB", "dsApplIfChainings"), ("DIRECTORY-SERVER-MIB", "dsApplIfSecurityErrors"), ("DIRECTORY-SERVER-MIB", "dsApplIfErrors"), ("DIRECTORY-SERVER-MIB", "dsApplIfReplicationUpdatesIn"), ("DIRECTORY-SERVER-MIB", "dsApplIfReplicationUpdatesOut"), ("DIRECTORY-SERVER-MIB", "dsApplIfInBytes"), ("DIRECTORY-SERVER-MIB", "dsApplIfOutBytes"),))
if mibBuilder.loadTexts: dsOpsGroup.setDescription(' A collection of objects for monitoring the Directory\n                  Server operations.')
dsIntGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 66, 4, 1, 3)).setObjects(*(("DIRECTORY-SERVER-MIB", "dsIntEntDirectoryName"), ("DIRECTORY-SERVER-MIB", "dsIntEntTimeOfCreation"), ("DIRECTORY-SERVER-MIB", "dsIntEntTimeOfLastAttempt"), ("DIRECTORY-SERVER-MIB", "dsIntEntTimeOfLastSuccess"), ("DIRECTORY-SERVER-MIB", "dsIntEntFailuresSinceLastSuccess"), ("DIRECTORY-SERVER-MIB", "dsIntEntFailures"), ("DIRECTORY-SERVER-MIB", "dsIntEntSuccesses"), ("DIRECTORY-SERVER-MIB", "dsIntEntURL"),))
if mibBuilder.loadTexts: dsIntGroup.setDescription(" A collection of objects for monitoring the Directory\n                  Server's interaction with peer Directory Servers.")
mibBuilder.exportSymbols("DIRECTORY-SERVER-MIB", dsApplIfReferrals=dsApplIfReferrals, dsConformance=dsConformance, dsIntTable=dsIntTable, dsApplIfInBytes=dsApplIfInBytes, dsTable=dsTable, dsApplIfChainings=dsApplIfChainings, dsApplIfStrongAuthBinds=dsApplIfStrongAuthBinds, dsServerType=dsServerType, dsIntEntry=dsIntEntry, dsIntEntIndex=dsIntEntIndex, dsApplIfReadOps=dsApplIfReadOps, dsSlaveHits=dsSlaveHits, dsApplIfModifyRDNOps=dsApplIfModifyRDNOps, dsApplIfSearchOps=dsApplIfSearchOps, dsIntEntTimeOfCreation=dsIntEntTimeOfCreation, dsTableEntry=dsTableEntry, dsIntEntTimeOfLastAttempt=dsIntEntTimeOfLastAttempt, dsApplIfOneLevelSearchOps=dsApplIfOneLevelSearchOps, dsServerDescription=dsServerDescription, PYSNMP_MODULE_ID=dsMIB, dsIntEntURL=dsIntEntURL, dsApplIfSimpleAuthBinds=dsApplIfSimpleAuthBinds, dsIntEntFailuresSinceLastSuccess=dsIntEntFailuresSinceLastSuccess, dsApplIfAddEntryOps=dsApplIfAddEntryOps, dsApplIfOpsEntry=dsApplIfOpsEntry, dsApplIfSecurityErrors=dsApplIfSecurityErrors, dsEntryGroup=dsEntryGroup, dsCopyEntries=dsCopyEntries, dsOpsIntCompliance=dsOpsIntCompliance, dsApplIfReplicationUpdatesIn=dsApplIfReplicationUpdatesIn, dsOpsCompliance=dsOpsCompliance, dsCacheEntries=dsCacheEntries, dsIntEntDirectoryName=dsIntEntDirectoryName, dsApplIfListOps=dsApplIfListOps, dsApplIfUnauthBinds=dsApplIfUnauthBinds, dsIntGroup=dsIntGroup, dsApplIfOpsTable=dsApplIfOpsTable, dsApplIfErrors=dsApplIfErrors, dsOpsGroup=dsOpsGroup, dsIntCompliance=dsIntCompliance, dsApplIfProtocol=dsApplIfProtocol, dsApplIfProtocolIndex=dsApplIfProtocolIndex, dsCacheHits=dsCacheHits, dsApplIfRemoveEntryOps=dsApplIfRemoveEntryOps, dsApplIfCompareOps=dsApplIfCompareOps, dsApplIfWholeSubtreeSearchOps=dsApplIfWholeSubtreeSearchOps, dsApplIfModifyEntryOps=dsApplIfModifyEntryOps, dsIntEntFailures=dsIntEntFailures, dsIntEntSuccesses=dsIntEntSuccesses, dsGroups=dsGroups, dsApplIfInOps=dsApplIfInOps, dsApplIfReplicationUpdatesOut=dsApplIfReplicationUpdatesOut, dsIntEntTimeOfLastSuccess=dsIntEntTimeOfLastSuccess, dsCompliances=dsCompliances, dsEntryCompliance=dsEntryCompliance, dsMIB=dsMIB, dsApplIfBindSecurityErrors=dsApplIfBindSecurityErrors, dsMasterEntries=dsMasterEntries, dsApplIfOutBytes=dsApplIfOutBytes)
